@@ -2,20 +2,22 @@
 #include <includes.h>
 
 
-
-
-/*
- * Escapes \n and \r properly. The resulting string
- * is copied in another buffer.
+/**
+ * @brief Escapes \\n and \\r \\ properly. The resulting string
+ * @brief is copied in another buffer  and returned.
+ * 
+ * @param in The string in which to escape newlines, carriage returns and
+ *           backslashes.
+ * 
+ * @return Parameter in, escaped or NULL if in equals NULL.
  */
-ExtFunc char * 
-addslashes(in)
-	char * in;
+ExtFunc char *
+addslashes (char* in)
 {
  char * ret;
  char * out;
 
- if ( in == NULL ) return NULL;
+ if (in == NULL) return NULL;
 
  out = malloc(strlen(in) * 2 + 1);
  bzero(out, strlen(in) * 2 + 1);
@@ -47,13 +49,14 @@ addslashes(in)
  return realloc(ret, strlen(ret) + 1);
 }
 
-/*
- * Replaces escape codes (\n, \r) by the real value
+/**
+ * @brief Replaces escape codes (\n, \r) by the real value.
+ * 
  * The resulting string is stored in another buffer
+ * @see addslashes
  */
-ExtFunc char * 
-rmslashes(in)
- char * in;
+ExtFunc char *
+rmslashes (char * in)
 {
  char * out = malloc(strlen(in) + 1);
  char * ret = out;
