@@ -24,6 +24,8 @@
  * of the hash list manager
  */
 
+#include <glib.h>
+
 #define __HARG_INTERNAL__
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -490,7 +492,7 @@ do_printf
   if (R != 0) {
     char *s = query_key_hlst ((void**)R) ;
     if (ptype)
-      fprintf (stderr, "<0x%04X/%d> = ", (void*)s,(int)(s));
+      fprintf (stderr, "<%p/%d> = ", s, (int)GPOINTER_TO_SIZE(s));
     else
       fprintf (stderr, "<%s> = ", s);
   } else {
@@ -674,8 +676,8 @@ harg_addt
 
   /* sanity check */
   if (a == 0 || key == 0 ||
-      size == 0 && ((value == 0) && is_blob_type (type) ||
-		    verify_simple_type (type, HARG_BLOB))) {
+      (size == 0 && (((value == 0) && is_blob_type (type)) ||
+		    verify_simple_type (type, HARG_BLOB)))) {
     errno = EINVAL; 
     return 0;
   }
@@ -738,8 +740,8 @@ harg_set_valuet
 
   /* sanity check */
   if (a == 0 || key == 0 ||
-      size == 0 && (value == 0 && is_blob_type (type) ||
-		    verify_simple_type (type, HARG_BLOB))) {
+      (size == 0 && (((value == 0) && is_blob_type (type)) ||
+		    verify_simple_type (type, HARG_BLOB)))) {
     errno = EINVAL; 
     return -1;
   }
@@ -828,8 +830,8 @@ harg_renamet
     return 0 ; /* nothing to do */
 
   /* check target type groups */
-  if (is_blob_type   (ntype) &&   is_blob_type (r->type) ||
-      is_scalar_type (ntype) && is_scalar_type (r->type) ||
+  if ((is_blob_type   (ntype) &&   is_blob_type (r->type)) ||
+      (is_scalar_type (ntype) && is_scalar_type (r->type)) ||
       is_specific_type (ntype) == 0) {
     if (same_keys == 0) {
       /* make new index */
@@ -933,9 +935,9 @@ harg_inct
     if (inc_op_creates_record (incop)) {
       if (R == 0 && (R = (harg**)make_hlst (a->x, key, klen)) == 0)
 	return -1;
-      *R = create_harg (type, (void*)inc, sizeof (int));
+      *R = create_harg (type, GSIZE_TO_POINTER(inc), sizeof (gpointer));
       errno = 0;
-      return (int)(*R)->d.d.ptr [0];
+      return GPOINTER_TO_SIZE((*R)->d.d.ptr [0]);
     }
     errno = ENOENT;
     return -1;
@@ -953,26 +955,26 @@ harg_inct
       errno = EEXIST;
       return -1;
     }
-    r->d.d.ptr [0] = (void*)((int)(r->d.d.ptr [0]) + inc) ;
-    return (int)r->d.d.ptr [0];
+    r->d.d.ptr [0] = GSIZE_TO_POINTER(GPOINTER_TO_SIZE(r->d.d.ptr [0]) + inc) ;
+    return GPOINTER_TO_SIZE(r->d.d.ptr [0]);
   }
 
   /* decrement */
-  if (inc_op_notnegtv_record (incop) && (int)r->d.d.ptr [0] < inc) {
+  if (inc_op_notnegtv_record (incop) && (GPOINTER_TO_SIZE(r->d.d.ptr [0]) < inc)) {
     errno = ERANGE;
     return -1;
   }
-  if (inc_op_notpostv_record (incop) && (int)r->d.d.ptr [0] > inc) {
+  if (inc_op_notpostv_record (incop) && (GPOINTER_TO_SIZE(r->d.d.ptr [0]) > inc)) {
     errno = ERANGE;
     return -1;
   }
-  if (inc_op_destroy0_record (incop) && (int)r->d.d.ptr [0] <= inc) {
+  if (inc_op_destroy0_record (incop) && (GPOINTER_TO_SIZE(r->d.d.ptr [0]) <= inc)) {
     delete_hlst (a->x, key, klen);
     return errno = 0;
   }
-  r->d.d.ptr [0] = (void*)((int)(r->d.d.ptr [0]) - inc) ;
+  r->d.d.ptr [0] = GSIZE_TO_POINTER(GPOINTER_TO_SIZE(r->d.d.ptr [0]) - inc) ;
   errno = 0 ;
-  return (int)r->d.d.ptr [0];
+  return GPOINTER_TO_SIZE(r->d.d.ptr [0]);
 }
 
 void harg_sort(harglst *a) {
