@@ -32,6 +32,7 @@
 #include "libnessus.h"
 #include "network.h"
 #include "resolve.h"
+#include "openvas-socket.h"
 
 #include <setjmp.h>
 
@@ -46,33 +47,32 @@
 #endif
 
 
-
 /*----------------------------------------------------------------*
  * Low-level connection management                                *
  *----------------------------------------------------------------*/
- 
+
 /** Nessus "FILE" structure */
 typedef struct {
- int fd;		/**< socket number, or whatever */
- int transport;	/**< "transport" layer code when stream is encapsultated.
-		 * Negative transport signals a free descriptor */
- int timeout;	  /**< timeout, in seconds special values: -2 for default */
- int options;			/**< Misc options - see libnessus.h */
-  
- int port;			 
-  SSL_CTX* 	ssl_ctx;	/**< SSL context 	*/
-  SSL_METHOD* 	ssl_mt;		/**< SSL method   */
-  SSL* 		ssl;		/**< SSL handler  */
-  int		last_ssl_err;	/**< Last SSL error code */
- pid_t		pid;		/**< Owner - for debugging only */
+  int fd;        /**< socket number, or whatever */
+  int transport; /**< "transport" layer code when stream is encapsultated.
+                  * Negative transport signals a free descriptor */
+  int timeout;   /**< timeout, in seconds special values: -2 for default */
+  int options;   /**< Misc options - see libnessus.h */
+
+  int port;
+  SSL_CTX*    ssl_ctx;       /**< SSL context.  */
+  SSL_METHOD* ssl_mt;        /**< SSL method.   */
+  SSL*        ssl;           /**< SSL handler.  */
+  int         last_ssl_err;  /**< Last SSL error code. */
+  pid_t       pid;           /**< Owner - for debugging only. */
 #if 0
-  int		last_sock_err;	/**< last socket level error */
+  int         last_sock_err;/**< last socket level error */
 #endif
-  char*		buf;		/**< NULL if unbuffered */
-  int		bufsz, bufcnt, bufptr;
+  char*       buf;          /**< NULL if unbuffered. */
+  int         bufsz, bufcnt, bufptr;
 } nessus_connection;
 
-/* 
+/**
  * The role of this offset is:
  * 1. To detect bugs when the program tries to write to a bad fd
  * 2. See if a fd is a real socket or a "nessus descriptor". This is a
@@ -83,33 +83,15 @@ typedef struct {
 
 static nessus_connection connections[NESSUS_FD_MAX];
 
-/*
- * Quick & dirty patch to run Nessus from behind a picky firewall (e.g.
- * FW/1 and his 'Rule 0'): Nessus will never open more than 1 connection at
- * a time.
- * Define NESSUS_CNX_LOCK, recompile and install nessus-library, and restart nessusd
- *
- * WARNING: waiting on the lock file may be long, so increase the default
- * script timeout or some scripts may be killed.
- */
-#undef NESSUS_CNX_LOCK
-/*#define NESSUS_CNX_LOCK	"/tmp/NessusCnx"*/
-
-#ifdef NESSUS_CNX_LOCK
-static int	lock_cnt = 0;
-static int	lock_fd = -1;
-#endif
-
 /**
  * NESSUS_STREAM(x) is TRUE if <x> is a Nessus-ified fd
  */
 #define NESSUS_STREAM(x) (((x - NESSUS_FD_OFF) < NESSUS_FD_MAX) && ((x - NESSUS_FD_OFF) >=0))
 
-
 /**
  * @brief Same as perror(), but prefixes the data by our pid.
  */
-static int 
+static int
 nessus_perror (const char* error)
 {
   fprintf(stderr, "[%d] %s : %s\n", getpid(), error, strerror(errno));
@@ -125,7 +107,7 @@ static int
 get_connection_fd()
 {
  int i;
- 
+
  for ( i = 0; i < NESSUS_FD_MAX ; i++)
  {
   if(connections[i].transport <= 0) /* Not used */
@@ -151,8 +133,8 @@ release_connection_fd (int fd)
      errno = EINVAL;
      return -1;
     }
-    
-    
+
+
  p = &(connections[fd - NESSUS_FD_OFF]);
 
  efree(&p->buf);
@@ -162,10 +144,8 @@ release_connection_fd (int fd)
  if (p->ssl_ctx != NULL)
   SSL_CTX_free(p->ssl_ctx);
 
-/* 
- * So far, fd is always a socket. If this is changed in the future, this
- * code shall be fixed
- */
+/* So far, fd is always a socket. If this is changed in the future, this
+ * code shall be fixed. */
 if (p->fd >= 0)
  {
   if (shutdown(p->fd, 2) < 0)
@@ -177,7 +157,7 @@ if (p->fd >= 0)
      * (ie: http), so we don't show this error by default
      */
     nessus_perror("release_connection_fd: shutdown()");
-#endif    
+#endif
     }
   if (socket_close(p->fd)  < 0)
     nessus_perror("release_connection_fd: close()");
@@ -230,38 +210,6 @@ nessus_deregister_connection (int fd)
 
 static int __port_closed;
 
-static int unblock_socket(int soc)
-{
-  int	flags =  fcntl(soc, F_GETFL, 0);
-  if (flags < 0)
-{
-      nessus_perror("fcntl(F_GETFL)");
-      return -1;
-    }
-  if (fcntl(soc, F_SETFL, O_NONBLOCK | flags) < 0)
-    {
-      nessus_perror("fcntl(F_SETFL,O_NONBLOCK)");
-      return -1;
-    }
-  return 0;
-}
-
-static int block_socket(int soc)
-{
-  int	flags =  fcntl(soc, F_GETFL, 0);
-  if (flags < 0)
-    {
-      nessus_perror("fcntl(F_GETFL)");
-      return -1;
-    }
-  if (fcntl(soc, F_SETFL, (~O_NONBLOCK) & flags) < 0)
-    {
-      nessus_perror("fcntl(F_SETFL,~O_NONBLOCK)");
-      return -1;
-    }
-  return 0;
-}
-
 /*
  * Initialize the SSL library (error strings and algorithms) and try
  * to set the pseudo random generator to something less silly than the
@@ -274,7 +222,7 @@ void sslerror2 (char* txt, int err)
 {
   char string[120];
 
-  ERR_error_string(err, string);
+  ERR_error_string_n(err, string, 120);
   fprintf(stderr, "[%d] %s: %s\n", getpid(), txt, string);
 }
 
@@ -314,9 +262,8 @@ nessus_SSL_init (char* path)
    * its PRNG
    */
 
- 
 #if 0
-  RAND_screen();	/* Only available under MSWin */
+  RAND_screen(); /* Only available under MSWin */
 #endif
 
 #ifdef EGD_PATH
@@ -346,7 +293,7 @@ nessus_SSL_init (char* path)
 	    return -1;
     RAND_write_file(path);	
     return 0;
-   } 
+   }
    return -1;
 }
 
@@ -452,7 +399,7 @@ stream_set_options (int fd, int reset_opt, int set_opt)
 }
 
 
-static int 
+static int
 read_stream_connection_unbuffered (int fd, void* buf0, int min_len, int max_len)
 {
   int			ret, realfd, trp, t, err;
@@ -464,7 +411,6 @@ read_stream_connection_unbuffered (int fd, void* buf0, int min_len, int max_len)
   time_t		now, then;
 
   int		 	select_status;
- 
 
   if (NESSUS_STREAM(fd))
     {
@@ -838,20 +784,20 @@ nsend (int fd, void* data, int length, int i_opt)
 
 
  /* Trying OS's send() */
-   block_socket(fd);	
-   do
+ openvas_sock_block(fd);
+ do
  {
        struct timeval tv = {0,5};
        fd_set wr;
        int e;
-       
+
        FD_ZERO(&wr);
        FD_SET(fd, &wr);
-       
+
        errno = 0;
        e  = select(fd + 1, NULL, &wr, NULL, &tv);
-       if ( e > 0 )
-       	 n = os_send(fd, data, length, i_opt);
+       if (e > 0)
+        n = os_send (fd, data, length, i_opt);
        else if ( e < 0 && errno == EINTR ) continue;
        else break;
      }
@@ -860,7 +806,7 @@ nsend (int fd, void* data, int length, int i_opt)
      fprintf(stderr, "[%d] nsend():send %s\n", getpid(), strerror(errno));
    return n;
  }
- 
+
 ExtFunc int
 nrecv (int fd, void* data, int length, int i_opt)
 {
@@ -876,13 +822,12 @@ nrecv (int fd, void* data, int length, int i_opt)
     return read_stream_connection(fd, data, length);
   }
 
- block_socket(fd);
+ openvas_sock_block(fd);
  do {
 	e = recv(fd, data, length, i_opt);
  } while ( e < 0 && errno == EINTR );
  return e;
 }
- 
 
 ExtFunc int
 close_stream_connection (int fd)
@@ -915,7 +860,7 @@ open_socket (struct sockaddr_in *paddr,
 
   __port_closed = 0;
 
-  if ((soc = socket(AF_INET, type, protocol)) < 0)
+  if ((soc = openvas_sock_new(AF_INET, type, protocol)) < 0)
     {
       nessus_perror("socket");
       return -1;
@@ -925,14 +870,13 @@ open_socket (struct sockaddr_in *paddr,
     timeout = TIMEOUT;
 
   if (timeout > 0)
-    if (unblock_socket(soc) < 0)
+    if (openvas_sock_unblock(soc) < 0)
       {
-	close(soc);
+        openvas_sock_close(soc);
 	return -1;
       }
 
-  
-  if (connect(soc, (struct sockaddr*) paddr, sizeof(*paddr)) < 0)
+  if (openvas_sock_connect(soc, (struct sockaddr*) paddr, sizeof(*paddr)) < 0)
     {
 #if debug_SSL > 2
       nessus_perror("connect");
@@ -940,7 +884,9 @@ open_socket (struct sockaddr_in *paddr,
 again:
       switch (errno)
 	{
+#ifdef EINPROGRESS
 	case EINPROGRESS:
+#endif
 	case EAGAIN:
 	  FD_ZERO(&fd_w);
 	  FD_SET(soc, &fd_w);
@@ -975,7 +921,7 @@ again:
 	      socket_close(soc);
 	      return -1;
 	    }
-	  
+
 	  if (opt == 0)
 	    break;
 #if DEBUG_SSL > 2
@@ -989,7 +935,7 @@ again:
 	  return  -1;
 	}
     }
-  block_socket(soc);
+  openvas_sock_block(soc);
   return soc;
 }
 
@@ -1028,20 +974,20 @@ int open_sock_tcp_hn (const char* hostname, unsigned int port)
  * @brief Reads a text from the socket stream into the argument buffer, always
  * @brief appending a '\\0' byte.
  * 
+ * @param buf  Buffer to read into.
+ * 
  * @return Number of bytes read, without the trailing '\\0'.
  */
 ExtFunc
 int recv_line (int soc, char* buf, size_t bufsiz)
 {
   int n, ret = 0;
-  
-  /*
-   * Dirty SSL hack
-   */
+
+  /* Dirty SSL hack */
   if(NESSUS_STREAM(soc))
   {
    buf[0] = '\0';
-   
+
    do
    {
     n = read_stream_connection_min (soc, buf + ret, 1, 1);
@@ -1050,37 +996,38 @@ int recv_line (int soc, char* buf, size_t bufsiz)
      case -1 :
        if(ret == 0)
         return -1;
-       else 
+       else
         return ret;
        break;
-     
+
      case 0:
        return ret;
        break;
-      
+
       default :
       	ret ++;
     }
    }
    while (buf [ret-1] != '\0' && buf [ret-1] != '\n' && ret < bufsiz) ;
-   
-   if(ret > 0 )
-   {
-   if (buf[ret - 1] != '\0')
-	{
-	if ( ret < bufsiz ) 
-		buf[ ret ] = '\0';
-	else 
-		buf [ bufsiz - 1 ] = '\0';
-	}
-   }
-   return ret;  
+
+   if (ret > 0 )
+    {
+      if (buf[ret - 1] != '\0')
+        {
+          if (ret < bufsiz)
+            buf[ ret ] = '\0';
+          else
+            buf[ bufsiz - 1 ] = '\0';
+        }
+    }
+
+   return ret;
   }
   else
   {
    fd_set rd;
    struct timeval tv;
-   
+
    do
    {
       int e;
@@ -1096,26 +1043,26 @@ int recv_line (int soc, char* buf, size_t bufsiz)
       {
        n = recv(soc, buf + ret, 1, 0);
        switch(n)
-       {
-        case -1 :
-	 if ( errno == EINTR ) continue;
-	 if(ret == 0)
-	  return -1;
-	 else
-	  return ret;
-	 break;  
-       case 0 :
-         return ret;
-       	 break;
-       default:
-         ret ++;	
+        {
+          case -1 :
+            if (errno == EINTR) continue;
+            if (ret == 0)
+              return -1;
+            else
+              return ret;
+            break;
+          case 0 :
+            return ret;
+            break;
+          default:
+            ret ++;
        }
-      } 
+      }
       else break;
       tv.tv_sec = 1;
       tv.tv_usec = 0;
     } while(buf[ret -1 ] != '\0' && buf[ret -1 ] != '\n' && ret < bufsiz);
-    
+
     if(ret > 0)
     {
     if(buf[ret - 1] != '\0')
@@ -1127,24 +1074,14 @@ int recv_line (int soc, char* buf, size_t bufsiz)
       }
     }
   }
+
   return ret;
 }
 
 ExtFunc int
 socket_close (int soc)
 {
-#if defined NESSUS_CNX_LOCK
-  if (lock_cnt > 0)
-    if (-- lock_cnt == 0)
-      {
-	if (flock(lock_fd, LOCK_UN) < 0)
-	  nessus_perror(NESSUS_CNX_LOCK);
-	if (close(lock_fd) < 0)
-	  nessus_perror(NESSUS_CNX_LOCK);
-	lock_fd = -1;
-      }
-#endif  
-  return close(soc);
+  return openvas_sock_close(soc);
 }
 
 ExtFunc void
@@ -1182,7 +1119,7 @@ auth_send (struct arglist * globals, char * data)
  }
  else sent+=n;
  }
- 
+
  if(confirm)
  {
   /*
