@@ -90,7 +90,7 @@ network_printf (int soc, char * data, ...)
 
   if(  soc <= 0 ) 
     return;
- 
+
   for(;;)
   {
    va_start(param, data);
@@ -147,24 +147,23 @@ network_gets (int soc, char* s, size_t size)
   /* We are assuming that recv_line() will block until it has 
    * recvieved a full line of data, encountered a hard error, or eof 
    * (socket close?)
-   * Also, recv_line will return 0 on error.
-   */
+   * Also, recv_line will return 0 on error. */
   n = recv_line(soc, s, size);
   if (n > 0)
     return n;
   else
-  {
     s[0] = '\0';    /* zero the buffer */
-    return -1;
-  }
+  return -1;
 }
 
 /**
- * Reads maximal size bytes from the socket soc into s and returns it.
- * Stops reading at '\0' and '\n' characters, and appends a 
- * terminating '\0' to s.
+ * @brief Reads maximal size bytes from the socket soc into s and returns it,
+ * @brief also stops at \\0's and \\n's.
  * 
- * @param soc  The socket.
+ * Stops reading at '\0' and '\n' characters, and appends a terminating '\0' to
+ * s.
+ * 
+ * @param soc  The socket (if NULL use current Contexts socket).
  * @param s    Pointer to the string (will not be set to NULL if NULL returned!).
  * @param size Number of bytes to maximally read from socket.
  * 
@@ -175,27 +174,29 @@ network_gets_raw (int soc, char* s, size_t size)
 {
   int n = 0, processed ;
 
-  if ( soc <= 0 ) soc = Context->socket;
-  if ( soc <= 0 ) return NULL;
+  if (soc <= 0) soc = Context->socket;
+  if (soc <= 0) return NULL;
 
-  /* read up until no more data, or a line terminating character 
-     '\0' or '\n' is found */
+  /* Read until no more data, or a line terminating character '\0'
+     or '\n' is found */
   for (processed = 0; processed < (int)size; processed ++) {
     if ((n = nrecv (soc, s + processed, 1, 0)) <= 0) {
-      /* on error, the characers read so far might be garbage */
+      /* On error, the characers read so far might be garbage */
       if (n < 0)
-	processed = 0 ;
-      break ;
+        processed = 0;
+      break;
     }
-    if (s [processed] == '\0' ||
-	s [processed] == '\n' )
-      break ;
+    if (   s [processed] == '\0'
+        || s [processed] == '\n')
+      break;
   }
 
-  /* append a terminating 0 character, return NULL on empty read */
-  if (processed + 1 == (int)size)  processed -- ;
-  s [processed] = '\0' ;
-  if (!processed) s = 0 ;
+  /* Append a terminating 0 character, return NULL on empty read */
+  if (processed + 1 == (int) size)
+    processed-- ;
+
+  s [processed] = '\0';
+  if (!processed) s = 0;
 
   return s;
 }
