@@ -26,13 +26,13 @@
  * do so, delete this exception statement from your version.
  */
 
-/**
+/** @file
  * If we want to scan big networks, nothing should be kept in memory
  * but be stored on disk instead. This also makes the link with
  * a database much easier.
  *
  * "As-is", this modules generates a flat file which is queried as a DB.
- * Users who deal with a huge number of hosts should consider installing
+ * Users who deal with a huge number of hosts should consider developing
  * a MySQL module.
  */
 
@@ -47,15 +47,41 @@
 
 extern struct context* Context;
 
+/**
+ * @brief Matrix holding the mapping actions that were done during application
+ * @brief of a severity filter (if Context->is_severity_mapped == TRUE).
+ * 
+ * The matrix gets filled in backend_convert and is used during report export.
+ * Rows are 'from', columns are 'to' severities.
+ * 
+ * The string<->integer conversation (e.g. "Security Hole" <-> 0) is done in
+ * priority_str_to_idx and priority_idx_to_str
+ */
+int sev_mapping_matrix[6][6];
+
 #define MAX_TMPFILES 256
 struct backend backends[MAX_TMPFILES];
 
+/**
+ * @brief Sets all elements in the sev_mapping_matrix to 0.
+ */
+void
+backend_reset_sev_mapping_matrix ()
+{
+  int r = 0;
+  int c = 0;
+
+  for (r = 0; r < 6; r++)
+    for (c = 0; c < 6; c++)
+      sev_mapping_matrix[r][c] = 0;
+}
 
 
 /**
  * @brief Prints info to stdout when BACKEND_DEBUG is defined.
  */
-void be_info(int be, const char * str)
+void
+be_info (int be, const char * str)
 {
 #ifdef BACKEND_DEBUG
  printf("%s(%d) disposable:%d, fd:%d, %s\n",
@@ -71,7 +97,6 @@ void be_info(int be, const char * str)
   	Monitoring functions
 ----------------------------------------------------------------------*/
 
-
 /**
  * @return -1 in case of error(s).
  */
@@ -81,7 +106,7 @@ backend_init (char* fname)
  char * tmpfile;
  int i = 0;
  char * tmpdir;
- 
+
  while((backends[i].fname) && (i<MAX_TMPFILES))i++;
  if(backends[i].fname)
   {
@@ -95,9 +120,9 @@ backend_init (char* fname)
  if(!tmpdir)tmpdir = getenv("TMP");
  if(!tmpdir)tmpdir = getenv("TEMP");
  if(!tmpdir)tmpdir = "/tmp";
- 
+
  tmpfile = g_build_filename (tmpdir, "openvas-XXXXXX", NULL);
- 
+
 #ifdef HAVE_MKSTEMP
  backends[i].fd = mkstemp(tmpfile);
  if( backends[i].fd >= 0 )
@@ -205,7 +230,7 @@ backend_insert_report_data (int be, char* subnet, char* host, char* port,
   {
     fprintf(stderr, "backend_insert: some arguments are NULL\n");
      return -1;
-  } 
+  }
 
  lseek(backends[be].fd, 0, SEEK_END);
  data = addslashes(data);
@@ -288,7 +313,55 @@ priority_humanstr_to_short_str (const char* humanstr)
 }
 
 /**
- * @brief Opens backend file, parses and transforms it into an arglist.
+ * @brief Convert message type into integer value used as index for severity
+ * @brief mapping count matrix.
+ * 
+ * @param str Message type name.
+ * @return Index or -1 if unknown.
+ */
+static int
+priority_str_to_idx (const char *str)
+{
+  if (!strcmp("Security Hole", str)) return 0;
+  if (!strcmp("Security Warning", str)) return 1;
+  if (!strcmp("Security Note", str)) return 2;
+  if (!strcmp("False Positive", str)) return 3;
+  if (!strcmp("Log Message", str)) return 4;
+  if (!strcmp("Debug Message", str)) return 5;
+
+  return -1;
+}
+
+/**
+ * @brief Converts an index from the severity mapping count matrix to its string
+ * @brief description.
+ * 
+ * @param idx Index in severity mapping matrix.
+ * @return Description as string or NULL if index unknown.
+ */
+char*
+priority_idx_to_str (int idx)
+{
+  if (idx == 0)
+    return "Security Hole";
+  if (idx == 1)
+    return "Security Warning";
+  if (idx == 2)
+    return "Security Note";
+  if (idx == 3)
+    return "False Positive";
+  if (idx == 4)
+    return "Log Message";
+  if (idx == 5)
+    return "Debug Message";
+
+  return NULL;
+}
+
+/**
+ * @brief Opens backend file, parses and transforms it into an arglist, fills
+ * @brief the severity mapping count matrix on the way, if a severity filter
+ * @brief is activated in the current Context.
  * 
  * Opens the backends file and parses its lines which look like
  * \<port (num/proto)\>|\<script id\>|\<REPORT|INFO|NOTE\>|\<data\>
@@ -303,205 +376,218 @@ priority_humanstr_to_short_str (const char* humanstr)
 struct arglist*
 backend_convert (int be)
 {
- harglst * hhosts;
- FILE * fd = fopen(backends[be].fname, "r");
- char buf[65535];
- char * current_hostname = NULL;
- struct arglist* current_host = NULL;
- struct arglist* nhosts = NULL;
- char * key;
- int line = 0;
- unsigned x;
+  harglst * hhosts;
+  FILE * fd = fopen (backends[be].fname, "r");
+  char buf[65535];
+  char * current_hostname = NULL;
+  struct arglist* current_host = NULL;
+  struct arglist* nhosts = NULL;
+  char * key;
+  int line = 0;
+  unsigned x;
 
- if(!fd)
-  {
-   perror("fopen ");
-   return NULL;
-  }
-  
- hhosts = harg_create(65000);
- bzero(buf, sizeof(buf));
- 
- while(fgets(buf, sizeof(buf) - 1, fd) && !feof(fd))
- {
-  char * buffer = NULL;
-  struct arglist * host = NULL;
-  struct arglist * ports = NULL;
-  struct arglist * port = NULL;
-  struct arglist * content = NULL;
-  char * hostname;
-  char * t;
-  char * t2;
-  char * id = NULL;
-  char * p = NULL;
-  
-  
-  line++;
-  
-  /* remove trailing \n */
-  buf[strlen(buf) - 1] = '\0'; 
-  
-  /* skip lines that are not <results> */
-  if(strncmp (buf, "results",
-              strlen("results"))) /* RATS: ignore, string literal is always nul- terminated */
-  	continue;
+  if (!fd)
+    {
+      perror ("fopen ");
+      return NULL;
+    }
 
-  /* "validate the nbe", as it has to have three '|'s */
-  t = strchr(buf, '|');
-  if(!t)goto parse_error;
-  
-  t = strchr(t+1, '|');
-  if(!t)goto parse_error;
- 
-  hostname = &(t[1]);
-  t = strchr(t+1, '|');
-  if(!t)goto parse_error;
- 	
-  t[0] = '\0';
- 
-  if(!current_hostname || strcmp(current_hostname, hostname))
+ if (Context->is_severity_mapped)
+   backend_reset_sev_mapping_matrix ();
+
+ hhosts = harg_create (65000);
+ bzero (buf, sizeof(buf));
+
+ while (fgets(buf, sizeof(buf) - 1, fd) && !feof(fd))
   {
-    host = harg_get_ptr(hhosts, hostname);
-    if(!host)
-    {
-      current_host = host = emalloc(sizeof(struct arglist));
-      if(current_hostname) efree(&current_hostname);
-      current_hostname = estrdup(hostname);
-      harg_add_ptr(hhosts, hostname, host);
-    }
-    else 
-    {
-      current_host = host;
-      if(current_hostname)efree(&current_hostname);
-      current_hostname = estrdup(hostname);
-    }
-  }
-  else
-  {
-    host = current_host;
-  }
-  
-  t += sizeof(char);
-  /*
-   * <port (num/proto)>|<script id>|<REPORT|INFO|NOTE>|<data>
-   * ^
-   * t is here
-   */
-   t2 = strchr(t, '|');
-   if(t2){
-    t2[0]='\0';
-   }
-  p = strdup(t);
-   
-   
-  buffer = strdup(t);
-  ports = arg_get_value(host, "PORTS");
-  if(!ports)
-  {
-   ports = emalloc(sizeof(struct arglist));
-   arg_add_value(host, "PORTS", ARG_ARGLIST, -1, ports);
-  }
-  
-  port = arg_get_value(ports, buffer);
-  if(!port)
-  {
-   port = emalloc(sizeof(struct arglist));
-   arg_add_value(ports, buffer, ARG_ARGLIST, -1, port);
-  }
-  arg_add_value(port, "STATE", ARG_INT, sizeof(int), (void*)1);
-  efree(&buffer);
-  
-  if(!t2 || !t2[1]){
-  	bzero(buf, sizeof (buf));
-	continue; /* port is open, that's all. */
- 	}
-  
-   t = t2+sizeof(char);
-  /*
-   * <port (num/proto)>|<script id>|<REPORT|INFO|NOTE>|<data>
-   *                    ^
-   *                    t is here
-   */
-  t2 = t;
-  t = strchr(t2, '|');
-  if(!t)continue;
-  t[0]='\0';
-  id = strdup(t2);
-  
-  t+=sizeof(char);
-  t2 = strchr(t, '|');
-  if(!t2) {
-    efree(id);
+    char * buffer = NULL;
+    struct arglist * host = NULL;
+    struct arglist * ports = NULL;
+    struct arglist * port = NULL;
+    struct arglist * content = NULL;
+    char * hostname;
+    char * t;
+    char * t2;
+    char * id = NULL;
+    char * p = NULL;
+
+    line++;
+
+    /* Remove trailing \n */
+    buf[strlen(buf) - 1] = '\0';
+
+    /* Skip lines that are not <results> */
+    if (strncmp (buf, "results",
+                 strlen("results"))) /* RATS: ignore, string literal is always nul- terminated */
+      continue;
+
+    /* "Validate the nbe", as it has to have three '|'s */
+    t = strchr (buf, '|');
+    if (!t) goto parse_error;
+
+    t = strchr (t+1, '|');
+    if (!t) goto parse_error;
+
+    hostname = &(t[1]);
+    t = strchr (t+1, '|');
+    if (!t) goto parse_error;
+
+    t[0] = '\0';
+
+    if (!current_hostname || strcmp (current_hostname, hostname))
+      {
+        host = harg_get_ptr (hhosts, hostname);
+        if (!host)
+          {
+            current_host = host = emalloc (sizeof(struct arglist));
+            if (current_hostname)
+              efree (&current_hostname);
+            current_hostname = estrdup (hostname);
+            harg_add_ptr (hhosts, hostname, host);
+          }
+        else
+          {
+            current_host = host;
+            if(current_hostname)efree(&current_hostname);
+            current_hostname = estrdup(hostname);
+          }
+      }
+    else
+      {
+        host = current_host;
+      }
+
+    t += sizeof(char);
+    /*
+     * <port (num/proto)>|<script id>|<REPORT|INFO|NOTE>|<data>
+     * ^
+     * t is here
+     */
+    t2 = strchr (t, '|');
+    if (t2)
+      t2[0]='\0';
+
+    p = strdup (t);
+
+    buffer = strdup (t);
+    ports = arg_get_value (host, "PORTS");
+    if (!ports)
+      {
+        ports = emalloc (sizeof(struct arglist));
+        arg_add_value (host, "PORTS", ARG_ARGLIST, -1, ports);
+      }
+
+    port = arg_get_value (ports, buffer);
+    if (!port)
+      {
+        port = emalloc (sizeof(struct arglist));
+        arg_add_value (ports, buffer, ARG_ARGLIST, -1, port);
+      }
+    arg_add_value (port, "STATE", ARG_INT, sizeof(int), (void*)1);
+    efree (&buffer);
+
+    if (!t2 || !t2[1])
+      {
+        bzero(buf, sizeof (buf));
+        continue; /* port is open, that's all. */
+      }
+
+    t = t2 + sizeof (char);
+    /*
+     * <port (num/proto)>|<script id>|<REPORT|INFO|NOTE>|<data>
+     *                    ^
+     *                    t is here
+     */
+    t2 = t;
+    t = strchr (t2, '|');
+    if(!t)
+      continue;
+    t[0] = '\0';
+    id = strdup (t2);
+
+    t += sizeof (char);
+    t2 = strchr (t, '|');
+    if (!t2)
+      {
+        efree (id);
+        continue;
+      }
+    t2[0] = 0;
+
+    if (Context->is_severity_mapped)
+      {
+        const char * prio = severity_filter_apply (current_hostname, p, id, t);
+        if (prio)
+          {
+            buffer = estrdup (priority_humanstr_to_short_str (prio));
+            ++sev_mapping_matrix[priority_str_to_idx(t)][priority_str_to_idx(prio)];
+          }
+        else
+          buffer = estrdup (priority_humanstr_to_short_str (t));
+      }
+    else
+      buffer = estrdup (priority_humanstr_to_short_str (t));
+
+    if (buffer == NULL)
+      {
+        fprintf (stderr, "Error - line %d is malformed (%s)\n", line, backends[be].fname);
+        fprintf (stderr, "  %s\n", t);
+        efree (id);
+        continue;
+      }
+
+    content = arg_get_value (port, buffer);
+
+    if(!content)
+      {
+        content = emalloc (sizeof(struct arglist));
+        arg_add_value (port, buffer, ARG_ARGLIST, -1, content);
+      }
+
+    efree (&buffer);
+    t2 += sizeof (char);
+    buffer = rmslashes (t2);
+    arg_add_value (content, id, ARG_STRING, strlen(buffer),buffer);
+    efree (&id);
+    bzero (buf, sizeof(buf));
     continue;
-  }
-  t2[0]=0;
-   
-  if (Context->is_severity_mapped)
-    {
-      const char * prio = severity_filter_apply (current_hostname, p, id, t);
-      if (prio)
-        buffer = estrdup (priority_humanstr_to_short_str (prio));
-      else
-        buffer = estrdup (priority_humanstr_to_short_str (t));
-    }
-  else
-    buffer = estrdup (priority_humanstr_to_short_str (t));
-
-  if (buffer == NULL) {
-    fprintf(stderr, "Error - line %d is malformed (%s)\n", line, backends[be].fname);
-    fprintf(stderr, "  %s\n", t);
-    efree(id);
-    continue;
-  }
-
-  content = arg_get_value(port, buffer);
-  
-  if(!content)
-  {
-   content = emalloc(sizeof(struct arglist));
-   arg_add_value(port, buffer, ARG_ARGLIST, -1, content);
-  }
-  
-  efree(&buffer);
-  t2+=sizeof(char);
-  buffer  = rmslashes(t2);
-  arg_add_value(content, id, ARG_STRING, strlen(buffer),buffer);
-  efree(&id);
-  bzero(buf, sizeof(buf));
-  continue;
 
 parse_error:
- bzero(buf, sizeof(buf));
- fprintf(stderr, "Parse error line <%d>\n", line);
- }
- fclose(fd);
- /*
-  *  harglist -> arglist conversion
-  */
- harg_csort(hhosts,_backend_cmpcb,"heh");
- harg_sort(hhosts);
- x = 0;
- nhosts = emalloc(sizeof(struct arglist));
- while((key = (char *)harg_get_nth(hhosts,x))) {
-  struct arglist * new = emalloc(sizeof(struct arglist));
-  struct arglist * h = harg_get_ptr(hhosts, key);
-  new->name = strdup(key);
-  new->type = ARG_ARGLIST;
-  new->length = -1;
-  new->value = h;
-  new->next = nhosts;
-  nhosts = new;
-  x++;
- }
+    bzero (buf, sizeof(buf));
+    fprintf (stderr, "Parse error line <%d>\n", line);
+  }
 
- return nhosts;
+  fclose(fd);
+  /* harglist -> arglist conversion */
+  harg_csort (hhosts,_backend_cmpcb, "heh");
+  harg_sort(hhosts);
+  x = 0;
+  nhosts = emalloc (sizeof(struct arglist));
+
+  while ((key = (char *) harg_get_nth(hhosts,x)))
+    {
+      struct arglist * new = emalloc (sizeof(struct arglist));
+      struct arglist * h = harg_get_ptr (hhosts, key);
+      new->name   = strdup (key);
+      new->type   = ARG_ARGLIST;
+      new->length = -1;
+      new->value  = h;
+      new->next   = nhosts;
+      nhosts      = new;
+      x++;
+    }
+
+  return nhosts;
 }
 
+/**
+ * @return Always 0.
+ */
 int
 backend_close (int be)
 {
  be_info(be, "CLOSE");
- 
+
 #ifdef HAVE_MMAP
  if(backends[be].mmap)
  {
@@ -511,9 +597,8 @@ backend_close (int be)
   efree(&backends[be].lines);
   efree(&backends[be].eols);
   backends[be].num_lines = 0;
-  
  }
-#endif 
+#endif
  if(backends[be].fd >= 0)
   close(backends[be].fd);
  backends[be].fd = -1;
@@ -528,7 +613,6 @@ backend_dispose (int be)
 
  be_info(be, "DISPOSE");
 
-
  if(backends[be].fd >= 0)
   backend_close(be);
 
@@ -554,7 +638,7 @@ backend_dispose (int be)
 #endif 
  bzero(&(backends[be]), sizeof(backends[be]));
  backends[be].fd = -1;
- return 0; 
+ return 0;
 }
 
 
@@ -563,24 +647,24 @@ backend_empty (int be)
 {
  FILE * f;
  char buf[32768];
- 
+
  if(backends[be].fname == NULL )
  {
-        fprintf(stderr, "NULL backend fname\n");
- 	return -1;
+  fprintf(stderr, "Could not open backend, fname is NULL\n");
+  return -1;
  }
 
  if(backends[be].fd < 0)
  {
   backends[be].fd = open(backends[be].fname, O_RDWR);
  }
- 
+
  if(backends[be].fd < 0)
  {
    fprintf(stderr, "Could not open backend\n");
    return -1;
  }
- 
+
  lseek(backends[be].fd, 0, SEEK_SET);
  f = fdopen(backends[be].fd, "r");
  if ( f == NULL ) 
@@ -588,7 +672,7 @@ backend_empty (int be)
   fprintf(stderr, "Could not re-open the backend\n");
   return -1;
  }
- 
+
  while(fgets(buf, sizeof(buf) - 1, f) != NULL )
  {
   buf[sizeof(buf) - 1] = '\0';
@@ -598,11 +682,13 @@ backend_empty (int be)
    return 1;
    }
  }
- 
+
  return 0;
 }
 
-
+/**
+ * @return Always 0.
+ */
 int
 backend_clear_all ()
 {
