@@ -27,8 +27,9 @@
  * do so, delete this exception statement from your version.
  */
 
-/**
- * Nessus Communication Manager
+/** @file
+ * OpenVAS Communication Manager, handles client/server communication on a
+ * rather high level
  */
 
 #include <includes.h>
@@ -80,13 +81,13 @@ comm_update_ui (struct context *context, int current)
   static int limit;
   static const char *fmt;
   gchar *pbar_text;
-  /* maximum number of steps for the progress bar (plugins + dependencies) */
+  /* Maximum number of steps for the progress bar (plugins + dependencies) */
 # define PBAR_MAX 12000
 
-  if(F_quiet_mode)
-    return; /* there is no UI to update in quiet mode */
+  if (F_quiet_mode)
+    return; /* There is no UI to update in quiet mode */
 
-  /* the task changes */
+  /* The task changes */
   if(previous != current)
   {
     previous = current;
@@ -109,23 +110,22 @@ comm_update_ui (struct context *context, int current)
   /* Update progress bar every 10 plugins (every 100 on slow links) */
   if(++number % (F_show_pixmaps?100:1000) == 0)
   {
-    /* if the progress bar is too short, step back 5% */
+    /* If the progress bar is too short, step back 5% */
     if(base+number >= limit)
       base -= PBAR_MAX/20;
 
-    /* update the progress bar */
-    gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(context->pbar),
-	1.0*(base+number)/PBAR_MAX);
+    /* Update the progress bar */
+    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR(context->pbar),
+                                   1.0 * (base+number)/PBAR_MAX);
 
-    /* update text displayed in the progress bar */
+    /* Update text displayed in the progress bar */
     pbar_text = g_strdup_printf(fmt, number);
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(context->pbar), pbar_text);
     g_free(pbar_text);
 
-    /* perform pending GUI events */
+    /* Perform pending GUI events */
      gtk_main_iteration();
   }
-
 #endif /* USE_GTK */
 }
 
@@ -144,16 +144,16 @@ parse_plugin (char * buf)
   char *t;
   size_t offset;
 
-  char * oid = NULL;
+  char * oid  = NULL;
   char * name = NULL;
-  char * category = NULL;
+  char * category  = NULL;
   char * copyright = NULL;
   char * description = NULL;
   char * summary = NULL;
-  char * family = NULL;
+  char * family  = NULL;
   char * version = NULL;
-  char * cve = NULL;
-  char * bid = NULL;
+  char * cve  = NULL;
+  char * bid  = NULL;
   char * xref = NULL;
   char * sign_key_ids;
   char * script_tags;
@@ -235,7 +235,7 @@ parse_plugin (char * buf)
     if(!str) failed = TRUE;
     else cve = str;
   }
-  
+
   if(failed == FALSE)
   {
     offset += strlen(str) + 5;
@@ -287,7 +287,7 @@ parse_plugin (char * buf)
   if(cve) efree(&cve);
   if(bid) efree(&bid);
   if(xref) efree(&xref);
-  
+
   return NULL;
 }
 
@@ -564,7 +564,6 @@ comm_parse_preference (struct context *context, struct arglist *serv_prefs,
 }
 
 
-
 /**
  * @brief Retrieves the server preferences and attempts parsing, calling
  * @brief comm_parse_preference.
@@ -678,7 +677,7 @@ cli_send_prefs_arglist(struct context *context, struct arglist *pref,
       {
         (*upload) = g_slist_prepend( (*upload), pref->value );
       }
-      
+
       // FIXME: Analogous to gui- preference sending, send the stuff in the cli
       if(strstr(pref->name, "[" PREF_SSH_CREDENTIALS "]:"))
       {
@@ -913,17 +912,17 @@ gui_comm_send_preferences (struct context* context)
         {
           network_printf(context->socket, "%s[%s]:%s <|> %s\n", plugs->name, type, name, value);
         }
-        
+
 	if(!strcmp(type, PREF_FILE))
 	{
 	  files_to_send = g_slist_prepend(files_to_send, value);
 	}
-        
+
         if(!strcmp(type, PREF_SSH_CREDENTIALS))
         {
           files_to_send = send_ssh_credential_files (files_to_send);
         }
-        
+
 	plugin_prefs = plugin_prefs->next;
       }
       plugs = plugs->next;
@@ -1194,8 +1193,8 @@ missing_plugins_list_init (struct missing_plugins_list * missing)
  * @brief Add an entry to the list of missing/outdated plugins.
  */
 static void
-missing_plugins_list_add(struct missing_plugins_list * missing,
-    const char * oid, const char * md5sum)
+missing_plugins_list_add (struct missing_plugins_list * missing,
+                          const char * oid, const char * md5sum)
 {
   if (missing->length == missing->allocated)
   {
@@ -1247,13 +1246,13 @@ update_existing_plugin (struct context *context,
                         struct nessus_plugin * plugin, void * data)
 {
   if (plugin && strcmp(plugin->md5sum, md5sum) == 0)
-  {
-    plugin->is_current = 1;
-  }
+    {
+      plugin->is_current = 1;
+    }
   else
-  {
-    missing_plugins_list_add((struct missing_plugins_list*)data, oid, md5sum);
-  }
+    {
+      missing_plugins_list_add((struct missing_plugins_list*)data, oid, md5sum);
+    }
 
   return 0;
 }
@@ -1282,16 +1281,16 @@ remove_outdated_plugins(struct nessus_plugin* plugin)
     if (!plugin->is_current)
     {
       if (prev != NULL)
-      {
-	prev->next = plugin->next;
-      }
-      nessus_plugin_free(plugin);
+        {
+          prev->next = plugin->next;
+        }
+      nessus_plugin_free (plugin);
     }
     else
     {
       prev = plugin;
       if (first == NULL)
-	first = plugin;
+        first = plugin;
     }
 
     plugin = next;
@@ -1338,7 +1337,7 @@ fetch_new_plugins(struct context *context, struct missing_plugins_list* missing,
       return -1;
     }
   }
-  
+
   /* Show the user the number of new plugins, if any. Also indicate whether 
    * they have been enabled (auto_enable_new_plugins option in context prefs).
    * For easier translation 4 strings (auto_enable*number) */
@@ -1392,7 +1391,7 @@ update_individual_plugins(struct context *context, char * buf, int bufsz)
   context->scanners = remove_outdated_plugins(context->scanners);
 
   result = fetch_new_plugins(context, &missing, buf, bufsz);
-    
+
 fail:
   missing_plugins_list_free(&missing);
   return result;
@@ -1407,12 +1406,13 @@ fail:
  */
 static int
 add_md5sum_to_plugin (struct context *context, const char * oid,
-                const char * md5sum, struct nessus_plugin * plugin, void * data)
+                      const char * md5sum, struct nessus_plugin * plugin,
+                      void * data)
 {
   if (plugin != NULL)
-  {
-    nessus_plugin_set_md5sum(plugin, md5sum);
-  }
+    {
+      nessus_plugin_set_md5sum(plugin, md5sum);
+    }
   else
     /* Since this function is used to fetch the md5sums for the plugins
      * immediately after the full list of plugins has been fetched from
@@ -1422,7 +1422,6 @@ add_md5sum_to_plugin (struct context *context, const char * oid,
 
   return 0;
 }
-  
 
 int
 comm_get_plugins (struct context *context)
@@ -1433,13 +1432,13 @@ comm_get_plugins (struct context *context)
   char * server_md5sum = NULL;
   int cache_status = -1;
 
-  /* without the plugins_md5sum we can't reliably update the plugins
+  /* Without the plugins_md5sum we can't reliably update the plugins
    * incrementally, so we have to make sure that all of the plugins are
    * reloaded */
   if (context->plugins_md5sum == NULL)
-  {
-    context_reset_plugins(context);
-  }
+    {
+      context_reset_plugins(context);
+    }
 
   bufsz = 1024 * 1024;
   buf = emalloc(bufsz);
@@ -1450,61 +1449,60 @@ comm_get_plugins (struct context *context)
    * case it starts with "SERVER <|> PLUGIN".  Anything else is probably
    * a login problem (wrong password, etc.)
    */
-  if(strncmp(buf, "SERVER <|> PLUGIN", 17) != 0)
-  {
-    result = -1;
-    goto fail;
-  }
+  if (strncmp(buf, "SERVER <|> PLUGIN", 17) != 0)
+    {
+      result = -1;
+      goto fail;
+    }
 
-  /* if we requested md5sums, we get the md5sum over all the plugins
+  /* If we requested md5sums, we get the md5sum over all the plugins
    * now */
   if(strncmp(buf, "SERVER <|> PLUGINS_MD5 <|> ", 27) == 0)
   {
     server_md5sum = parse_separator(buf + 22);
     if (server_md5sum == NULL)
-    {
-      show_error(_("Invalid PLUGINS_MD5 information sent from server"));
-      result = -1;
-      goto fail;
-    }
+      {
+        show_error(_("Invalid PLUGINS_MD5 information sent from server"));
+        result = -1;
+        goto fail;
+      }
 
     /* Read and check the cache */
     if (context->plugins_md5sum == NULL)
-    {
-      cache_status = plugin_cache_read(context);
-    }
-    else
-    {
-      /* The cache was already loaded */
-      cache_status = 0;
-    }
-    if (cache_status < 0) /* "error" */
-    {
-      /* the cache could not be read for some reason.  Most likely an
-       * error or no cache file exists. Fetch the full list of plugins  */
-      network_printf(context->socket, "CLIENT <|> COMPLETE_LIST <|> CLIENT\n");
-      network_gets(context->socket, buf, 27);
-    }
-    else if (strcmp(context->plugins_md5sum, server_md5sum) != 0)
-    {
-      /* the cache is outdated so we update the individual plugins.  We
-       * set the plugins_md5sum temporarily to a different value because
-       * neither the old md5sum nor the new md5sum just read from the
-       * server correspond to the plugin information in the context
-       * while the update is being performed.
-       */
-      context_set_plugins_md5sum(context, "");
-      if (update_individual_plugins(context, buf, bufsz) < 0)
       {
-	show_error(_("Error while updating the cached plugin information"));
-	result = -1;
-	goto fail;
+        cache_status = plugin_cache_read (context);
+      }
+    else
+      {
+        /* The cache was already loaded */
+        cache_status = 0;
+      }
+    if (cache_status < 0) /* "error" */
+      {
+        /* The cache could not be read for some reason.  Most likely an
+         * error or no cache file exists. Fetch the full list of plugins  */
+        network_printf(context->socket, "CLIENT <|> COMPLETE_LIST <|> CLIENT\n");
+        network_gets(context->socket, buf, 27);
+      }
+    else if (strcmp(context->plugins_md5sum, server_md5sum) != 0)
+      {
+        /* The cache is outdated so we update the individual plugins.  We
+         * set the plugins_md5sum temporarily to a different value because
+         * neither the old md5sum nor the new md5sum just read from the
+         * server correspond to the plugin information in the context
+         * while the update is being performed. */
+        context_set_plugins_md5sum (context, "");
+        if (update_individual_plugins (context, buf, bufsz) < 0)
+          {
+            show_error (_("Error while updating the cached plugin information"));
+            result = -1;
+            goto fail;
+          }
+        context_set_plugins_md5sum(context, server_md5sum);
       }
-      context_set_plugins_md5sum(context, server_md5sum);
-    }
   }
 
-  /* we may get a complete plugin list if we either did not request the
+  /* We may get a complete plugin list if we either did not request the
    * md5sum in the first place or if the cache wasn't current. */
   int n_new_plugins = 0;
   if (strncmp(buf, "SERVER <|> PLUGIN_LIST <|>", 26) == 0)
@@ -1541,36 +1539,36 @@ comm_get_plugins (struct context *context)
       comm_get_plugins_md5(context, buf, bufsz, add_md5sum_to_plugin, NULL);
   }
 
-  /* if we requested md5sums, we need to tell the server explicitly that
+  /* If we requested md5sums, we need to tell the server explicitly that
    * it should continue.  Also, write the cache. */
   if (server_md5sum != NULL)
-  {
-    context_set_plugins_md5sum(context, server_md5sum);
-    network_printf(context->socket, "CLIENT <|> GO ON <|> CLIENT\n");
-    context_reset_plugin_tree(context);
-    context_force_plugin_prefs_redraw(context);
-  }
+    {
+      context_set_plugins_md5sum(context, server_md5sum);
+      network_printf(context->socket, "CLIENT <|> GO ON <|> CLIENT\n");
+      context_reset_plugin_tree(context);
+      context_force_plugin_prefs_redraw(context);
+    }
   
   /* Show the user the number of new plugins, if any. Also indicate whether 
    * they have been enabled (auto_enable_new_plugins option in context prefs).
    * For easier translation 4 strings (auto_enable*number) */
   if(n_new_plugins > 0)
     {
-    int auto_enabled = prefs_get_int(context, "auto_enable_new_plugins");
-    if(n_new_plugins == 1)
-      {
-      if(auto_enabled)
-        show_info(_("Found and enabled one new plugin."));
-      else
-        show_info(_("Found and disabled one new plugin."));
-      }
-    else /* more than one, use linguistic plural*/
-      {
-      if(auto_enabled)
-        show_info(_("Found and enabled %d new plugins."), n_new_plugins);
-      else
-        show_info(_("Found and disabled %d new plugins."), n_new_plugins);
-      }
+      int auto_enabled = prefs_get_int(context, "auto_enable_new_plugins");
+      if(n_new_plugins == 1)
+        {
+        if(auto_enabled)
+          show_info(_("Found and enabled one new plugin."));
+        else
+          show_info(_("Found and disabled one new plugin."));
+        }
+      else /* more than one, use linguistic plural*/
+        {
+        if(auto_enabled)
+          show_info(_("Found and enabled %d new plugins."), n_new_plugins);
+        else
+          show_info(_("Found and disabled %d new plugins."), n_new_plugins);
+        }
     }
 
  fail:
@@ -1581,13 +1579,11 @@ comm_get_plugins (struct context *context)
 
 
 /*-------------------------------------------------------------------------
-
 			Sessions management
-			
 ---------------------------------------------------------------------------*/
 
 /**
- * Does the server support sessions saving ?
+ * @brief Does the server support sessions saving?
  */
 int
 comm_server_restores_sessions (struct context *context)
@@ -1637,6 +1633,9 @@ comm_restore_session (struct context * context, char *name)
   network_printf(context->socket, "CLIENT <|> SESSION_RESTORE <|> %s <|> CLIENT\n", name);
 }
 
+/*-------------------------------------------------------------------------
+               Requesting Dependencies and Certificates
+---------------------------------------------------------------------------*/
 
 int
 comm_get_dependencies (struct context *context)
@@ -1714,15 +1713,15 @@ comm_parse_certificate (char* buffer, struct context* context)
   char* pubkey;
   char* fpr;
   char* fpr_short = NULL;
-  
+
   if( strcmp(buffer, "<|> SERVER\n") == 0 )
     return 1;
 
   // Initialize the hashtable if not yet done.
   if(context->signer_fp_certificates == NULL)
-    context->signer_fp_certificates =  g_hash_table_new_full(g_str_hash, 
+    context->signer_fp_certificates =  g_hash_table_new_full(g_str_hash,
                    g_str_equal, NULL, (GDestroyNotify) openvas_certificate_free);
-  
+
   sep = strstr(buffer, "<|>");
   if (sep == NULL)
     return -1;
@@ -1740,7 +1739,7 @@ comm_parse_certificate (char* buffer, struct context* context)
   pubkey = strtok(NULL,"<|>");
 
   // Not enough tokens or incomplete public key
-  if(fpr == NULL || name == NULL || trust_level == NULL || pkey_length < 1 
+  if(fpr == NULL || name == NULL || trust_level == NULL || pkey_length < 1
                   || pubkey == NULL
      || strlen(pubkey)-2 != pkey_length )
     {
@@ -1754,14 +1753,18 @@ comm_parse_certificate (char* buffer, struct context* context)
     if (pos[0] == ';') pos[0] = '\n';
     pos++;
   }
-  
+
   // Make the "fingerprint"- key 16 chars long (it seems it sometimes is,
-  //  sometimes isnt)
+  // sometimes isnt)
   if (strlen (fpr) > 16)
     {
       fpr_short = fpr + (strlen(fpr)-16) ;
     }
 
+  // Public key field might contain a space before the actual data, skip it.
+  while (pubkey[0] == ' ')
+    pubkey++;
+
   // Create certificate
   openvas_certificate* cert = openvas_certificate_new ( estrdup(fpr),
                                                         estrdup(name),
@@ -1776,12 +1779,13 @@ comm_parse_certificate (char* buffer, struct context* context)
 
 
 /**
- * Request certificates used for NVTs signatures.
+ * @brief Request certificates used for NVTs signatures.
+ *
  * Certificates are then stored in the contexts hashtable signer_fp_certificates
  * where a fingerprint points to a certificate structure.
- * 
+ *
  * @param context The Context to use (e.g. a specific scope).
- * 
+ *
  * @return 0 on success; != 0 on error.
  */
 int
@@ -1793,7 +1797,7 @@ comm_get_certificates (struct context* context)
   
   buffer[0] = '\0';
   network_gets(context->socket, buffer, response_length);
-    
+
   // If certificate list starts
   if( strcmp(buffer, "SERVER <|> CERTIFICATES\n") == 0)
   {
