@@ -50,17 +50,13 @@ int comm_get_rules(struct context *);
 int comm_get_plugins(struct context *);
 
 int comm_send_preferences(struct context *);
-int comm_send_long_preferences(struct context *);
 int comm_send_rules(struct context *);
-void comm_get_preferences_errors(struct context*);
 
 harglst * comm_get_sessions();
 int comm_server_restores_sessions(struct context *);
 
 void comm_restore_session(struct context *, char*);
 
-int comm_plugin_upload(char*);
-
 int comm_get_dependencies(struct context*);
 
 int comm_parse_preference(struct context *, struct arglist *, struct arglist *,
