@@ -20,6 +20,8 @@
 
 #include "includes.h"
 #include "nessus_i18n.h"
+
+#include "file_utils.h"
 #include "nessus_plugin.h"
 #include "context.h"
 #include "preferences.h"
@@ -28,9 +30,15 @@
 #include "comm.h"
 #include "hash_table_file.h"
 #include "openvas_certificate_file.h"
+#include "openvas_lsc_user_deb.h"
+#include "openvas_lsc_user_makensis.h"
+#include "openvas_lsc_user_rpm.h"
+#include "openvas_lsc_target_prep.h"
 #include "openvas_ssh_login.h"
 #include "openvas_ssh_key_create.h"
 
+
+
 #ifdef USE_GTK
 #include <gtk/gtk.h>
 #endif /* USE_GTK */
@@ -143,12 +151,12 @@ context_force_plugin_prefs_redraw(struct context *context)
 void
 context_reset_plugins (struct context *context)
 {
-  nessus_plugin_free(context->plugins);
-  nessus_plugin_free(context->scanners);
+  nessus_plugin_free (context->plugins);
+  nessus_plugin_free (context->scanners);
   context->plugins = NULL;
   context->scanners = NULL;
-  efree(&context->plugins_md5sum);
-  context_reset_plugin_tree(context);
+  efree (&context->plugins_md5sum);
+  context_reset_plugin_tree (context);
 }
 
 /**
@@ -254,6 +262,7 @@ context_remove_child (struct context* context, struct context* child)
   *child_ptr = next;
 }
 
+
 /**
  * @brief Warns the user if a login is invalid (e.g. misses key file) and asks
  *        how to solve the situation.
@@ -270,45 +279,100 @@ verify_sshlogin_integrity (char* accountname, openvas_ssh_login* login,
                            GSList** removelist)
 {
   #ifdef USE_GTK
-  if (login && login->valid == FALSE)
+  // Check if something is missing
+  if (login)
     {
-      GtkWidget* dialog = gtk_message_dialog_new (NULL, 
-                            GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
-                            GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-                            _("SSH Login '%s' misses files.\nDelete this account and all information or recreate the files?"),
-                             accountname);
-      gtk_dialog_add_buttons (GTK_DIALOG(dialog), _("Delete Account"), 12,
-                                                  _("Recreate Files"), 13, NULL);
+      gint response;
+      // Following will be true e.g. if makensis but no .exe found.
+      gboolean rpm_missing = FALSE;
+      gboolean deb_missing = FALSE;
+      gboolean exe_missing = FALSE;
+      gchar* packpath;
 
-      gtk_widget_show_all (dialog);
+      // Find out if a package/installer is missing but its possible to recreate
+      if (openvas_lsc_user_rpm_generator_found())
+        {
+          packpath = openvas_lsc_user_rpm_filename (login->name);
+          if (!check_is_file (packpath))
+              rpm_missing = TRUE;
 
-      int response = gtk_dialog_run (GTK_DIALOG(dialog));
+          g_free (packpath);
 
-      if (response == 12) // "Delete"
-        {
-          (*removelist) = g_slist_prepend ((*removelist), g_strdup(accountname));
-        }
-      else if (response == 13) // "Create new"
-        {
-          openvas_ssh_login* login = g_hash_table_lookup (Global->sshkeys, accountname);
-          openvas_ssh_key_create_unlink_files (login);
-          if (openvas_ssh_key_create (login) == FALSE)
-            show_warning (_("Recreation of SSH login '%s' failed.\nCheck your console and remove or repair this login manually."), accountname);
-          else
-            show_info (_("Recreation of SSH login '%s' successful."), accountname);
-        }
-      else
-        {
-          // Seems that dialog (or main-gui) was simply closed, do nothing.
-          // Put notification into the log message area.
+          packpath = openvas_lsc_user_deb_filename (login->name);
+          if (openvas_lsc_user_deb_alien_found() && !check_is_file (packpath))
+              deb_missing = TRUE;
+          g_free (packpath);
         }
 
-      gtk_widget_destroy (dialog);
+      if (openvas_lsc_user_makensis_found())
+        {
+          packpath = openvas_lsc_user_makensis_filename (login->name);
+          if (!check_is_file (packpath))
+            exe_missing = TRUE;
+        }
+
+      // If some files are missing but can be recreated, let the user choose
+      if (rpm_missing || deb_missing || exe_missing || login->valid == FALSE)
+        {
+          GtkWidget* dialog = gtk_message_dialog_new (NULL, 
+                              GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
+                              GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
+                              _("SSH Login '%s' misses files.\nDelete this account and all information or recreate the files?"),
+                              accountname);
+          gtk_dialog_add_buttons (GTK_DIALOG(dialog), _("Delete Account"), 12,
+                                                      _("Recreate Files"), 13, NULL);
+
+          gtk_widget_show_all (dialog);
+
+          response = gtk_dialog_run (GTK_DIALOG(dialog));
+
+          if (response == 12) // "Delete"
+            {
+              (*removelist) = g_slist_prepend ((*removelist), g_strdup(accountname));
+            }
+          else if (response == 13) // "Create new"
+            {
+              openvas_ssh_login* login = g_hash_table_lookup (Global->sshkeys, accountname);
+              // Recreate keys
+              if (login->valid == FALSE)
+                {
+                  openvas_ssh_key_create_unlink_files (login);
+                  if (openvas_ssh_key_create (login) == FALSE)
+                    show_warning (_("Recreation of SSH login '%s' failed.\nCheck your console and remove or repair this login manually."), accountname);
+                  else
+                    show_info (_("Recreation of SSH login '%s' successful."), accountname);
+                }
+              // Recreate nsis installer
+              if (exe_missing == TRUE)
+                {
+                  packpath = openvas_lsc_user_makensis_filename (login->name);
+                  openvas_lsc_user_makensis (login, packpath);
+                  g_free (packpath);
+                }
+              // Recreate rpm package
+              if (rpm_missing == TRUE)
+                {
+                  packpath = openvas_lsc_user_rpm_filename (login->name);
+                  openvas_lsc_user_rpm_create (login, packpath);
+                  g_free (packpath);
+                }
+              // Recreate deb package
+              if (deb_missing == TRUE)
+                {
+                  packpath = openvas_lsc_user_deb_filename (login->name);
+                  openvas_lsc_user_deb (login, packpath);
+                  g_free (packpath);
+                }
+            }
+          else // Seems that dialog (or main-gui) was simply closed, do nothing.
+            ;
+          gtk_widget_destroy (dialog);
+        }
     }
   #else
-    if (login && login->valid == FALSE)
-      show_warning (_("SSH Login %s seems to miss files. (The GUI can help you to repair or delete it)"), login->name);
-  #endif
+  if (login && login->valid == FALSE)
+    show_warning (_("SSH Login %s seems to miss files. (The GUI can help you to repair or delete it)"), login->name);
+  #endif /* USE_GTK */
 }
 
 /**
@@ -338,12 +402,13 @@ context_pickup_sshkeys (struct context* context, const char* sshdir)
   // Check if all logins are valid (files exist).
   g_hash_table_foreach (loginfos, (GHFunc) verify_sshlogin_integrity, &invalidkeylist);
 
-  // Remove the keys that the user wanted to destroy
+  // Remove the keys and other files that the user wanted to destroy
   if (invalidkeylist != NULL)
     {
       listit = invalidkeylist;
       while (listit != NULL)
         {
+          openvas_lsc_target_prep_remove (g_hash_table_lookup (Global->sshkeys, listit->data));
           openvas_ssh_key_create_undo (g_hash_table_lookup (Global->sshkeys, listit->data));
           free (listit->data);
           listit = listit->next;
@@ -425,7 +490,8 @@ context_collect_recurse (struct context *context, const char* dir)
 /**
  * @brief Recursively collects contexts found in and under the nessus_dir.
  * 
- * @param context Is queried for the nessus_dir preference.
+ * @param context Is queried for the nessus_dir preference, found contexts are
+ *                added to it.
  */
 void
 context_collect (struct context *context)
@@ -662,61 +728,35 @@ context_new (struct context* parent, const char* name, const char* filename)
 }
 
 
-void
-context_delete_directory (const char* dir)
-{
-  DIR *odir;
-  struct dirent *dirent;
-
-  if((odir = opendir(dir)))
-  {
-    while((dirent = readdir(odir)))
-    {
-      const char *file = dirent->d_name;
-      char *path;
-
-      if(!strcmp(file, ".") || !strcmp(file, ".."))
-	continue;
-
-      path = g_build_filename(dir, file, NULL);
-
-      if(check_is_dir(path))
-	context_delete_directory(path);
-      else
-	if(unlink(path))
-	  show_error_and_wait(_("File %s couldn't be deleted: %s."),
-		path, strerror(errno));
-      g_free(path);
-    }
-    closedir(odir);
-    if(rmdir(dir))
-      show_error_and_wait(_("Directory %s couldn't be deleted: %s."),
-	    dir, strerror(errno));
-  }
-}
-
+/**
+ * @brief Removes a Context and its children, including the representation on
+ * @brief disc.
+ * 
+ * @param context The context to remove.
+ */
 void
 context_delete (struct context *context)
 {
   while(context->children)
     context_delete(context->children);
 
-  arg_free_all(context->prefs);
+  arg_free_all (context->prefs);
   context->prefs = NULL;
-  context_reset_plugins(context);
-  arg_free_all(context->dependencies);
+  context_reset_plugins (context);
+  arg_free_all (context->dependencies);
   context->dependencies = NULL;
-  context_delete_directory(context->dir);
-  if(context->signer_fp_certificates)
-    g_hash_table_destroy(context->signer_fp_certificates);
+  if (file_utils_rmdir_rf (context->dir) == -1)
+    show_error (_("Error removing files or directories\n(possible cause of error: '%s')"), strerror(errno));
+  if (context->signer_fp_certificates)
+    g_hash_table_destroy (context->signer_fp_certificates);
   if (context->map_target_sshlogin)
     g_hash_table_destroy (context->map_target_sshlogin);
-  context_remove_child(context->parent, context);
-  if(context == Context)
-  {
-    show_error(_("context_delete() deleted the current context."));
-    Context = NULL;
-  }
+  context_remove_child (context->parent, context);
+  if (context == Context)
+    {
+      show_error(_("context_delete() deleted the current context."));
+      Context = NULL;
+    }
 }
 
 /**
@@ -889,13 +929,14 @@ context_sync_plugin_prefs (struct context* context)
  *
  * FIXME: handle symbolic links
  * @return 1 if file exists, 0 otherwise.
+ * @TODO Move to other module.
  */
 int
 check_exists (const char *name)
 {
   struct stat sb;
 
-  if(stat(name, &sb))
+  if (stat (name, &sb))
     return 0;
   else
     return 1;
@@ -905,16 +946,17 @@ check_exists (const char *name)
  * Replacement for g_file_test which is unreliable on windows
  * if nessus and gtk are compiled with a different libc.
  * FIXME: handle symbolic links
+ * @TODO Move to other module.
  */
 int
 check_is_file (const char *name)
 {
   struct stat sb;
 
-  if(stat(name, &sb))
+  if (stat (name, &sb))
     return 0;
   else
-    return(S_ISREG(sb.st_mode));
+    return (S_ISREG(sb.st_mode));
 }
 
 /**
@@ -923,14 +965,15 @@ check_is_file (const char *name)
  *
  * FIXME: handle symbolic links
  * @return 0 if parameter is directory, 1 if it is not (or does not exist).
+ * @TODO Move to other module.
  */
 int
 check_is_dir (const char* name)
 {
   struct stat sb;
 
-  if(stat(name, &sb))
+  if (stat (name, &sb))
     return 0;
   else
-    return(S_ISDIR(sb.st_mode));
+    return (S_ISDIR(sb.st_mode));
 }
