@@ -25,7 +25,7 @@
  * file, but you are not obligated to do so.  If you do not wish to
  * do so, delete this exception statement from your version.
  */
- 
+
 #include <includes.h>
 #include "nessus_i18n.h"
 #include "nessus_plugin.h"
@@ -41,9 +41,8 @@
 #include <gtk/gtk.h>
 #include "filter.h"
 
-
-
-	
+/* Default values, filter on name only. Memorize, so that when dialog is opened
+   the same values are selected. */
 static int filter_on_name = 1;
 static int filter_on_description = 0;
 static int filter_on_summary = 0;
@@ -61,8 +60,8 @@ build_filter_dlog()
   GtkWindow * window = GTK_WINDOW(arg_get_value(MainDialog, "WINDOW"));
   GtkWidget * dialog;
   GtkWidget * label, *sep, * button, *entry;
- GtkWidget * box, *hbox, *frame,*vbox;
- struct arglist * ctrls = emalloc(sizeof(struct arglist));
+  GtkWidget * box, *hbox, *frame,*vbox;
+  struct arglist * ctrls = emalloc(sizeof(struct arglist));
 
   dialog = gtk_dialog_new_with_buttons(_("Filter plugins..."), window,
              GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -86,26 +85,26 @@ build_filter_dlog()
  sep = gtk_hseparator_new();
  gtk_box_pack_start(GTK_BOX(box), sep, FALSE, FALSE, 0);
  gtk_widget_show(sep);
- 
+
  hbox = gtk_hbox_new(FALSE, FALSE);
  gtk_box_pack_start(GTK_BOX(box), hbox, FALSE, FALSE, 3);
  label = gtk_label_new(_("Pattern:"));
  gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 6);
  gtk_widget_show(label);
- 
+
  entry = gtk_entry_new();
- arg_add_value(ctrls,"ENTRY", ARG_PTR, -1, entry);
+ arg_add_value(ctrls, "ENTRY", ARG_PTR, -1, entry);
  gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, FALSE, 6);
  gtk_widget_show(entry);
  gtk_widget_show(hbox);
- 
+
  frame = gtk_frame_new(_("Filter on:"));
  gtk_box_pack_start(GTK_BOX(box), frame, FALSE, FALSE, 6);
  vbox = gtk_vbox_new(FALSE, FALSE);
  gtk_container_border_width(GTK_CONTAINER(frame), 6);
  gtk_container_add(GTK_CONTAINER(frame), vbox);
  gtk_widget_show(vbox);
- 
+
  /*--------------------------------------------*/
  button = gtk_check_button_new_with_label(_("Name"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
@@ -154,35 +153,34 @@ build_filter_dlog()
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_BID", ARG_PTR, -1, button);
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), filter_on_bid);
- 
+
   /*--------------------------------------------*/
  button = gtk_check_button_new_with_label(_("XREF"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_XREF", ARG_PTR, -1, button);
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), filter_on_xref);
- 
- 
+
  gtk_widget_show(frame);
 
  gtk_widget_show(dialog);
  return ctrls;
-} 
- 
- 
-int ask_filter(filter)
- struct plugin_filter * filter;
-{
- struct arglist * ctrls = build_filter_dlog();
- GtkWidget * dialog;
- char * pattern = NULL;
+}
 
-  dialog = arg_get_value(ctrls,"WINDOW");
+
+int
+ask_filter (struct plugin_filter * filter)
+{
+  struct arglist * ctrls = build_filter_dlog();
+  GtkWidget * dialog;
+  char * pattern = NULL;
+
+  dialog = arg_get_value (ctrls, "WINDOW");
 
   switch (gtk_dialog_run(GTK_DIALOG(dialog)))
   {
     case GTK_RESPONSE_OK:
-      pattern = (char*)gtk_entry_get_text(GTK_ENTRY(
+      pattern = (char*) gtk_entry_get_text(GTK_ENTRY(
         arg_get_value(ctrls,"ENTRY")));
       filter_on_name = GTK_TOGGLE_BUTTON(
         arg_get_value(ctrls, "FILTER_NAME"))->active;
@@ -210,7 +208,7 @@ int ask_filter(filter)
   if (!pattern)
     filter->pattern = NULL;
   else
-    filter->pattern = estrdup(pattern);
+    filter->pattern = estrdup (pattern);
 
  filter->filter_on_name = filter_on_name;
  filter->filter_on_description = filter_on_description;
@@ -222,23 +220,10 @@ int ask_filter(filter)
  filter->filter_on_bid = filter_on_bid;
  filter->filter_on_xref = filter_on_xref;
 
- gtk_widget_destroy(dialog);
- arg_free(ctrls);
+ gtk_widget_destroy (dialog);
+ arg_free (ctrls);
  return 0;
 }
-
-#else
-/*
- * Not used yet
- */
-char *
-ask_filter()
-{
- char * ret = emalloc(1024);
- printf(_("Enter a new filter : "));
- fgets(ret, 1023, stdin);
- return ret;
-}
 #endif /* defined(USE_GTK) */
 
 #ifndef NS
@@ -247,101 +232,110 @@ ask_filter()
 
 
 #ifdef USE_GTK
-static int match(str, pat)
- char * str, * pat;
+/**
+ * @brief Compares pattern against string.
+ * 
+ * @param str The string to compare against the pattern.
+ * @param pat The pattern (regular expression).
+ * 
+ * @return -1 if pat is not an acceptable pattern.
+ */
+static int
+match (char * str, char * pat)
 {
   regex_t re;
   regmatch_t subs[NS];
 
   re_set_syntax(RE_SYNTAX_POSIX_EGREP);
   if(regcomp(&re, pat, REG_EXTENDED|REG_ICASE))
-  {
-   show_error(_("Invalid regular expression"));
-   bzero(pat, strlen(pat));
-   return -1;
-  }
+    {
+      show_error(_("Invalid regular expression"));
+      bzero(pat, strlen(pat));
+      return -1;
+    }
   if(regexec(&re, str, (size_t)NS, subs, 0) == 0)
-  {
-    regfree(&re);
-    return 0;
-  }
+    {
+      regfree(&re);
+      return 0;
+    }
    regfree(&re);
    return 1;
 }
 #endif
 
-int 
-filter_plugin(filter, plugin)
- struct plugin_filter *filter;
- struct nessus_plugin * plugin;
+int
+filter_plugin (struct plugin_filter *filter, struct nessus_plugin * plugin)
 {
- int ret = 0; /* Don't filter it */
- int retval = 0;
- 
+  int ret    = 0; /* Don't filter it */
+  int retval = 0;
+
 #ifdef USE_GTK
- char * name = plugin->name;
- char * description = nessus_plugin_get_description(plugin);
- char * summary = plugin->summary;
- char * author =  plugin->copyright;
- char * oid = plugin->oid;
- char * category =  plugin->category;
- char * cve = 	  plugin->cve;
- char * bid = 	  plugin->bid;
- char * xref = 	  plugin->xrefs;
- 
- if(!filter->pattern || !strlen(filter->pattern))
-	goto  ret;
- 
- 
- if(filter->filter_on_name)
-	 {
-	  ret = match(name, filter->pattern);
-	  if(!ret) goto ret;
-	 }
- if(filter->filter_on_description)
-	{
-	  ret = match(description, filter->pattern);
-	  if(!ret) goto ret;
-	}
- if(filter->filter_on_summary)
- 	{
-	 ret = match(summary, filter->pattern);
-	 if(!ret) goto ret;
-	 }
- if(filter->filter_on_author)
-	 {
-	  ret = match(author, filter->pattern);
-	  if(!ret)goto ret;
-	 }
- if(filter->filter_on_category)
-	 {
-	  ret = match(category, filter->pattern);
-	  if(!ret)goto ret;
-	 }
-	 
- if( filter->filter_on_cve  )
- 	{
-	 if (cve != NULL ) ret = match(cve, filter->pattern);
-	 else ret = 0;
-	 if(!ret)goto ret;
-	}
-	
- if( filter->filter_on_bid )
- 	{
-	 if (bid != NULL ) ret = match(bid, filter->pattern);
-	 else ret = 0;
-	 
-	 if(!ret)goto ret;
-	}		
-	
- if( filter->filter_on_xref ) 
- 	{
-	 if(xref != NULL ) ret = match(xref, filter->pattern);
-	 else ret = 0;
-	 
-	 if (!ret) goto ret;
-	 }	 
- if(filter->filter_on_id)ret= match(oid, filter->pattern);
+  char * name        = plugin->name;
+  char * description = nessus_plugin_get_description(plugin);
+  char * summary     = plugin->summary;
+  char * author      = plugin->copyright;
+  char * oid         = plugin->oid;
+  char * category    = plugin->category;
+  char * cve         = plugin->cve;
+  char * bid         = plugin->bid;
+  char * xref        = plugin->xrefs;
+
+  if (!filter->pattern || !strlen(filter->pattern))
+    goto ret;
+
+  if (filter->filter_on_name)
+    {
+      ret = match (name, filter->pattern);
+      if(!ret) goto ret;
+    }
+
+  if (filter->filter_on_description)
+    {
+      ret = match (description, filter->pattern);
+      if(!ret) goto ret;
+    }
+
+  if (filter->filter_on_summary)
+    {
+      ret = match (summary, filter->pattern);
+      if (!ret) goto ret;
+    }
+
+  if (filter->filter_on_author)
+    {
+      ret = match (author, filter->pattern);
+      if (!ret) goto ret;
+    }
+
+  if (filter->filter_on_category)
+    {
+      ret = match (category, filter->pattern);
+      if (!ret) goto ret;
+    }
+
+  if (filter->filter_on_cve)
+    {
+      if (cve != NULL ) ret = match (cve, filter->pattern);
+      else ret = 0;
+      if (!ret)goto ret;
+    }
+
+  if (filter->filter_on_bid)
+    {
+      if (bid != NULL ) ret = match (bid, filter->pattern);
+      else ret = 0;
+      if (!ret) goto ret;
+    }
+
+  if (filter->filter_on_xref)
+    {
+      if (xref != NULL ) ret = match (xref, filter->pattern);
+      else ret = 0;
+      if (!ret) goto ret;
+    }
+
+ if (filter->filter_on_id)
+   ret = match (oid, filter->pattern);
 
  retval = ret;
 
@@ -349,6 +343,4 @@ ret:
 #endif
 
   return retval;
-
 }
-
