@@ -77,7 +77,11 @@
 #include "error_dlg.h"
 #include "preferences.h"
 #include "html_output.h"
+#include "backend.h"
 
+/* Created from backend_convert, when a severity_filter is active, gives the
+   mapping matrix. */
+extern int sev_mapping_matrix[6][6];
 
 static void insert_img(FILE *, char*);
 
@@ -823,7 +827,47 @@ create_host_report(struct arglist * host)
  chdir("..");
  return name;
 }
- 
+
+/**
+ * @brief Prints severity mapping matrix if severity mapping is enabled
+ * @brief for Current Context, otherwise does nothing.
+ * 
+ * @param file File to write to.
+ */
+static void
+print_severity_map (FILE* file)
+{
+  int r = 0;
+  int c = 0;
+
+  if (Context->is_severity_mapped == FALSE)
+    return;
+
+  fprintf (file, "<br><br><hr>\n");
+  fprintf (file, "<h2>Severity Filter Statistics :</h2>\n");
+  fprintf (file, "<table><tr><th>From/To</th>\n");
+
+  // Horizontal captions
+  for (c = 0; c < 6; c++)
+    fprintf (file, "\t<th width=\"14%%\">%s</th>\n", priority_idx_to_str(c));
+  fprintf (file, "</tr>\n");
+
+  // Rows
+  for (r = 0; r < 6; r++)
+    {
+      fprintf(file, "<tr>\n");
+      fprintf(file, "<th>%s</th>", priority_idx_to_str(r));
+
+      for (c = 0; c < 6; c++)
+        {
+          fprintf(file, "<td>%d</td>\n", sev_mapping_matrix[r][c]);
+        }
+      fprintf(file, "</tr>\n");
+    }
+
+  fprintf (file, "</table><br><br>");
+}
+
 /*----------------------------------------------------------------------------
 
 		              Make the global index
@@ -1138,6 +1182,10 @@ static int html_make_index(hosts)
     }
     fprintf(f, "</table></center>\n");
     fprintf(f, "</ul>\n");
+    
+    // Print severity mapping if activated
+    print_severity_map (f);
+    
     /*
      * Appendix
      */
