@@ -27,6 +27,7 @@
  */
  
 #include <includes.h>
+#include "backend.h"
 #include "report.h"
 #include "report_utils.h"
 #include "nessus_plugin.h"
@@ -38,6 +39,9 @@
 #define CATEGORY_D 3
 #define CATEGORY_E 4
 
+/* Created from backend_convert, when a severity_filter is active, gives the
+   mapping matrix. */
+extern int sev_mapping_matrix[6][6];
 
 static void latex_print_header(FILE *);
 static void latex_print_footer(FILE *);
@@ -379,7 +383,7 @@ void latex_print_host_ports_problems(FILE * f, struct arglist * port)
    }
    if(note)
    {
-    fprintf(f, "Security note :\\\\\n");
+    fprintf(f, "Security notes :\\\\\n");
     fprintf(f, "\\begin{itemize}\n");
     while(note->next)
     {
@@ -394,7 +398,7 @@ void latex_print_host_ports_problems(FILE * f, struct arglist * port)
    }
    if(false_positive)
    {
-    fprintf(f, "False_positive :\\\\\n");
+    fprintf(f, "False positives :\\\\\n");
     fprintf(f, "\\begin{itemize}\n");
     while(false_positive->next)
     {
@@ -528,6 +532,45 @@ void latex_appendix(FILE *f)
   }
  }
 }
+
+/**
+ * @brief Prints a table with the mapping matrix of an applied severity filter.
+ * @brief If the current Contexts is_severity_mapped flag is not set, does
+ * @brief nothing.
+ */
+void
+latex_severity_mapping_matrix (FILE* f)
+{
+  if (Context->is_severity_mapped == FALSE)
+    return;
+
+  int r = 0;
+  int c = 0;
+  fprintf(f, "\\newpage\n");
+  fprintf(f, "\\section{Severity mapping statistics}\n");
+  fprintf(f, "A severity filter was applied during report export. See the numbers of applied overrides below.\\\\\n\\\\\n");
+  fprintf (f,"\\label{severity_mapping_matrix}\n");
+  fprintf (f, "\\begin{tabular}{|p{2cm}|p{1.5cm}|p{1.5cm}|p{1.5cm}|p{1.5cm}|p{1.5cm}|p{1.5cm}|}\n");
+  fprintf (f, "\\hline\n");
+  // Print Headings
+  fprintf (f, "From/To & %s & %s & %s & %s & %s & %s \\\\ \n\\hline\n",
+               priority_idx_to_str (0), priority_idx_to_str (1),
+               priority_idx_to_str (2), priority_idx_to_str (3),
+               priority_idx_to_str (4), priority_idx_to_str (5) );
+
+  for (r = 0; r < 6; r++)
+    {
+      fprintf (f, "%s ", priority_idx_to_str (r));
+      for (c = 0; c < 6; c++)
+        {
+          fprintf (f, "& %d ", sev_mapping_matrix[r][c]);
+        }
+      fprintf (f, "\\\\ \\hline\n");
+    }
+
+  //fprintf (f, "\\hline\n");
+  fprintf (f, "\\end{tabular}\n");
+}
  				
 int arglist_to_latex(struct arglist * list, char * filename)
 {
@@ -576,6 +619,7 @@ int arglist_to_latex(struct arglist * list, char * filename)
   
   latex_print_hosts(f, list);
   latex_conclusion(f);
+  latex_severity_mapping_matrix (f);
   latex_appendix(f);
   latex_print_footer(f);		
   fclose(f);
