@@ -66,13 +66,12 @@
 
 static void monitor_input_callback(struct arglist *);
 static void monitor_add_host(struct arglist *, char *, int);
-static void monitor_stop_test(GtkWidget *, struct context *);
 static void monitor_list_update(struct arglist *, char *, int);
 static int monitor_stop_whole_test_destroy(void*, void*, struct arglist *);
 static int monitor_stop_whole_test(GtkWidget * , struct arglist *);
 
 
-static int 
+static int
 is_server_present (int soc)
 {
 	fd_set  rd;
@@ -99,40 +98,41 @@ is_server_present (int soc)
 
 
 /**
- * Function called when the UI is idle, which checks
- * whether the server sent us anything. We use this rather
- * than the traditional gdk input watcher, because it
- * works under Win32
+ * @brief Function called when the UI is idle, which checks whether the server
+ * @brief sent us anything.
+ * 
+ * We use this rather than the traditional gdk input watcher, because it
+ * works under Win32.
  */
 static int
-idle_socket(struct arglist * ctrls)
+idle_socket (struct arglist * ctrls)
 {
   fd_set rd;
-  struct timeval tv = {0,100};
+  struct timeval tv = {0, 100};
   int n, soc;
   struct context * context = arg_get_value(ctrls, "CONTEXT");
-  if ( context == NULL ) return FALSE;
+  if (context == NULL) return FALSE;
 
   if(context->socket < 0)
     {
       fprintf(stderr, "idle_socket: context->socket=%d\n", context->socket);
       return FALSE;
     }
-  if ( stream_pending(context->socket) )
-  {
-   monitor_input_callback(ctrls);
-   return TRUE;
-  }
+  if (stream_pending(context->socket))
+    {
+      monitor_input_callback(ctrls);
+      return TRUE;
+    }
   soc = nessus_get_socket_from_connection(context->socket);
-  if((soc < 0) || (soc >= FD_SETSIZE))
-  {
-   fprintf(stderr, _("idle_server: soc(%d) out of range\n"), soc);
-   return -1;
-  }
+  if ((soc < 0) || (soc >= FD_SETSIZE))
+    {
+      fprintf(stderr, _("idle_server: soc(%d) out of range\n"), soc);
+      return -1;
+    }
   FD_ZERO(&rd);
   FD_SET(soc, &rd);
   n = select(soc+1, &rd, NULL, NULL, &tv);
-  if(FD_ISSET(soc, &rd)&& (n > 0))
+  if (FD_ISSET(soc, &rd)&& (n > 0))
     monitor_input_callback(ctrls);
   return TRUE;
 }
@@ -179,20 +179,17 @@ monitor_dialog_setup (char * victim, struct context * context)
   int backend = backend_init(NULL);
 
   /* Could not create a backend */
-  if( backend < 0 )
+  if (backend < 0)
     return;
 
   arg_add_value(ctrls, "MONITOR_BACKEND", ARG_INT, -1, GSIZE_TO_POINTER(backend));
   arg_add_value(ctrls, "PARENT", ARG_PTR, -1, parent);
   arg_add_value(ctrls, "CONTEXT", ARG_PTR, -1, context);
   context->action = CONTEXT_SCANNING;
-  prefs_context_update(context);
+  prefs_context_update (context);
 
   w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  if (GTK_CHECK_VERSION(2,6,0)) /* TreeView since GTK 2.6 */
-    gtk_window_set_default_size(GTK_WINDOW(w), 320,200);
-  else
-    gtk_window_set_default_size(GTK_WINDOW(w), 640,480);
+  gtk_window_set_default_size(GTK_WINDOW(w), 320,200);
 
   /* TODO make the window non-modal
    * This can be done when context is kept for all called functions */
@@ -203,25 +200,25 @@ monitor_dialog_setup (char * victim, struct context * context)
 #endif
 
   gtk_widget_realize(w);
-  g_signal_connect(GTK_OBJECT(w), "delete_event",
-		     (GtkSignalFunc)monitor_stop_whole_test_destroy,ctrls);
-		     
-  host_name = prefs_get_string(context, "nessusd_host");
-  if(host_name)window_title = emalloc(strlen(host_name) + 255);
+  g_signal_connect (GTK_OBJECT(w), "delete_event",
+                   (GtkSignalFunc) monitor_stop_whole_test_destroy, ctrls);
+
+  host_name = prefs_get_string (context, "nessusd_host");
+  if(host_name) window_title = emalloc(strlen(host_name) + 255);
   else window_title = emalloc(255);
   sprintf(window_title, _("Scanning network from %s"),
-          host_name?host_name:_("some host"));
-  gtk_window_set_title(GTK_WINDOW(w), window_title);
-  efree(&window_title);
-  gtk_container_border_width(GTK_CONTAINER(w), 10);
-  arg_add_value(ctrls, "WINDOW", ARG_PTR, -1, w);
-  gtk_widget_show(w);
-  
+          host_name ? host_name:_("some host"));
+// window_title = g_strdup_printf(_("Scanning network from %s"), host_name ? host_name : _("some host"));
+  gtk_window_set_title (GTK_WINDOW(w), window_title);
+  efree (&window_title);
+  gtk_container_border_width (GTK_CONTAINER(w), 10);
+  arg_add_value (ctrls, "WINDOW", ARG_PTR, -1, w);
+  gtk_widget_show (w);
+
   box = gtk_vbox_new(FALSE,10);
   gtk_container_add(GTK_CONTAINER(w), box);
   gtk_widget_show(box);
-  
-  if (GTK_CHECK_VERSION(2,6,0)) { /* TreeView since GTK 2.6 */
+
     GtkListStore * store;
     GtkCellRenderer   * renderer;
     GtkTreeViewColumn * column;
@@ -230,7 +227,7 @@ monitor_dialog_setup (char * victim, struct context * context)
     gtk_container_border_width(GTK_CONTAINER (scrolled_window), 10);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW (scrolled_window),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-				
+
     gtk_container_border_width(GTK_CONTAINER(scrolled_window), 10);  
     gtk_box_pack_start(GTK_BOX(box), scrolled_window, TRUE, TRUE, 0);
 
@@ -275,30 +272,13 @@ monitor_dialog_setup (char * victim, struct context * context)
                                           w);
     gtk_widget_show(w);
     gtk_widget_show (scrolled_window);
-  } else { /* old style for GTK < 2.6 */
-    scrolled_window = gtk_scrolled_window_new(NULL, NULL);
-    gtk_container_border_width(GTK_CONTAINER (scrolled_window), 10);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW (scrolled_window),
-                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-    gtk_container_border_width(GTK_CONTAINER(scrolled_window), 10);  
-    gtk_box_pack_start(GTK_BOX(box), scrolled_window, TRUE, TRUE, 0);
+  tag = gtk_idle_add ((GtkFunction)idle_socket, ctrls);
 
-    w = gtk_list_new();
-    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window),
-                                          w);
-    gtk_widget_show(w);
-    gtk_widget_show (scrolled_window);
-    arg_add_value(ctrls, "LIST", ARG_PTR, -1, w);
-  }
-
-  
-  tag = gtk_idle_add((GtkFunction)idle_socket, ctrls);
-  
   arg_add_value(ctrls, "TAG", ARG_INT, sizeof(gpointer), GSIZE_TO_POINTER(tag));
   w = gtk_button_new_with_label(_("Stop the whole test"));
-  g_signal_connect(GTK_OBJECT(w), "clicked",
-		     (GtkSignalFunc)monitor_stop_whole_test,ctrls);
+  g_signal_connect (GTK_OBJECT(w), "clicked",
+                   (GtkSignalFunc)monitor_stop_whole_test,ctrls);
   gtk_box_pack_start(GTK_BOX(box), w, FALSE, TRUE, 0);
   gtk_widget_show(w);
   if(!attack_host(victim, context))
@@ -320,102 +300,63 @@ monitor_dialog_setup (char * victim, struct context * context)
 static void
 monitor_list_update (struct arglist * ctrls, char * msg, int short_status)
 {
- char * hostname;
- char * action;
- char* current = NULL;
- int max;
- gfloat gmax;
- gfloat gcurrent;
- GList * dlist;
- GtkObject * item;
- GtkWidget * gtkw;
- char * list_hostname;
- int flag = 0;
+  char * hostname;
+  char * action;
+  char* current = NULL;
+  int max;
+  char * list_hostname;
+  int flag = 0;
 
- if(!short_status)
-  parse_nessusd_status(msg, &hostname, &action, &current, &max);
- else
-  parse_nessusd_short_status(msg, &hostname, &action, &current, &max);
+  if (!short_status)
+    parse_nessusd_status (msg, &hostname, &action, &current, &max);
+  else
+    parse_nessusd_short_status (msg, &hostname, &action, &current, &max);
 
-  if (GTK_CHECK_VERSION(2,6,0)) { /* TreeView since GTK 2.6 */
-    GtkListStore * store = arg_get_value(ctrls, "MON_STORE");
-    GtkTreeIter iter;
-    int f;
-    if (max == 0) {
-      f = 100;
-    } else {
-      f = (atoi(current) / max) * 100;
-      if(f>=100)f=100;
-      if(f<=0)f=0;
-    }
-
-    if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter)) {
-      do {
-        gtk_tree_model_get (GTK_TREE_MODEL(store), &iter,
-          COL_HOSTNAME, &list_hostname, -1);
-        if(!list_hostname){
-          fprintf(stderr, _("Error ! Null hostname in the list\n"));
-          return;
-        }
-        if (!strcmp(list_hostname, hostname)) {
-          if( strcmp(action, "portscan") == 0 )
-            gtk_list_store_set(store, &iter, COL_PORTSCAN, f, -1);
-          else
-            gtk_list_store_set(store, &iter, COL_CHECKS, f, -1);
-          flag = 1;
-          break;
-        }
-      } while (gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter));
-    }
-  } else { /* old style for GTK < 2.6 */
-    gtkw = arg_get_value(ctrls, "LIST");
-    dlist = GTK_LIST(gtkw)->children;
-    while(dlist && !flag)
+  GtkListStore * store = arg_get_value(ctrls, "MON_STORE");
+  GtkTreeIter iter;
+  int f;
+  if (max == 0)
     {
-      item = GTK_OBJECT(dlist->data);
-      list_hostname = gtk_object_get_data(item, "hostname");
-      if(!list_hostname){
-        fprintf(stderr, _("Error ! Null hostname in the list\n"));
-        /*exit(1);*/
-        return;
-      }
-      if(!strcmp(list_hostname, hostname))
-      {
-        GtkWidget * progress_bar;
-        gfloat f;
-   
-        gmax = max;
-	if (gmax == 0) {
-          f = 1.0;
-        } else {
-          gcurrent = atoi(current);
-          f = (gcurrent/gmax);
-          if(f>=1.0)f=1.0;
-          if(f<=0.0)f=0.0;
-        }
-
-        if( strcmp(action, "portscan") == 0 )
-          progress_bar = gtk_object_get_data(item, "progress_bar_portscan");
-        else
-          progress_bar = gtk_object_get_data(item, "progress_bar_attack");
-
-        gtk_progress_bar_update (GTK_PROGRESS_BAR(progress_bar), f);
-
-        flag = 1;
-      }
-    dlist = dlist->next;
+      f = 100;
     }
+  else
+    {
+      f = (atoi(current) / (float)max) * 100;
+      if (f >= 100) f=100;
+      if (f <= 0) f=0;
+    }
+
+  if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter)) {
+    do
+      {
+        gtk_tree_model_get (GTK_TREE_MODEL(store), &iter,
+                            COL_HOSTNAME, &list_hostname, -1);
+        if (!list_hostname)
+          {
+            fprintf(stderr, _("Error ! Null hostname in the list\n"));
+            return;
+          }
+        if (!strcmp(list_hostname, hostname))
+          {
+            if (strcmp(action, "portscan") == 0)
+              gtk_list_store_set (store, &iter, COL_PORTSCAN, f, -1);
+            else
+              gtk_list_store_set (store, &iter, COL_CHECKS, f, -1);
+            flag = 1;
+            break;
+          }
+      } while (gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter));
   }
 
  if(!flag)
- {
- /* the host was not found, we must add one... */
- monitor_add_host(ctrls, estrdup(hostname), atoi(current));
- }
- 
- efree(&hostname);
- efree(&action);
- if(current)efree(&current);
+  {
+    /* the host was not found, we must add one... */
+    monitor_add_host (ctrls, estrdup(hostname), atoi(current));
+  }
+
+ efree (&hostname);
+ efree (&action);
+ if (current) efree (&current);
 }
 
 /*
@@ -424,7 +365,6 @@ monitor_list_update (struct arglist * ctrls, char * msg, int short_status)
 static void
 monitor_remove_host (struct arglist * ctrls, char * host)
 {
-  if (GTK_CHECK_VERSION(2,6,0)) { /* TreeView since GTK 2.6 */
     GtkListStore * store = arg_get_value(ctrls, "MON_STORE");
     GtkTreeIter iter;
     char * list_hostname;
@@ -439,38 +379,15 @@ monitor_remove_host (struct arglist * ctrls, char * host)
         }
       } while (gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter));
     }
-  } else { /* old style for GTK < 2.6 */
-    GtkWidget * item;
-    GList * list = NULL;
-    item =  gtk_object_get_data(GTK_OBJECT(arg_get_value(ctrls, "LIST")),host);
- 
-    if(!item){
-      /*
-       * If this happens, then it's very likely that the server
-       * thinks the communication has been cut between the client
-       * and itself. Which is not a good thing.
-       */
-      return;
-    }
- 
-    if(item != (void*)-1)
-    {
-      list = g_list_append(list, item);
-      gtk_list_remove_items(GTK_LIST(arg_get_value(ctrls, "LIST")), list);
-      gtk_object_remove_data(GTK_OBJECT(arg_get_value(ctrls, "LIST")), host);
-      g_list_free(list);
-    }
-  }
 }
 
 
 /**
  * @brief Adds a new hostname and progress bar in the monitor window.
  */
-void 
+void
 monitor_add_host (struct arglist * ctrls, char * hostname, int port)
 {
-  if (GTK_CHECK_VERSION(2,6,0)) { /* TreeView since GTK 2.6 */
     GtkListStore * store = arg_get_value(ctrls, "MON_STORE");
     GtkTreeIter iter;
     GdkPixbuf *pixbuf = gdk_pixbuf_new_from_xpm_data(
@@ -483,119 +400,7 @@ monitor_add_host (struct arglist * ctrls, char * hostname, int port)
       COL_PORTSCAN, 0,
       COL_CHECKS, 0,
       -1);
-  } else { /* old style for GTK < 2.6 */
- GtkWidget * progress_bar_portscan;
- GtkWidget * progress_bar_attack;
- GtkWidget * table;
- GtkWidget * label;
- GtkWidget * item;
- GtkWidget * button;
- GtkWidget * separator;
- GtkWidget * box, * hbox;
- GdkPixbuf *pixbuf;
- GtkWidget *img;
- GList * dlist;
- struct context * context = arg_get_value(ctrls, "CONTEXT");
-
- item = gtk_list_item_new();
- dlist = NULL;
- table = gtk_table_new(4, 3, FALSE);
- gtk_table_set_col_spacings(GTK_TABLE(table), 15);
- gtk_table_set_row_spacings(GTK_TABLE(table),  5);
- 
- gtk_container_add(GTK_CONTAINER(item), table);
- 
- hbox = gtk_hbox_new(FALSE,0);
- gtk_widget_show(hbox);
- 
- gtk_table_attach_defaults(GTK_TABLE(table), hbox, 0,1,0,3); 
- 
- 
- /*
-  * Host name
-  */
- box = gtk_vbox_new(TRUE,0);
- gtk_widget_show(box);
- gtk_box_pack_start(GTK_BOX(hbox), box, FALSE, FALSE, 0);
- if(F_show_pixmaps)
- {
-  pixbuf = gdk_pixbuf_new_from_xpm_data((const char **)computer_xpm);
-  img = gtk_image_new_from_pixbuf(pixbuf);
-
-  gtk_box_pack_start(GTK_BOX(box), img, FALSE, FALSE, 0);
-  gtk_widget_show(img);
- }
- label = gtk_label_new(hostname);
- gtk_object_set_data(GTK_OBJECT(item), "label", label);
- gtk_widget_set_usize(label, 150, 15);
- gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 0);
- gtk_widget_show(label);
- 
- /*
-  * Portscan, Attack and Plugin labels
-  */
- box = gtk_vbox_new(TRUE, 0);
- gtk_widget_show(box);
- gtk_box_pack_end(GTK_BOX(hbox), box, FALSE, FALSE, 0);
- 
- label = gtk_label_new(_("Portscan:"));
- gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 0);
- gtk_widget_show(label);
- 
- label = gtk_label_new(_("Checks:"));
- gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 0);
- gtk_widget_show(label);
- 
- /*
-  *  Progress bars
-  */
- box = gtk_vbox_new(FALSE,0);
- gtk_table_attach_defaults(GTK_TABLE(table), box, 1,2,0,3); 
-  gtk_widget_show(box);
- progress_bar_portscan = gtk_progress_bar_new();
- /*
- gtk_table_attach_defaults(GTK_TABLE(table),progress_bar_portscan, 1,2,0,1);
- */
- gtk_box_pack_start(GTK_BOX(box), progress_bar_portscan, TRUE, TRUE,0);
- gtk_widget_show(progress_bar_portscan);
- 
- progress_bar_attack = gtk_progress_bar_new();
- /*
- gtk_table_attach_defaults(GTK_TABLE(table),progress_bar_attack, 1,2,1,2);
- */
- gtk_box_pack_start(GTK_BOX(box), progress_bar_attack, TRUE, TRUE,0);
- gtk_widget_show(progress_bar_attack);
- 
- /*
-  * Stop button
-  */
- box = gtk_vbox_new(TRUE,0);
- gtk_table_attach_defaults(GTK_TABLE(table), box, 2,3,0,2);
- gtk_widget_show(box);
- 
- button = gtk_button_new_with_label(_("Stop"));
- g_signal_connect(GTK_OBJECT(button), "clicked",
-		     (GtkSignalFunc)monitor_stop_test, context);
- gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
- gtk_object_set_data(GTK_OBJECT(button), "hostname", hostname);
- gtk_widget_show(button);
- 
- separator = gtk_hseparator_new();
- gtk_table_attach_defaults(GTK_TABLE(table), separator, 0,3,3,4);
- gtk_widget_show(separator);
-
-
- gtk_object_set_data(GTK_OBJECT(item), "hostname", hostname);
- gtk_object_set_data(GTK_OBJECT(item), "progress_bar_attack", progress_bar_attack);
- gtk_object_set_data(GTK_OBJECT(item), "progress_bar_portscan", progress_bar_portscan);
- gtk_widget_show(table);
- gtk_widget_show(item);
- dlist = g_list_append(dlist, item);
- gtk_object_set_data(GTK_OBJECT(arg_get_value(ctrls, "LIST")), hostname,item);
- gtk_list_append_items(GTK_LIST(arg_get_value(ctrls, "LIST")), dlist);
-
-  }
- }
+}
 
 
 /**
@@ -636,7 +441,7 @@ monitor_stop_whole_test (GtkWidget* w, struct arglist* ctrls)
   type = parse_server_message(context, buf, GPOINTER_TO_SIZE(arg_get_value(ctrls, "MONITOR_BACKEND")), msg);
   efree(&msg);
  }
-  
+
  context->action = CONTEXT_IDLE;
  prefs_context_update(context);
  gtk_widget_hide(arg_get_value(ctrls, "WINDOW"));
@@ -646,8 +451,8 @@ monitor_stop_whole_test (GtkWidget* w, struct arglist* ctrls)
 
 
 /**
- * This function is called whenever there is new
- * data coming from the server.
+ * @brief This function is called whenever there is new data coming from the
+ * @brief server.
  */
 void
 monitor_input_callback (struct arglist * ctrls)
@@ -660,50 +465,54 @@ monitor_input_callback (struct arglist * ctrls)
   int interrupted = 0;
   struct context * context = arg_get_value(ctrls, "CONTEXT");
 
-  if ( context == NULL ) return;
+  if (context == NULL) return;
 
-  if ( buf == NULL )
-  {
-   bufsz = 1024 * 1024;
-   buf   = emalloc( bufsz );
-   msg   = emalloc( bufsz );
-  }
-  network_gets_raw( context->socket, buf, bufsz );
-  if ((n = strlen (buf)) && buf [n-1] == '\n') buf [n-1] = '\0';
+  if (buf == NULL)
+    {
+      bufsz = 1024 * 1024;
+      buf   = emalloc( bufsz );
+      msg   = emalloc( bufsz );
+    }
 
-  if( buf[0] == '\0') {
-  	if(!is_server_present(context->socket))
-	{
-  	 interrupted++;
-   	 goto scan_finished;
-	}
-        else return;
-       }	
+  network_gets_raw (context->socket, buf, bufsz);
+  // Replace newline at end of string with \0
+  if ((n = strlen (buf)) && buf [n-1] == '\n')
+    buf [n-1] = '\0';
+
+  if( buf[0] == '\0')
+    {
+      if (!is_server_present(context->socket))
+        {
+          interrupted++;
+          goto scan_finished;
+        }
+      else return;
+    }
 
   type = parse_server_message(context, buf, GPOINTER_TO_SIZE(arg_get_value(ctrls, "MONITOR_BACKEND")), msg);
- 
-  switch(type)
-  {
-  	case MSG_BYE : 
-		network_printf(context->socket, "CLIENT <|> BYE <|> ACK\n");
-  		finished = 1;
-  		break;
-	case MSG_STAT2 : 
-		monitor_list_update(ctrls,buf+2, 1);	
-		break;
-  	case MSG_STAT :
-  	 	monitor_list_update(ctrls, msg, 0);
-  		break;
-	case MSG_FINISHED :
-		monitor_remove_host(ctrls, msg);
-		break;	
-  }
+
+  switch (type)
+    {
+      case MSG_BYE :
+          network_printf (context->socket, "CLIENT <|> BYE <|> ACK\n");
+          finished = 1;
+          break;
+      case MSG_STAT2 :
+          monitor_list_update (ctrls,buf+2, 1);
+          break;
+      case MSG_STAT :
+          monitor_list_update (ctrls, msg, 0);
+          break;
+      case MSG_FINISHED :
+          monitor_remove_host (ctrls, msg);
+          break;
+    }
   buf[0] = '\0';
   msg[0] = '\0';
-  
+
   if(finished)
     {
-   scan_finished : 
+   scan_finished :
       gtk_widget_hide(arg_get_value(ctrls, "WINDOW"));
       gtk_idle_remove(GPOINTER_TO_SIZE(arg_get_value(ctrls, "TAG")));
       gtk_widget_destroy(arg_get_value(ctrls, "WINDOW"));
@@ -713,14 +522,4 @@ monitor_input_callback (struct arglist * ctrls)
     }
 }
 
-/**
- * @brief This function stops one test.
- */
-void
-monitor_stop_test (GtkWidget * w,struct context * context)
-{
- char * hostname = gtk_object_get_data (GTK_OBJECT(w), "hostname");
- network_printf (context->socket, "CLIENT <|> STOP_ATTACK <|> %s <|> CLIENT\n", hostname);
-}
-
 #endif /* USE_GTK */
