@@ -42,6 +42,7 @@
 #endif
 
 #include "error_dlg.h"
+#include "file_utils.h" /* for file_utils_ensure_dir */
 #include "read_target_file.h"
 #include "comm.h"
 #include "auth.h"
@@ -63,7 +64,6 @@
 #include "latex_output.h"
 #include "text_output.h"
 #include "xml_output_ng.h"
-#include "openvas_ssh_key_create.h" /* for ensure_dir, until we have a file_util module */
 #include "plugin_cache.h"
 #include "severity_filter.h"
 
@@ -99,13 +99,17 @@
 /**
  * @brief Arglist holding the GUI elements (most of them nested in other arglists).
  * 
- * Following overview is not complete yet.
+ * Following overview is not complete yet and should help to remove the dynamic
+ * approach and replace this arglist by static structs representing the GUI.
  * 
  * MainDialog (arg)
  * - USER (arg)
  *   - FRAME
  * - SAVE_KB (arg)
  *   - FRAME
+ * - COMMENT (arg)
+ *   - VBOX
+ *   - REPORT
  * - SCAN_OPTIONS (arg)
  *   - FRAME
  * - PLUGINS (arg)
@@ -157,7 +161,7 @@ extern severity_filter_t* global_filter;
 char * Alt_rcfile = NULL;
 struct plugin_filter Filter;
 static gboolean dont_check_ssl_cert = FALSE;
-gboolean quiet_mode = FALSE;
+gboolean quiet_mode   = FALSE;
 gboolean show_pixmaps = FALSE;
 int F_show_pixmaps;
 int F_quiet_mode;
@@ -167,7 +171,7 @@ int ListOnly = 0;
  * @brief Initialize I18N support, if possible
  */
 static void
-i18n_init(void)
+i18n_init (void)
 {
 #ifdef HAVE_GNU_GETTEXT
   setlocale (LC_ALL, "" );
@@ -194,7 +198,7 @@ i18n_init(void)
 #define CLN_AUTH_SRV 1
 
 static int
-verify_callback(preverify_ok, ctx)
+verify_callback (preverify_ok, ctx)
      int		preverify_ok;
      X509_STORE_CTX	*ctx;
 {
@@ -220,15 +224,15 @@ verify_callback(preverify_ok, ctx)
 static int
 split_var_val (const char *line, char* var, char* val)
 {
-  const char	*p;
-  char	*q;
+  const char *p;
+  char *q;
 
   for (p = line, q = var; *p != '=' && *p != '\0' && *p != '\n'; p ++, q ++)
     *q = *p;
   *q = '\0';
   if (*p == '\0')
     return 0;
-  
+
   for (q = val, p ++; *p != '\0' && *p != '\n'; p ++, q ++)
     *q = *p;
   *q = '\0';
@@ -286,12 +290,18 @@ get_server_cert_hash(sname, hash)
     return 0;
 }
 
+/**
+ * @brief Prints hash into a string.
+ * 
+ * @param hash_str[out] String to contain hash, needs to be 2* SHA_DIGEST_LENGTH
+ *                      bytes long.
+ */
 static void
 print_hash(hash_str, hash)
      char	*hash_str;
      const unsigned char	*hash;
 {
-  int	i;
+  int i;
 
   for (i = 0; i < SHA_DIGEST_LENGTH; i ++)
     sprintf(hash_str + 2 * i, "%02x", hash[i]);
@@ -311,10 +321,10 @@ set_server_cert_hash(sname, hash)
 
   if ((fname = preferences_get_altname(Global, "cert")) == NULL)
     return -1;
-  
+
   if ((fp2 = tmpfile()) == NULL)
     goto error;
-  
+
   fp1 = fopen(fname, "r");
   if (fp1 == NULL && errno != ENOENT)
     goto error;
@@ -376,10 +386,10 @@ set_server_cert_hash(sname, hash)
     fclose(fp2);
   if (fname != NULL)
     efree(&fname);
-    
-  return -1;  
+
+  return -1;
 }
-#endif
+#endif /* CLN_AUTH_SRV */
 
 
 /**
@@ -396,20 +406,20 @@ connect_to_nessusd (struct context * context)
   int port;
   const char * login;
 #ifdef CLN_AUTH_SRV
-  int	paranoia_level;
+  int paranoia_level;
   /*
    * 0: not initialised.
    * 1: remember certificate
    * 2: trust CA
    * 3: trust CA & check certificate
-   */      
+   */
 #endif
-  static SSL_CTX	*ssl_ctx = NULL;
-  static SSL_METHOD	*ssl_mt = NULL;
-  SSL		*ssl = NULL;
-  const char	*cert, *key, *client_ca, *trusted_ca, *ssl_ver;
-  const char	*ssl_cipher_list;
-  STACK_OF(X509_NAME)	*cert_names;
+  static SSL_CTX    *ssl_ctx = NULL;
+  static SSL_METHOD *ssl_mt  = NULL;
+  SSL *ssl                   = NULL;
+  const char *cert, *key, *client_ca, *trusted_ca, *ssl_ver;
+  const char *ssl_cipher_list;
+  STACK_OF(X509_NAME) *cert_names;
   int use_client_cert = prefs_get_int(context, "use_client_cert");
   char *pem_pass = NULL;
   int soc, soc2;
@@ -431,8 +441,7 @@ connect_to_nessusd (struct context * context)
   login = prefs_get_string(context, "nessusd_user");
 
   soc = open_sock_tcp_hn(hostname, port);
-  
-  
+
   if(soc<0)
   	{
   	static char err_msg[1024];
@@ -445,8 +454,8 @@ connect_to_nessusd (struct context * context)
   		return err_msg;
 		}
   	}
-	
-  opt = 1;	
+
+  opt = 1;
   setsockopt(soc, SOL_SOCKET, SO_KEEPALIVE, &opt, sizeof(opt));
 
   ssl_ver = prefs_get_string(context, "ssl_version");
@@ -488,7 +497,7 @@ Please launch openvasclient-mkrand(1) first !"));
 	      ssl_ver = SSL_VER_DEF_NAME;
 	      ssl_mt = SSL_VER_DEF_METH();
 	    }
-      
+
 	  if (ssl_mt == NULL)
 	    {
 	      char	s[32];
@@ -520,7 +529,7 @@ Please launch openvasclient-mkrand(1) first !"));
 	    ssl_cipher_list = STRONG_CIPHER_LIST;
 	  else if (strcmp(ssl_cipher_list, "edh") == 0)
 	    ssl_cipher_list = EDH_CIPHER_LIST;
-	  
+
 	  if (! SSL_CTX_set_cipher_list(ssl_ctx, ssl_cipher_list))
 	    sslerror("SSL_CTX_set_cipher_list");
 	}
@@ -583,7 +592,7 @@ Please launch openvasclient-mkrand(1) first !"));
 #if 0
 	      if (SSL_CTX_set_default_verify_paths(ssl_ctx) <= 0)
 		sslerror("SSL_CTX_set_default_verify_paths");
-#endif  
+#endif
 	      if (! SSL_CTX_load_verify_locations(ssl_ctx, trusted_ca, NULL))
 		{
 		  sslerror("SSL_CTX_load_verify_locations");
@@ -594,7 +603,7 @@ Please launch openvasclient-mkrand(1) first !"));
 		}
 	    }
 	}
-#endif    
+#endif
 
       if (! SSL_set_fd(ssl, soc))
 	{
@@ -604,7 +613,6 @@ Please launch openvasclient-mkrand(1) first !"));
 	  return "SSL error";
 	}
 
-  
       if (SSL_connect(ssl) <= 0)
 	{
 	  sslerror("SSL_connect");
@@ -616,7 +624,7 @@ Please launch openvasclient-mkrand(1) first !"));
 #if DEBUG_SSL > 1
       {
 	char	*p = SSL_get_cipher(ssl);
-	if (p != NULL) 
+	if (p != NULL)
 	  fprintf(stderr, "SSL_get_cipher = %s\n", p);
       }
 #endif
@@ -629,9 +637,8 @@ Please launch openvasclient-mkrand(1) first !"));
 
 	  /*  Essentially store a key,value pair of 'hostname,port'=certificate hash
 	   *  Allows instances of openvasd to have their own server certs w/out confusing the cli 
-	   *  
+	   *
 	   *  certhash is len(hostname)+1(comma)+5(port = )+1(\n) 
-	   *   
 	   */
 	  if((certhash = g_try_malloc(strlen(hostname)+10)) ==  NULL)
 	  {
@@ -639,7 +646,7 @@ Please launch openvasclient-mkrand(1) first !"));
             return "Out of memory error";
 	  }
 	  g_sprintf(certhash,"%s,%d",hostname,port);
-    
+
 	  if (get_server_cert_hash(certhash, stored_hash) <= 0)
 	    memset(stored_hash, 0, sizeof(stored_hash));
 
@@ -690,7 +697,7 @@ Please launch openvasclient-mkrand(1) first !"));
     }
   stream_set_buffer(soc2, 1024 * 1024);
   soc = soc2;
-  
+
   context->socket = soc;
 
   if(comm_init(context->socket, PROTO_NAME) || (auth_login(context->socket, login, passwd)))
@@ -731,6 +738,117 @@ Please launch openvasclient-mkrand(1) first !"));
   return(NULL);
 }
 
+/**
+ * @brief Converts a nbe report into one of the supported formats (pdf, xml,
+ * @brief html, tex etc).
+ * 
+ * Attention, this function calls exit(1) in case of errors and prints messages
+ * to stdout or stderr.
+ * 
+ * @param in_report   nbe- file to read from.
+ * @param out_report  File to write. If parameter output_type is not specified,
+ *                    the type will be derived from the file extension.
+ * @param output_type The type of output wished (can be NULL, then the type
+ *                    will be derived from parameter output_reports file
+ *                    extension).
+ * @param filter_report If TRUE, the global severity filter will be applied
+ *                      before report conversion.
+ * @param drop_fp     If TRUE, Issues of severity level "False Positive" will be
+ *                    dropped during html report conversion (makes sense only in
+ *                    combination with parameter filter_report set to TRUE).
+ * @param drop_no_info If TRUE, found ports and services with no further issues
+ *                     (or LOG or DEBUG messages) will be dropped during html
+ *                     report conversion.
+ */
+static void
+convert_report (gchar* in_report, gchar* out_report,
+                gchar* output_type, gboolean filter_report, gboolean drop_fp,
+                gboolean drop_no_info)
+{
+  int be;
+
+  // Fail if parameter is missing
+  if (!((in_report != NULL) && (out_report != NULL)))
+    {
+      printf (_("You need to specify an input file as well as an output file for report conversion.\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
+      printf (_("Please use --help for more information.\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
+      exit (1);
+    }
+
+  // If filter should be applied during report conversion, load global severity
+  // filter and enable filtering for the Current context.
+  if (filter_report == TRUE)
+    {
+      gchar* filter_file = g_build_filename (prefs_get_nessushome(), ".openvas", "severity_overrides.xml", NULL);
+      global_filter = severity_filter_from_xml (filter_file);
+      g_free (filter_file);
+      Context->is_severity_mapped = TRUE;
+    }
+
+  F_quiet_mode = TRUE;
+  be = backend_import_report (in_report);
+  if (be >= 0)
+    {
+      char * type;
+
+      if (!output_type)
+        {
+          type = strrchr (out_report, '.');
+          if (type != NULL)
+            type++;
+          else
+            type = "nbe";
+        }
+      else
+        {
+          type = output_type;
+        }
+
+      if (drop_fp && strcmp (type, "html"))
+        printf (_("Warning: Dropping False Positives (--convert-drop-fp or -D) is just supported in combination with conversion to html.\n"));
+
+      if (drop_no_info && strcmp (type, "html"))
+        printf (_("Warning: Dropping Ports and Services with 'No Information' (--convert-drop-no-info or -N) is just supported in combination with conversion to html.\n"));
+
+      if (!strcmp(type, "tex") || !strcmp(type, "latex"))
+        arglist_to_latex (backend_convert(be), out_report);
+      else if (!strcmp(type, "txt") || !strcmp(type, "text"))
+        arglist_to_text (backend_convert(be), out_report);
+      else if (!strcmp(type, "html"))
+        html_output_from_arg (backend_convert(be), out_report, drop_fp, drop_no_info);
+#ifndef NO_GDCHART
+      else if (!strcmp(type, "html_pie") || !strcmp(type, "html_graph"))
+        arglist_to_html_graph (backend_convert(be), out_report);
+#endif
+      else if (!strcmp(type, "nbe"))
+        {
+          if (filter_report == TRUE)
+            {
+              fprintf (stderr, _("Cannot apply severity overrides when converting to nbe!\nConsider dropping the -F flag.\n"));
+              exit (1);
+            }
+          backend_to_nbe (be, out_report);
+        }
+      else if (!strcmp(type, "xml"))
+        backend_to_xml_ng (be, out_report);
+      else
+        {
+          if (!strcmp (type, "pdf"))
+            fprintf (stderr, _("Pdf conversion of reports is available in GUI mode only.\n"));
+          else
+            fprintf (stderr, _("Unsupported report type '%s'\n"), type);
+          exit (1);
+        }
+
+      backend_close (be);
+    }
+  else /* Could not open backend from in_report */
+    {
+      fprintf (stderr, _("Could not import '%s' - is it a .nbe file?\n"),
+              in_report);
+    }
+}
+
 int
 main (int argc, char * argv[])
 {
@@ -747,7 +865,7 @@ main (int argc, char * argv[])
 #endif
 
   /* Options for command line parsing */
-  static gboolean make_config_file = FALSE;  
+  static gboolean make_config_file = FALSE;
   static gboolean display_version = FALSE;
   static gboolean verbose = FALSE;
 #ifdef USE_GTK  
@@ -763,12 +881,15 @@ main (int argc, char * argv[])
   static gboolean sqlize_output = FALSE;
   static gboolean list_sessions = FALSE;
   static gboolean restore_session = FALSE;
+  static gboolean convert_filtered = FALSE;
+  static gboolean convert_drop_fp  = FALSE;
+  static gboolean convert_drop_ni  = FALSE;
   static gchar **remaining_options = NULL;
   guint remaining_options_count = 0;
   GError *error = NULL;
   GOptionContext *option_context;
   gchar *session_id = NULL;
-  static GOptionEntry entries[] = 
+  static GOptionEntry entries[] =
   {
     { "version", 'v', 0, G_OPTION_ARG_NONE, &display_version, N_("Display version information"), NULL },
 #ifdef USE_GTK
@@ -787,6 +908,9 @@ main (int argc, char * argv[])
     { "list-prefs", 'P', 0, G_OPTION_ARG_NONE, &list_prefs, N_("Obtain list of server and plugin preferences"), NULL },
     { "in-report", 'i', 0, G_OPTION_ARG_FILENAME, &in_report, N_("Input file (report conversion)"), N_("<in.nbe>") },
     { "out-report", 'o', 0, G_OPTION_ARG_FILENAME, &out_report, N_("Output file (report conversion)"), N_("<out.[html|xml|nbe]>") },
+    { "convert-filtered", 'F', 0, G_OPTION_ARG_NONE, &convert_filtered, N_("Apply global severity filter during report conversion"), NULL },
+    { "convert-drop-fp", 'D', 0, G_OPTION_ARG_NONE, &convert_drop_fp, N_("Drop false positives during report conversion to html"), NULL },
+    { "convert-drop-no-info", 'N', 0, G_OPTION_ARG_NONE, &convert_drop_ni, N_("Drop issues with \"No Information\" during report conversion to html"), NULL },
     { "dont-check-ssl-cert", 'x', 0, G_OPTION_ARG_NONE, &dont_check_ssl_cert, N_("Override SSL \"paranoia\" question preventing OpenVAS-Client from checking certificates"), NULL },
     { "sqlize-output", 'S', 0, G_OPTION_ARG_NONE, &sqlize_output, N_("Issue SQL output for -p and -P (experimental)"), NULL },
     { "list-sessions", 's', 0, G_OPTION_ARG_NONE, &list_sessions, N_("List sessions"), N_("<host> <port> <user> <pass>") },
@@ -800,9 +924,10 @@ main (int argc, char * argv[])
 #ifdef USE_GTK
   g_option_context_add_group(option_context, gtk_get_option_group (FALSE));
 #endif
+
   if (!g_option_context_parse(option_context, &argc, &argv, &error))
   {
-    g_print("%s\n\n", error->message);
+    g_print ("%s\n\n", error->message);
     exit (0);
   }
 
@@ -824,17 +949,16 @@ main (int argc, char * argv[])
 
   if (display_version)
   {
-    printf(_("OpenVAS-Client (%s) %s for %s\n\n"), PROGNAME, NESSUS_VERSION, NESS_OS_NAME);
-    printf(_("NessusClient origin: (C) 1998 - 2003 Renaud Deraison <deraison@nessus.org>\n"));
-    printf(_("New code since OpenVAS-Client: (C) 2007, 2008, 2009 Intevation GmbH\n"));
+    printf(_("OpenVAS-Client (%s) %s for %s\n\n"), PROGNAME, /* RATS: ignore, the non-constant format string comes from a trusted source. */
+           OPENVASCLIENT_VERSION, NESS_OS_NAME);
+    printf(_("NessusClient origin: (C) 1998 - 2003 Renaud Deraison <deraison@nessus.org>\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
+    printf(_("New code since OpenVAS-Client: (C) 2007, 2008, 2009 Intevation GmbH\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
     printf ("\n");
     exit(0);
   }
 
   if (batch_mode != NULL)
-  {
     quiet_mode = TRUE;
-  }
 
   if (list_prefs || list_plugins)
   {
@@ -843,7 +967,6 @@ main (int argc, char * argv[])
   }
 
 #ifdef ENABLE_SAVE_TESTS
-
   if (restore_session)
   {
     if(remaining_options != NULL)
@@ -851,85 +974,60 @@ main (int argc, char * argv[])
       session_id = g_strdup(remaining_options[0]);
     else
     {
-      printf(_("The session ID is required to restore a session.\n"));
-      printf(_("Please use %s --help for more information.\n"), myself);
+      printf(_("The session ID is required to restore a session.\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
+      printf(_("Please use %s --help for more information.\n"), myself); /* RATS: ignore, the non-constant format string comes from a trusted source. */
       exit(1);
     }
   }
 #endif
-  F_quiet_mode = quiet_mode;
+
+  F_quiet_mode   = quiet_mode;
   F_show_pixmaps = show_pixmaps;
 
   /* Initialize global context */
-  context_init(&Global, NULL);
+  context_init (&Global, NULL);
   Context = Global;
 
+  // Just convert a report from one format into another
   if((in_report != NULL) || (out_report != NULL))
-  {
-    int be;
-    if(!((in_report != NULL) && (out_report != NULL)))
     {
-      printf(_("You need to specify an input file as well as an output file for report conversion.\n"));
-      printf(_("Please use %s --help for more information.\n"), myself);
-      exit(1);
+      // If in_report is part of a "report" directory, load the context
+      // To do so, we have to trick a bit (usually all contexts are read in
+      // recursively).
+      struct context* context;
+      context_init (&context, Global);
+      context->type = CONTEXT_REPORT;
+      context_collect_recurse (context, g_path_get_dirname (in_report));
+      context_load_plugin_cache (context);
+      Context = context;
+
+      convert_report (in_report, out_report, output_type, convert_filtered,
+                      convert_drop_fp, convert_drop_ni);
+      exit (0);
     }
-    F_quiet_mode = TRUE;
-    be = backend_import_report(in_report);
-    if(be >= 0)
-    {
-      char * type;
-      if(!output_type)
-      {
-        type = strrchr(out_report, '.');
-        if(type != NULL)
-          type++;
-        else
-          type = "nbe";
-      }
-      else
-      {
-        type = output_type;
-      }
-      if(!strcmp(type, "tex") || !strcmp(type, "latex"))
-        arglist_to_latex(backend_convert(be), out_report);
-      else if(!strcmp(type, "txt") || !strcmp(type, "text"))
-        arglist_to_text(backend_convert(be), out_report);
-      else if(!strcmp(type, "html"))
-        arglist_to_html(backend_convert(be), out_report);
-#ifndef NO_GDCHART
-      else if(!strcmp(type, "html_pie") || !strcmp(type, "html_graph"))
-        arglist_to_html_graph(backend_convert(be), out_report);
-#endif
-      else if(!strcmp(type, "nbe"))
-        backend_to_nbe(be, out_report);
-      else if(!strcmp(type, "xml"))
-        backend_to_xml_ng(be, out_report); 
-      else
-      {
-        fprintf(stderr, _("Unsupported report type '%s'\n"), type);
-        exit(1);
-      }
-      backend_close(be);
-      exit(0);
-    }
-    else
-    {
-      fprintf(stderr, _("Could not import '%s' - is it a .nbe file?\n"),
-              in_report);
-    }
-    exit(0);
-  }
+
+  // Alarm if --convert-filtered flag is given but no --in-report or --out-report
+  if (convert_filtered == TRUE)
+    printf (_("Ignoring -F (--convert-filtered) option.\nThis option can only be used in combination with -i (--in-report) and -o (--out-report)."));
+
+  // Alarm if --convert-drop-fp flag is given but no --in-report or --out-report
+  if (convert_drop_fp == TRUE)
+    printf (_("Ignoring -D (--convert-drop-fp) option.\nThis option can only be used in combination with -i (--in-report) and -o (--out-report) and html as target format."));
+
+  // Alarm if --convert-drop-no-info flag is given but no --in-report or --out-report
+  if (convert_drop_ni == TRUE)
+    printf (_("Ignoring -N (--convert-drop-no-info) option.\nThis option can only be used in combination with -i (--in-report) and -o (--out-report) and html as target format."));
 
   if(make_config_file && !quiet_mode)
   {
-    printf(_("The option -make_config_file can only be used in batch mode.\n"));
-    printf(_("Please use %s --help for more information.\n"), myself);
+    printf(_("The option --make_config_file can only be used in batch mode.\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
+    printf(_("Please use %s --help for more information.\n"), myself); /* RATS: ignore, the non-constant format string comes from a trusted source. */
     exit(1);
   }
 
 #define BATCH_USAGE "batch mode and <host> <port> <user> <pass> "
 #define BATCH_ARGC 3
-	
+
 #ifdef ENABLE_SAVE_TESTS
   if(list_sessions && (remaining_options_count < BATCH_ARGC) && !quiet_mode)
   {
@@ -967,7 +1065,7 @@ main (int argc, char * argv[])
   }
 #endif
 
-  /* system environment set up */
+  /* System environment set up */
   if(!make_config_file)
   {
     if (preferences_init(Global))
@@ -986,8 +1084,8 @@ main (int argc, char * argv[])
     fprintf(stderr, _("Verbose mode can only be used in batch mode\n"));
     exit(1);
   }
-  
-  /* do we run in batchmode ? */
+
+  /* Do we run in batchmode ? */
   if (remaining_options_count >= BATCH_ARGC || quiet_mode)
   {
     struct cli_args * cli;
@@ -997,17 +1095,16 @@ main (int argc, char * argv[])
     cli = cli_args_new();
     cli_args_verbose(cli, verbose);
 
-    /* with, or without ENABLE_CRYPTO_LAYER */
+    /* With, or without ENABLE_CRYPTO_LAYER */
 #define NUM_ARGS 5
 
 #ifndef ENABLE_SAVE_TESTS
-
     if (remaining_options_count != NUM_ARGS)
     {
       if(!((remaining_options_count == NUM_ARGS - 2) && make_config_file))
       {
-        printf(_("Batch mode requires login information.\n"));
-        printf(_("Please use %s --help for more information.\n"), myself);
+        printf(_("Batch mode requires login information.\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
+        printf(_("Please use %s --help for more information.\n"), myself); /* RATS: ignore, the non-constant format string comes from a trusted source. */
         exit(0);
       }
     }
@@ -1039,10 +1136,10 @@ main (int argc, char * argv[])
         exit(1);
       }
     }
-    else if (remaining_options_count != NUM_ARGS) 
+    else if (remaining_options_count != NUM_ARGS)
     {
-      printf(_("Batch mode requires login information.\n"));
-      printf(_("Please use %s --help for more information.\n"), myself);
+      printf(_("Batch mode requires login information.\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
+      printf(_("Please use %s --help for more information.\n"), myself); /* RATS: ignore, the non-constant format string comes from a trusted source. */
       exit(0);
     }
 
@@ -1086,7 +1183,7 @@ main (int argc, char * argv[])
       }
       if(sqlize_output)
         cli_sql_dump_plugins(cli);
-      else 
+      else
         cli_dump_plugins(cli);
 
       cli_close_connection(cli);
@@ -1126,6 +1223,7 @@ main (int argc, char * argv[])
     /* login now */
     if((cli_connect_to_nessusd(cli)) < 0)
       nessus_exit(1);
+
 #ifdef ENABLE_SAVE_TESTS
     if(list_sessions)
     {
@@ -1138,12 +1236,13 @@ main (int argc, char * argv[])
     {
       cli_restore_session(cli, session_id);
     }
-    else	
+    else
 #endif
+
     if(make_config_file)
     {
       if(!preferences_generate_new_file(Global, NULL))
-        printf(_("A new openvasrc file has been saved\n"));
+        printf(_("A new openvasrc file has been saved\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
     }
     else
     {
@@ -1152,7 +1251,7 @@ main (int argc, char * argv[])
     }
     /* Free session id. It's no longer needed */
     g_free(session_id);
-    /* end, exit */
+    /* End, exit */
     nessus_exit(0);
   }
   /* Free session id. It's no longer needed */
@@ -1182,17 +1281,17 @@ main (int argc, char * argv[])
   if (global_filter == NULL)
     {
       gchar * filter_file_dir = g_build_filename (prefs_get_nessushome(), ".openvas", NULL); 
-      if (ensure_dir (filter_file_dir) == TRUE)
+      if (file_utils_ensure_dir (filter_file_dir) == TRUE)
         global_filter = severity_filter_new (_("Global Severity Overrides"), filter_file);
       g_free (filter_file_dir);
     }
   g_free (filter_file);
 
-    signal(SIGINT, sighand_exit);
-    signal(SIGQUIT, sighand_exit);
-    signal(SIGKILL, sighand_exit);
-    signal(SIGTERM, sighand_exit);
-    
+  signal(SIGINT, sighand_exit);
+  signal(SIGQUIT, sighand_exit);
+  signal(SIGKILL, sighand_exit);
+  signal(SIGTERM, sighand_exit);
+
   gtk_main();
 
   /* FIXME: Server preferences are not saved here */
@@ -1204,6 +1303,9 @@ main (int argc, char * argv[])
   return 0; /* make the compiler happy */
 
 #else
+  /* RATS: ignore, the non-constant format string comes from a trusted
+   * source.
+   */
   printf(_("\n\
   This version of OpenVAS-Client was compiled without gui support\n\
   and can only be run in batch mode.\n\
@@ -1214,8 +1316,8 @@ main (int argc, char * argv[])
 } /* main */
 
 #ifdef NESSUSNT
-int WINAPI WinMain(HINSTANCE hThisInst, HINSTANCE hPrevInst,
-    		   LPSTR lpszArgs, int nWinMode)
+int WINAPI WinMain (HINSTANCE hThisInst, HINSTANCE hPrevInst,
+                    LPSTR lpszArgs, int nWinMode)
 {
 /*
  * Initialize WinSock and jump into the regular 'main'
@@ -1226,5 +1328,4 @@ int WINAPI WinMain(HINSTANCE hThisInst, HINSTANCE hPrevInst,
   WSACleanup();
   return 0;
 }
- 
-#endif
+#endif /* NESSUSNT */
