@@ -29,28 +29,19 @@
 #ifndef _NESSUSC_NESSUS_H
 #define _NESSUSC_NESSUS_H
 
-/* The default port assigned to nessus by the iana is 1241, see
-   http://www.isi.edu/in-notes/iana/assignments/port-numbers */
+/* The default port assigned to OpenVAS for OTP by the iana is 9390, see
+   http://www.iana.org/assignments/port-numbers */
 #ifdef _WIN32
-#ifndef NESIANA_PORT
-#define NESIANA_PORT 1241
+#ifndef OPENVAS_IANA_OTP_PORT
+#define OPENVAS_IANA_OTP_PORT 9390
 #endif
 #endif
 
 #define DEFAULT_SERVER "localhost"
-#define PROTO_NAME "< NTP/1.2 >< plugins_cve_id plugins_version plugins_bugtraq_id plugins_xrefs timestamps dependencies %s >\n"
-#define PROTO_NAME_OTP "< OTP/1.0 >< plugins_cve_id plugins_version plugins_bugtraq_id plugins_xrefs timestamps dependencies %s >\n"
+#define PROTO_NAME "< OTP/1.0 >\n"
 # define SSL_VER_DEF_NAME	"TLSv1"
 # define SSL_VER_DEF_METH	TLSv1_client_method
 
-#ifdef _CYGWIN_
-extern char * NESSUS_RCFILE;
-extern int init_directories;
-#else
-#define NESSUS_RCFILE     "~/.openvasrc"
-#endif
-
-
 #include "context.h"
 
 char * connect_to_nessusd(struct context *);
