@@ -20,15 +20,6 @@
 #ifndef _NESSUSC_NESSUS_I18N_H
 #define _NESSUSC_NESSUS_I18N_H
 
-/*
- * Define function _() according to whether GNU gettext is available.
- * If not available, _() is just a dummy.
- */
-#ifdef HAVE_GNU_GETTEXT
-# include <libintl.h>
-# define _(a) gettext (a)
-#else
-# define _(a) (a)
-#endif /*HAVE_GNU_GETTEXT*/
+#include <glib/gi18n.h>
 
 #endif /* _NESSUSC_NESSUS_I18N_H */
