@@ -37,6 +37,7 @@
 
 #include "report.h"
 #include "report_utils.h"
+#include "html_output.h"
 #include "error_dlg.h"
 #include "globals.h"
 #include "preferences.h"
@@ -46,15 +47,21 @@
 
 #include "nessus_i18n.h"
 
-static char * convert_cr_to_html(char *);
-static char * portname_to_ahref(char *, char *);
+/**
+ * \file
+ * PDF export currently works with an intermediate html export.
+ * The intermediate html file is then used to create a pdf, calling the external
+ * tool "htmldoc".
+ */
+
+
 int arglist_to_plainhtml(struct context *, int, char *);
 void pdf_summary_to_file(FILE *, int, struct arglist *);
 static void print_appendix(FILE *, GHashTable*);
 
 
-/*
- * These makros print the utf8 strings as locale strings to file.
+/**
+ * Print the utf8 strings as locale strings to file.
  * Obviously this is not an elegant implementation, but I am currently
  * unsure how and how far this method should/must be extended to other
  * modules.
@@ -64,13 +71,13 @@ static void print_appendix(FILE *, GHashTable*);
 #define PRINT(file, x) { char * s = _2l(x); fprintf(file, s); g_free(s); }
 #define PRINT1(file, x, v) { char * s = _2l(x); fprintf(file, s, v); g_free(s); }
 
-/*
+/**
  * Convert the UTF-8 String to what locale is set to.
  * Unfortunately this is required htmldoc does not honor
  * the UTF-8 encoding setting in the html file.
  */
-char * _2l(utfstr)
-  char * utfstr;
+char *
+_2l (char * utfstr)
 {
   char * localestr;
   gsize bytes_read, bytes_written;
@@ -82,21 +89,17 @@ char * _2l(utfstr)
   return localestr;
 }
 
-/*
+/**
  * Print format string 'fmt' to file with one %s
  * replaced with first timestamp of type = 'type'
  * (optionally host = 'host') from backend 'be'.
- * Doesn't print anything of no timestamp is found.
+ * Doesn't print anything if no timestamp is found.
  *
  * TODO: Format timestamp according to locale settings.
  */
 static void
-PRINT_timestamp(file, be, fmt, type, host)
- FILE * file;
- int be;
- const char *fmt;
- const char *type;
- const char *host;
+PRINT_timestamp (FILE * file, int be, const char *fmt, const char *type,
+                 const char *host)
 {
  struct subset *s;
  char *query;
@@ -120,250 +123,38 @@ PRINT_timestamp(file, be, fmt, type, host)
  subset_free(s);
 }
 
-/*
- * Handy functions
+/**
+ * Writes html table rows with information about a found security issue, 
+ * containing a link to the plugin (in the appendix or online).
+ * The security class (currently in use: Informational, Warning and 
+ * Vulnerability) will be highlighted in a specific color (colorcode parameter).
+ * 
+ * @param file The file to write to.
+ * @param reportplugin The plugin of which to extract description etc.
+ * @param colorcode Colorcode to be used for highlighting the class string.
+ * @param class Class of security issue (currently in use: Informational, 
+ *              Warning and Vulnerability).
+ * @param include_plugins If TRUE the link will be internal (appendix).
  */
-
-/*
- * print URL linking to CVE/BID/OpenVAS database to file.
- * '%s' in urlfmt (from preferences) will be replaced by
- * item IDs (or their parts split at minus characters).
- * '%%' will insert a percent character.
- * Everything else after '%' aborts parsing.
- * If urlfmt yields an empty string (e.g. it is only "%"),
- * only the item ID will be printed.
- */
-static void
-fprint_link(file, key, item)
-  FILE *file;
-  const char *key;
-  const char *item;
+static void html_print_plugin_box (FILE* file, struct arglist* reportplugin,
+                                   char* colorcode, char* class,
+                                   gboolean include_plugins)
 {
-  char *itemparts = estrdup(item);
-  char *itemsrc = itemparts;
-  char *urlfmt = estrdup(prefs_get_string(Global, key));
-  char *src = urlfmt;
-  char *url = emalloc(strlen(urlfmt)+strlen(item)+1);
-  char *dst = url;
-  char *tmp;
-
-  while((tmp = strchr(src, '%')))
-  {
-    *tmp = '\0';
-    strcpy(dst, src);
-    dst += strlen(src);
-    src = tmp+1;
-    switch(*src)
-    {
-      case 's':
-	if((tmp = strchr(itemsrc, '-')))
-	  *tmp = '\0';
-	strcpy(dst, itemsrc);
-	dst += strlen(itemsrc);
-	if(tmp)
-	  itemsrc = tmp+1;
-	src++;
-	break;
-      case '%':
-	strcpy(dst++, "%");
-	src++;
-	break;
-      default:
-	*src = '\0';
-    }
-  }
-  strcpy(dst, src);
-
-  efree(&itemparts);
-  efree(&urlfmt);
-  if(*url)
-    fprintf(file, "<a href=\"%s\">%s%s</a>", url,
-            strcmp("url_nessus", key) ? "" : "1.3.6.1.4.1.25623.1.0.", item);
-  else
-    fprintf(file, "%s", item);
-  efree(&url);
+  char* desc = html_output_convert_cr_to_html(reportplugin->value);
+  fprintf(file, "\t<tr bgcolor=\"%s\">\n", colorcode);
+  fprintf(file, "\t\t<td valign=\"top\">");
+  PRINT(file, class);
+  fprintf(file, "\t\t</td");
+  fprintf(file, "\t</tr>\n");
+  fprintf(file, "\t<tr>\n");
+  fprintf(file, "\t\t<td>\n");
+  html_output_print_data_with_links(file, desc, reportplugin->name, include_plugins);
+  fprintf(file, "\n\t\t</td>\t</tr>\n");
+  efree(&desc);
 }
 
-/* All the cross references (CVE, BID) have the same format - XREF: <num>,...<br> */
-static char * 
-extract_xref(file, str, key)
- FILE * file;
- char * str, * key;
-{
- while(str != NULL && strncmp(str, "<br>", 4) != 0)
-   {
-    char * e1 = strchr(str, ',');
-    char * e2 = strchr(str, '<');
-    char tmp = '\0';
-    if((e1 > e2) || (e1 == NULL))e1 = e2;
-   
-   
-    if(e1 != NULL)
-    {
-     tmp = e1[0];
-     e1[0] = '\0';
-    }
-    fprint_link(file, key, str);
-    str = e1;
-    if(e1 != NULL)
-    {
-     e1[0] = tmp;
-   
-     if(tmp == ','){
-     	fputc(',', file);
-	fputc(' ', file);
-	str ++;
-	str ++;
-	}
-     else
-        fputc('<', file);
-    }
-   }
-  return str;
-}
- 
-static void 
-print_data_with_links(FILE * file, char * str, char * plugin_id,
-    int internal_link)
-{
- while(str != NULL && str[0] != '\0')
- {
-  if(strncmp(str, "http:", 5) == 0 || strncmp(str, "https:", 6) == 0 )
-  {
-   char * e1, * e2;
-   char tmp = 0;
-   
-   e1 = strchr(str, ' ');
-   e2 = strstr(str, "<br>");
-   if((e1 > e2) || (e1 == NULL))e1 = e2;
-   
-   if(e1 != NULL)
-   {
-    tmp = e1[0];
-    e1[0] = '\0';
-   }
-   fprintf(file, "<a href=\"%s\">%s</a>", str, str);
-   str += strlen(str) - 1;
-   if(e1 != NULL)
-   {
-    e1[0] = tmp;
-   }
-  }
-  else if(strncmp(str, "CVE : ", 6) == 0)
-  {
-   fprintf(file, "CVE : ");
-   str += 6;
-   str = extract_xref(file, str, "url_cve");
-  }
-  else if(strncmp(str, "BID : ", 6) == 0)
-  {
-  fprintf(file, "BID : ");
-  str += 6;
-  str = extract_xref(file, str, "url_bid");
-  }
-  else fputc(str[0], file);
-  if(str != NULL)
-    str++;
- }
- 
- fprintf(file, "OpenVAS ID : ");
- if (internal_link)
-   fprintf(file, "<a href=\"#nvt1.3.6.1.4.1.25623.1.0.%s\">1.3.6.1.4.1.25623.1.0.%s</a>", plugin_id, plugin_id);
- else
-   fprint_link(file, "url_nessus", plugin_id);
-}
-
-
-static char * convert_cr_to_html(str)
- char * str;
-{
- int num = 0;
- char * t;
- char * ret;
- int i, j = 0;
- /*
-  * Compute the size we'll need
-  */
-  
-  t = str;
-  while(t[0])
-  {
-   if((t[0]=='\n')||(t[0]=='>')||(t[0]=='<'))num++;
-   t++;
-  }
- 
-  ret = emalloc(strlen(str)+5*num+1);
-  for(i=0, j=0;str[i];i++,j++)
-  {
-   if(str[i]=='\n'){
-   	ret[j++]='<';
-	ret[j++]='b';
-	ret[j++]='r';
-	ret[j++]='>';
-	ret[j]='\n';
-	}
-   else if(str[i]=='>') {
-    	ret[j++]='&';
-	ret[j++]='g';
-	ret[j++]='t';
-	ret[j]=';';
-	}
-  else if(str[i]=='<')
-  	{
-	ret[j++]='&';
-	ret[j++]='l';
-	ret[j++]='t';
-	ret[j]=';';
-	}
-  else ret[j] = str[i];
-  }
-  return ret;
-}
-
-
-   
-static char * portname_to_ahref(name, hostname)
- char * name;
- char * hostname;
-{
-  char *t, *k;
-
-  /*
-   * Convert '192.168.1.1' to '192_168_1_1' or
-   * 'prof.nessus.org' to 'prof_nessus_org'
-   */
-  hostname = 
-    t = estrdup (hostname) ;
-  while ((t = strchr (t, '.')) != 0)
-    t [0] = '_' ;
-  if (name == 0)
-    return hostname ;
-
-  /*
-   * Convert 'telnet (21/tcp)' to '21_tcp'
-   */
-  name =
-    k = estrdup (name);
-  if ((t = strrchr (k, '(')) != 0) 
-    k = t + 1;
-  if ((t = strchr (k, ')')) != 0)
-    t [0] = '\0' ;
-  while ((t = strchr (k, '/')) != 0)
-    t [0] = '_' ;
- 
-  /*
-   * append: "name" + "_" + "hostname"
-   */
-  t = emalloc (strlen (hostname) + strlen (k) + 2);
-  strcat (strcat (strcpy (t, hostname), "_"), k);
-  efree (&hostname);
-  efree (&name);
-  return t ;
-}
-
-
-
-static int exec_htmldoc(char ** argv)
+static int
+exec_htmldoc (char ** argv)
 {
  int ret;
  int pid;
@@ -392,7 +183,9 @@ static int exec_htmldoc(char ** argv)
  return WEXITSTATUS(ret);
 }
 
-char**  append_argv(char **argv, char   *opt)
+// TODO replace argv handling and exec_htmldoc with glib functions.
+char**
+append_argv (char **argv, char   *opt)
 {
   int argc, n ;
   
@@ -424,7 +217,8 @@ char**  append_argv(char **argv, char   *opt)
   return argv ;
 }
 
-void    destroy_argv(char **argv)
+void
+destroy_argv (char **argv)
 {
   int argc ;
   if (argv == 0)
@@ -435,8 +229,20 @@ void    destroy_argv(char **argv)
 }
 
 
+/**
+ * Exports arglist to html (temporarily creates report.html!), then calls 
+ * htmldoc to produce a pdf file.
+ * 
+ * @param be The backend index.
+ * @param filename Filename to write to.
+ * 
+ * @return Returns always 0.
+ * 
+ * @see exec_htmldoc
+ * @see arglist_to_plainhtml
+ */
 int
-arglist_to_pdf(struct context * context, int be, char * filename)
+arglist_to_pdf (struct context * context, int be, char * filename)
 {
  char tmpfname[PATH_MAX];
  char * cwd = emalloc(PATH_MAX * sizeof(char));
@@ -460,7 +266,7 @@ arglist_to_pdf(struct context * context, int be, char * filename)
 
  const char *nessus_dir = estrdup(prefs_get_string(Global, "nessus_dir"));
 
- snprintf(tmpfname, PATH_MAX, "%s/.openvas_%d_pdf",nessus_dir, getpid());
+ snprintf(tmpfname, PATH_MAX, "%s/.openvas_%d_pdf", nessus_dir, getpid());
  
  while (!getcwd(cwd, cwd_max))
  {	cwd_max=cwd_max+PATH_MAX;
@@ -517,13 +323,22 @@ arglist_to_pdf(struct context * context, int be, char * filename)
  g_free(htmldoc_datadir);
  g_free(htmldoc_program);
 #endif /* CYGWIN */
-
+ argv = append_argv(argv, NULL);
+ destroy_argv (argv);
  return(htmldoc_ret);
 }
 
-
+/* As pdf export works via intermediate html export, it might be worth looking
+   at arglist_html (html_output.c), refactor and merge. */
+/**
+ * Exports a backend into plain html to be converted to a pdf using htmldoc.
+ * 
+ * @param be Index of backend to use.
+ * @param filename Filename of file to export to or "-" to print to stdout.
+ * @return 0 on success, -1 on error.
+ */
 int
-arglist_to_plainhtml(struct context * context, int be, char *filename)
+arglist_to_plainhtml (struct context * context, int be, char *filename)
 {
  FILE *file;
  struct arglist *hosts;
@@ -531,7 +346,7 @@ arglist_to_plainhtml(struct context * context, int be, char *filename)
  int include_plugins = (prefs_get_int(Global, "report_plugin_details_in_pdf")
      && context->plugins != NULL);
 
- if(!strcmp(filename, "-"))file = stdout;
+ if(!strcmp(filename, "-")) file = stdout;
  else file = fopen(filename, "w");
  if(!file){
  	show_error(_("Could not create this file !"));
@@ -556,15 +371,14 @@ arglist_to_plainhtml(struct context * context, int be, char *filename)
  {
   char * hostname;
   char * port;
-  char * desc;
   struct arglist * ports;
   char * href;
   char * name;
   hostname = hosts->name;
 
-  href = portname_to_ahref(NULL, hostname);
+  href = html_output_portname_to_ahref(NULL, hostname);
   fprintf(file, "\n<h3>%s</h3>\n<a name=\"%s\"></a>\n", hostname, href);
-  name = portname_to_ahref("toc", hostname);
+  name = html_output_portname_to_ahref("toc", hostname);
   fprintf(file, "<a name=\"%s\"></a>\n", name);
   efree(&name);
 
@@ -593,13 +407,13 @@ arglist_to_plainhtml(struct context * context, int be, char *filename)
      struct arglist * open = ports;
      if(open->next)
      {
-  
         while(open && open->next){
-          name = portname_to_ahref(open->name, hostname);
+          name = html_output_portname_to_ahref(open->name, hostname);
 	  if(name)
 	  {
 	      if(arg_get_value(open->value, "REPORT") ||
 	         arg_get_value(open->value, "INFO") ||
+	         arg_get_value(open->value, "FALSE") ||
 	         arg_get_value(open->value, "NOTE")) 
 	      {
 	             fprintf(file, "\t<tr>\n");
@@ -607,7 +421,7 @@ arglist_to_plainhtml(struct context * context, int be, char *filename)
 	   				name, open->name);
 	             if(arg_get_value(open->value, "REPORT")) {
 		     	fprintf(file, "\t\t<td><font color=red>");
-			PRINT(file, _("Security hole found"));
+			PRINT(file, _("Security hole(s) found"));
 			fprintf(file, "</font></td>\n");
 		     }
 	             else if(arg_get_value(open->value, "INFO")) {
@@ -615,14 +429,19 @@ arglist_to_plainhtml(struct context * context, int be, char *filename)
 		     	PRINT(file, _("Security warning(s) found"));
 			fprintf(file, "</td>\n");
 		     }
+	             else if(arg_get_value(open->value, "FALSE")) {
+			fprintf(file, "\t\t<td>");
+		     	PRINT(file, _("False positive(s) found"));
+			fprintf(file, "</td>\n");
+		     }
 	             else {
 			fprintf(file, "\t\t<td>");
-		     	PRINT(file, _("Security notes found"));
+		     	PRINT(file, _("Security note(s) found"));
 			fprintf(file, "</td>\n");
 		     	fprintf(file, "\t</tr>");
 		     }
-	      }	 
-	        else {	
+	      }
+	        else {	// Not port, info or note
 		     fprintf(file, "\t<tr>\n");
 		     fprintf(file, "\t\t<td>%s</td>\n", open->name);
 		     fprintf(file, "\t\t<td>");
@@ -631,7 +450,7 @@ arglist_to_plainhtml(struct context * context, int be, char *filename)
 	      }
 	      efree(&name);
 	  }
-	  else {
+	  else { // No port name
 	      fprintf(file, "\t<tr>\n");
               fprintf(file, "\t\t<td>%s</td>\n", open->name);
 	      fprintf(file, "\t\t<td>");
@@ -659,95 +478,80 @@ arglist_to_plainhtml(struct context * context, int be, char *filename)
     struct arglist * report;
     struct arglist * info;
     struct arglist * note;
+    struct arglist * false_positive;
 
     port = ports->name;
 
-    name = portname_to_ahref(ports->name, hostname);
+    name = html_output_portname_to_ahref(ports->name, hostname);
 
     report = arg_get_value(ports->value, "REPORT");
     info = arg_get_value(ports->value, "INFO");
     note = arg_get_value(ports->value, "NOTE");
+    false_positive = arg_get_value(ports->value, "FALSE");
 
-    if (report || info || note)
+    if (report || info || note || false_positive)
     {
     fprintf(file, "<h4><a name=\"%s\"></a>%s - %s</h4>\n", name, hostname, port);
     fprintf(file, "<table border=1 bordercolor=\"#c1c1c1\" width=\"100%%\"\n");
     fprintf(file, "       cellpadding=2 cellspacing=0>\n");
 
-    if(report)while(report && report->next)
+    while(report && report->next)
      {
      if(strlen(report->value))
-     {
-     /*
-      * Convert the \n to <p> 
-      */
-      desc = convert_cr_to_html(report->value);
-      fprintf(file, "\t<tr bgcolor=\"#FF5050\">\n");
-      fprintf(file, "\t\t<td valign=top>");
-      PRINT(file, _("Vulnerability"));
-      fprintf(file, "</font>: ");
-      fprintf(file, "\t</tr>\n");
+       {
+       // Print info about plugins, eventually add to appendix
+       html_print_plugin_box(file, report, "#FF5050", "Vulnerability", 
+                        include_plugins);
+       if(include_plugins)
+         g_hash_table_insert(appendix_plugins, report->name, context);
+       }
+     report = report->next;
+     }
 
-      fprintf(file, "\t<tr>\n");
-      fprintf(file, "\t\t<td>\n"); 	
-      print_data_with_links(file, desc, report->name, include_plugins);
-      if (include_plugins)
-	g_hash_table_insert(appendix_plugins, report->name, context);
-      fprintf(file, "\n\t\t</td>\t</tr>\n");
-      efree(&desc);
-     }
-      report = report->next;
-     }
-   if(info)while(info && info->next)
-    {
-     if(strlen(info->value))
+    while(info && info->next)
      {
-     /*
-      * Convert the \n to <p> 
-      */
-     desc = convert_cr_to_html(info->value); 
-     name = portname_to_ahref(ports->name, hostname);
-     fprintf(file, "\t<tr bgcolor=\"#FFFFA0\">\n");
-     fprintf(file, "\t\t<td valign=top>");
-     PRINT(file, _("Warning"));
-     fprintf(file, ": ");
-     fprintf(file, "\t<tr>\n");
-     fprintf(file, "\t\t<td>\n"); 	
-     print_data_with_links(file, desc, info->name, include_plugins);
-     if (include_plugins)
-       g_hash_table_insert(appendix_plugins, info->name, context);
-     fprintf(file, "\n\t\t</td>\t</tr>\n");
-     efree(&desc);
-     }  
+     if(strlen(info->value))
+       {
+        name = html_output_portname_to_ahref(ports->name, hostname);
+        html_print_plugin_box(file, info, "#FFFFA0", "Warning", 
+                        include_plugins);
+        if (include_plugins)
+          g_hash_table_insert(appendix_plugins, info->name, context);
+       }
      info = info->next;
     }
 
-   if(note)while(note->next)
+   while(note && note->next)
     {
      if(strlen(note->value))
      {
      char * name;
-     desc = emalloc(strlen(note->value)+1);
-     strncpy(desc, note->value, strlen(note->value));
-     /*
-      * Convert the \n to <p> 
-      */
-     desc = convert_cr_to_html(note->value); 
-     name = portname_to_ahref(ports->name, hostname);
-     fprintf(file, "\t<tr bgcolor=\"#ABABE1\">\n");
-     fprintf(file, "\t\t<td valign=top>");
-     PRINT(file, _("Informational"));
-     fprintf(file, ": ");
-     fprintf(file, "\t<tr>\n");
-     fprintf(file, "\t\t<td>\n"); 	
-     print_data_with_links(file, desc, note->name, include_plugins);
+     //desc = emalloc(strlen(note->value)+1);
+     //strncpy(desc, note->value, strlen(note->value));
+     /* Convert the \n to <br>, make "<",">" html- safe */
+     name = html_output_portname_to_ahref(ports->name, hostname);
+     html_print_plugin_box(file, note, "#ABABE1", "Informational", 
+                        include_plugins);
      if (include_plugins)
        g_hash_table_insert(appendix_plugins, note->name, context);
-     fprintf(file, "\n\t\t</td>\t</tr>\n");
-     efree(&desc);
-     }  
+     }
      note = note->next;
     }
+
+    while(false_positive && false_positive->next)
+    {
+     if(strlen(false_positive->value))
+     {
+       char * name;
+       name = html_output_portname_to_ahref(ports->name, hostname);
+       html_print_plugin_box(file, false_positive, "#ABABE1", "False Positive", 
+			  include_plugins);
+       if (include_plugins)
+	 g_hash_table_insert(appendix_plugins, false_positive->name, context);
+     }
+     false_positive = false_positive->next;
+    }
+
     fprintf(file, "\t</table>\n");
     fprintf(file, "<font size=-2><a href=\"#%s\">", href);
     PRINT1(file, _("[ return to %s ]"), hostname);
@@ -756,6 +560,7 @@ arglist_to_plainhtml(struct context * context, int be, char *filename)
     }
     ports = ports->next;
    }
+
   hosts = hosts->next;
   efree(&href);
  }
@@ -768,7 +573,8 @@ arglist_to_plainhtml(struct context * context, int be, char *filename)
 
  fprintf(file, "<hr>\n<i>");
  PRINT(file, 
-	_("This file was generated by <a href=\"http://www.openvas.org\">OpenVAS</a>, the free security scanner."));
+	_("This file was generated by <a href=\"http://www.openvas.org\">"
+          "OpenVAS</a>, the free security scanner."));
  fprintf(file, "</i></BODY>\n");
  fprintf(file, "</HTML>\n");
  fclose(file);
@@ -782,7 +588,7 @@ arglist_to_plainhtml(struct context * context, int be, char *filename)
 }
 
 
-void pdf_summary_to_file(FILE *file, int be, struct arglist *hosts)
+void pdf_summary_to_file (FILE *file, int be, struct arglist *hosts)
 {
  struct arglist * dummy = hosts;
 
@@ -805,7 +611,7 @@ void pdf_summary_to_file(FILE *file, int be, struct arglist *hosts)
  fprintf(file, "</h2>\n");
  fprintf(file, "<a name=\"_summary\">\n");
 
- PRINT(file, _("This report gives details on hosts that were tested and issues that were found."));
+ PRINT(file, _("This report gives details on hosts that were tested and issues that were found. "));
  PRINT(file, _("Please follow the recommended steps and procedures to eradicate these threats.\n"));
  fprintf(file, "\t<p>\n");
  fprintf(file, "\n");
@@ -819,21 +625,24 @@ void pdf_summary_to_file(FILE *file, int be, struct arglist *hosts)
  fprintf(file, "\t\t<td width=\"16%%\">");
  PRINT(file, _("Host"));
  fprintf(file, "</td>\n");
- fprintf(file, "\t\t<td width=\"30%%\">");
+ fprintf(file, "\t\t<td width=\"32%%\">");
  PRINT(file, _("Possible Issues"));
  fprintf(file, "</td>\n");
- fprintf(file, "\t\t<td width=\"18%%\">");
+ fprintf(file, "\t\t<td width=\"13%%\">");
  PRINT(file, _("Holes"));
  fprintf(file, "</td>\n");
- fprintf(file, "\t\t<td width=\"18%%\">");
+ fprintf(file, "\t\t<td width=\"13%%\">");
  PRINT(file, _("Warnings"));
  fprintf(file, "</td>\n");
- fprintf(file, "\t\t<td width=\"18%%\">");
+ fprintf(file, "\t\t<td width=\"13%%\">");
  PRINT(file, _("Notes"));
  fprintf(file, "</td>\n");
+ fprintf(file, "\t\t<td width=\"13%%\">");
+ PRINT(file, _("False Positives"));
+ fprintf(file, "</td>\n");
  while (dummy && dummy->next) {
   	int result;
-  	char * href = portname_to_ahref(NULL, dummy->name);
+  	char * href = html_output_portname_to_ahref(NULL, dummy->name);
 
 	/* The host name */
 	fprintf(file, "\t<tr>\n");
@@ -858,6 +667,11 @@ void pdf_summary_to_file(FILE *file, int be, struct arglist *hosts)
 		PRINT(file, _("Security note(s) found"));
 		fprintf(file, "</td>\n");
 	}
+  	else if(result == FALSE_PRESENT) {
+		fprintf(file, "\t\t<td>");
+		PRINT(file, _("False positive(s) found"));
+		fprintf(file, "</td>\n");
+	}
   	else {
 		fprintf(file, "\t\t<td>");
 		PRINT(file, _("No noticeable information found"));
@@ -871,6 +685,8 @@ void pdf_summary_to_file(FILE *file, int be, struct arglist *hosts)
 		number_of_warnings_by_host(dummy->value));
 	fprintf(file, "\t\t<td align=\"center\">%d</td>\n",
 	       	number_of_notes_by_host(dummy->value));
+	fprintf(file, "\t\t<td align=\"center\">%d</td>\n",
+	       	number_of_false_positives_by_host(dummy->value));
 	fprintf(file, "\t</tr>\n");
 	dummy = dummy->next;
  }
@@ -887,68 +703,140 @@ void pdf_summary_to_file(FILE *file, int be, struct arglist *hosts)
 	number_of_warnings(hosts));
  fprintf(file, "\t\t<td align=\"center\">%d</td>\n",
        	number_of_notes(hosts));
+ fprintf(file, "\t\t<td align=\"center\">%d</td>\n",
+       	number_of_false_positives(hosts));
  fprintf(file, "\t</tr>\n");
  fprintf(file, "</table>\n");
 }
 
 
 static void
-print_plugin_table_row(FILE *file, char *fieldname, char *text)
+print_plugin_table_row (FILE *file, char *fieldname, char *text)
 {
-  char *html = convert_cr_to_html(text);
-  fprintf(file, "\t<tr><th align=\"right\">%s</th>"
+  char *html = html_output_convert_cr_to_html(text);
+  fprintf(file, "\t<tr><td align=\"right\" valign=\"top\"><b>%s</b></td>"
       "<td>%s</td></tr>\n", fieldname, html);
   efree(&html);
 }
 
+
 static void
-print_prefs_row(FILE *file, char *pref, char *text)
+print_prefs_row (FILE *file, char *pref, char *text)
 {
-  char *pref_html = convert_cr_to_html(pref);
-  char *text_html = convert_cr_to_html(text);
+  char *pref_html = html_output_convert_cr_to_html(pref);
+  char *text_html = html_output_convert_cr_to_html(text);
     fprintf(file, "\t<tr><td><b>%s</b></th><td>%s</td></tr>\n",
 	pref_html, text_html);
   efree(&text_html);
   efree(&pref_html);
 }
 
+
+/**
+ * Prints names and trust level of signatures of a NVT in an unordered list in
+ * a table row with two cells (left hand cell will contain "Signed by:").
+ * Uses non-conform html list item tags not nested in a list, to force htmldoc 
+ * to insert bullets for them.
+ * 
+ * @param file File to write to.
+ * @param nvt Pointer to plugin as nessus_plugin struct.
+ * @param context The context used to retrieve certificate information.
+ */
+static void
+print_plugin_information_signatures (FILE* file, struct nessus_plugin* nvt, 
+                                     struct context* context)
+{
+  int idx = 0;
+  gchar** fprs;
+
+  if( nvt->sign_key_ids == NULL
+      || strcmp(nvt->sign_key_ids, "") == 0
+      || strcmp(nvt->sign_key_ids, "NOSIGNKEYS") == 0)
+    {
+    print_plugin_table_row(file, _("Signed by"), _("not signed"));
+    }
+  else if (context->signer_fp_certificates == NULL)
+  {
+    print_plugin_table_row(file, _("Signed by"), 
+                                 _("unknown signature(s)"));
+  }
+  else
+    {
+    /* fprs contains (comma separated) fingerprint(s) that are keys in 
+       the contexts hashtable. extract and look up */
+    fprs = g_strsplit_set(nvt->sign_key_ids, ",", -1);
+    // Start table row
+    fprintf(file, "\t<tr><td align=\"right\" valign=\"top\"><b>%s</b></td>"
+                  "<td align=\"left\">", _("Signed by"));
+
+    while (fprs[idx] != NULL)
+      {
+      openvas_certificate* cert = 
+                g_hash_table_lookup(context->signer_fp_certificates, fprs[idx]);
+      if(cert != NULL)
+        {
+        const char* trust = (cert->trusted == TRUE) ? _("trusted")
+                                              : _("not trusted");
+        char* text = g_strdup_printf ("%s (%s)", cert->ownername, trust);
+        // Print ownername and trustlevel in good (trusted, green) or bad color
+        fprintf(file, "<li><font color=\"%s\">%s</font></li>", 
+                      (cert->trusted == TRUE) ? "#006600" : "#660000", text);
+        g_free(text);
+        }
+      else
+        {
+        // Certificate not found in hashtable
+        fprintf(file, "<li><font color=\"%s\">%s</font></li>", 
+                                         "#660000", _("unknown signature"));
+        }
+      idx++;
+      }
+    // End the unordered list and table row 
+    fprintf(file, "\n\t</td></tr>\n");
+    g_strfreev(fprs);
+    }
+}
+
 static void
 print_plugin_information(gpointer key, gpointer value, gpointer userdata)
 {
   struct context *context = value;
   FILE *file = userdata;
-  char *plugin_id_str = key;
-  int plugin_id = atoi(plugin_id_str);
+  char *plugin_oid = key;
   struct nessus_plugin *plugin;
   char *description;
   char *html_description;
 
-  plugin = nessus_plugin_get_by_id(context->plugins, plugin_id);
+  plugin = nessus_plugin_get_by_oid(context->plugins, plugin_oid);
   if (plugin == NULL)
-    plugin = nessus_plugin_get_by_id(context->scanners, plugin_id);
+    plugin = nessus_plugin_get_by_oid(context->scanners, plugin_oid);
 
   if (plugin == NULL)
   {
-    fprintf(stderr, "print_plugin_information: no plugin with id %d\n",
-	plugin_id);
+    fprintf(stderr, "print_plugin_information: no plugin with oid %s\n",
+	plugin_oid);
     return;
   }
 
-  fprintf(file, "<H3><a name=\"nvt1.3.6.1.4.1.25623.1.0.%s\">NVT 1.3.6.1.4.1.25623.1.0.%d: %s</a></H3>\n\n",
-      plugin_id_str, plugin_id, plugin->name);
+  fprintf(file, "<H3><a name=\"nvt%s\">NVT %s: %s</a></H3>\n\n",
+      plugin_oid, plugin_oid, plugin->name);
 
   fprintf(file, "<table>\n");
   print_plugin_table_row(file, _("Summary"), plugin->summary);
   print_plugin_table_row(file, _("Category"), plugin->category);
   print_plugin_table_row(file, _("Family"), plugin->family);
   print_plugin_table_row(file, _("Version"), plugin->version);
-  print_plugin_table_row(file, _("CVE"), plugin->cve);
-  print_plugin_table_row(file, _("BID"), plugin->bid);
-  print_plugin_table_row(file, _("XRefs"), plugin->xrefs);
+  if(plugin->cve != NULL && strcmp(plugin->cve, "NOCVE") != 0)
+    print_plugin_table_row(file, _("CVE"), plugin->cve);
+  if(plugin->bid != NULL &&  strcmp(plugin->bid, "NOBID") != 0)
+    print_plugin_table_row(file, _("BID"), plugin->bid);
+  if(plugin->xrefs != NULL &&  strcmp(plugin->xrefs, "NOXREF") != 0)
+    print_plugin_table_row(file, _("XRefs"), plugin->xrefs);
+  print_plugin_information_signatures(file, plugin, context);
   fprintf(file, "</table>");
 
   description = nessus_plugin_get_description(plugin);
-  html_description = convert_cr_to_html(description);
+  html_description = html_output_convert_cr_to_html(description);
   PRINT1(file, "<p></p>\n<h4>%s</h4>\n", _("Description"));
   fputs(html_description, file);
   efree(&html_description);
@@ -979,6 +867,13 @@ print_plugin_information(gpointer key, gpointer value, gpointer userdata)
   }
 }
 
+
+/**
+ * Writes plugin information tables (in html) for a number of plugins.
+ * @param file The html file to write to.
+ * @param hash HashTable containing the nessus_plugins.
+ * @see print_plugin_information
+ */
 static void
 print_appendix(FILE *file, GHashTable *hash)
 {
@@ -986,6 +881,3 @@ print_appendix(FILE *file, GHashTable *hash)
 
   g_hash_table_foreach(hash, print_plugin_information, file);
 }
-
-
-
