@@ -26,10 +26,11 @@
  * do so, delete this exception statement from your version.
  */
 
-/* Cache for the plugin information read from the server
+/**
+ * \file
+ * Cache for the plugin information read from the server.
  *
- * File format
- * -----------
+ * @section plugincache-fileformat File format
  *
  * A plugin cache file consists of a number of lines, each holding a
  * number of fields.  The fields are separated by vertical bar
@@ -45,10 +46,12 @@
  * are the field separators.  So decoding can be done by first replacing
  * all | with NUL and then %-unescaping each field.  Unescaping never
  * makes the string longer and thus can be done in place.
+ * An example is given below.
  *
- * There are several kinds of lines, distinguished by the keyword:
+ * There are several kinds of lines, distinguished by keywords.
+ * For a healthy cache file they appear in the following order:
  *
- *   NessusClientPluginCache
+ *   OpenVASNVTDescCache
  *
  *     This is only and always used on the first line and also serves as
  *     a magic string identifying the file.  The following fields are in
@@ -60,11 +63,17 @@
  *      - the hex-encoded md5sum that was reported by the server for the
  *        set of plugins saved in the cache.
  *
- *   plugin
+ *   nvt
  *
- *     Plugin desription.  The rest of the fields are: id, md5sum, name,
+ *     NVT desription.  The rest of the fields are: oid, md5sum, name,
  *     category, copyright, description, summary, family, version, cve,
- *     bid, xrefs.
+ *     bid, xrefs, sign_key_ids.
+ *
+ *   dependency
+ *
+ *     Description of a dependency. Currently, in this line the plugins
+ *     are refered to by their respective name. Indication is that the
+ *     first plugin depends on the later.
  *
  *   end
  *
@@ -73,13 +82,18 @@
  *     considered outdated.
  *
  *
- * Files used
- * ----------
+ * @section plugincache-files-used Files used
  *
  * A cache file is specific for a given context and is stored in the
- * same directory as the nessusrc file for the context.  The cache for
- * the global context is ~/.openvas_plugin_cache.  If an alternate
- * nessurc file was given on the command line, no caching is done.
+ * same directory as the openvasrc file for the context.  The cache for
+ * the global context is ~/.openvas_nvt_cache.  If an alternate
+ * openvas file was given on the command line, no caching is done.
+ * 
+ * @section plugincache-example Examplary first two lines of a cache file
+ * 
+ * OpenVASNVTDescCache|2|fc8902a32651d93ab136e75977f664ec
+ * nvt|1.3.6.1.4.1.25623.1.0.11219|8e58495bf0130d4da02340a505b14041|SYN Scan|scanner|Copyright (C) Renaud Deraison \<deraison@cvs.nessus.org\>|%0aThis plugins performs a supposedly fast SYN port scan%0aIt does so by computing the RTT (round trip time) of the packets%0acoming back and forth between the openvasd host and the target,%0athen it uses that to quicky send SYN packets to the remote host%0a|Performs a TCP SYN scan|Port scanners|$Revision: 1266 $|NOCVE|NOBID|NOXREF|NOSIGNKEYS|NOTAG
+ *
  */
 
 #include <includes.h>
@@ -91,51 +105,50 @@
 #include "preferences.h"
 #include "globals.h"
 #include "plugin_cache.h"
-
+#include "nessus_i18n.h"
 
 /* file format constants */
 #define MAX_HEADER_ITEMS 3
-#define MAX_LINE_ITEMS 13
-#define HEADER_MAGIC "NessusClientPluginCache"
-#define FILE_FORMAT_VERSION 0
-#define PLUGIN_KEYWORD "plugin"
+#define MAX_LINE_ITEMS 15
+#define HEADER_MAGIC "OpenVASNVTDescCache"
+#define FILE_FORMAT_VERSION 2
+#define NVT_KEYWORD "nvt"
 #define DEP_KEYWORD "dependency"
 #define END_KEYWORD "end"
 
-/* Determine the cache file to use for the context.
+/**
+ * @brief Determine the cache file to use for the context.
  *
  * The cache file will be in the same directory as the nessusrc file of
- * the context.  The return value has to be free's with efree.
+ * the context.  The return value has to be free'd with efree.
  */
-char *
+gchar *
 plugin_cache_get_filename(struct context *context)
 {
   char *filename = NULL;
 
   if (context->dir)
   {
-    filename = emalloc(strlen(context->dir) + strlen("/nessus_plugin_cache")+1);
-    sprintf(filename, "%s/nessus_plugin_cache", context->dir);
+    filename = g_build_filename (context->dir, "openvas_nvt_cache", NULL);
   }
   else
   {
     char *home = prefs_get_nessushome();
-
-    filename = emalloc(strlen(home) + strlen("/.openvas_plugin_cache") + 1);
-    sprintf(filename, "%s/.openvas_plugin_cache", home);
+    filename = g_build_filename (home, ".openvas_nvt_cache", NULL);
   }
 
   return filename;
 }
 
 
-/* Write a string to the cache file
+/**
+ * @brief Write a string to the cache file.
  *
  * The parameter FILE is the stream to be used to write to the cache
  * file.  S is the NUL-terminated string to be written.  The bytes of S
  * are percent escaped (see file format description above).
  *
- * The return value is 0 on success and != 0 otherwise.
+ * @return Returns 0 on success and != 0 otherwise.
  */
 static int
 write_string(FILE *file, const char *s)
@@ -153,24 +166,25 @@ write_string(FILE *file, const char *s)
   return ferror(file) ? -1 : 0;
 }
 
-/* Write a record to the cache file
+/**
+ * @brief Write a record to the cache file.
  *
- * The parameter FILE is be the stream to be used to write to the cache
+ * The parameter FILE is the stream to be used to write to the cache
  * file.  FORMAT is a string containing one character for each of the
  * fields following the format parameter.  Two field types are
  * supported:
  *
- *   i   The value must be an int.  It written in a decimal.
- *   s   The value must be a NUL-terminated string.
- *       The string percent escaped while being written
- *   k   The value must be a NUL-terminated string.
+ *   i   (int) The value must be an int.  It is written in a decimal.
+ *   s   (string) The value must be a NUL-terminated string.
+ *       The string is percent-escaped while being written.
+ *   k   (keyword) The value must be a NUL-terminated string.
  *       The string is copied literally to the file
  *       and is not percent escaped.
  *
  * The values are written in percent-escaped form, separated by vertical
  * bars, followed by a newline to end the line/record.
  *
- * The return value is 0 on success and != 0 otherwise.
+ * @return Returns 0 on success and != 0 otherwise.
  */
 /* TODO: check for write errors */
 static int
@@ -213,20 +227,19 @@ write_record(FILE *file, const char *format, ...)
   }
   if (!failure)
     failure = putc('\n', file) == EOF;
-
   va_end(ap);
-
   return failure;
 }
 
 
-/* Write a plugin to the cache file
+/**
+ * @brief Write a plugin to the cache file.
  *
  * The parameter PLUGIN is the plugin to write and FILE is be the stream
  * to be used to write to the cache file.  The plugin is written as a
  * single record as described in the file format description.
  *
- * The return value is 0 on success and != 0 otherwise.
+ * @return Returns 0 on success and != 0 otherwise.
  */
 static int
 write_plugin(struct nessus_plugin *plugin, FILE *file)
@@ -234,21 +247,22 @@ write_plugin(struct nessus_plugin *plugin, FILE *file)
   char * md5sum = plugin->md5sum;
   if (md5sum == NULL)
     md5sum = "";
-
-  return write_record(file, "kisssssssssss", PLUGIN_KEYWORD,
-      plugin->id, md5sum, plugin->name, plugin->category, plugin->copyright,
+  return write_record(file, "kssssssssssssss", NVT_KEYWORD,
+      plugin->oid, md5sum, plugin->name, plugin->category, plugin->copyright,
       nessus_plugin_get_description(plugin), plugin->summary, plugin->family,
-      plugin->version, plugin->cve, plugin->bid, plugin->xrefs);
+      plugin->version, plugin->cve, plugin->bid, plugin->xrefs, 
+      plugin->sign_key_ids, plugin->script_tags);
 }
 
 
-/* Write a dependency to the cache file
+/**
+ * @brief Write a dependency to the cache file.
  *
  * The parameter DEP is the dependency to write and FILE is be the stream
  * to be used to write to the cache file.  The dependency is written as a
  * single record as described in the file format description.
  *
- * The return value is 0 on success and != 0 otherwise.
+ * @return Returns 0 on success and != 0 otherwise.
  */
 static int
 write_dep(struct arglist *dep, FILE *file)
@@ -263,13 +277,14 @@ write_dep(struct arglist *dep, FILE *file)
 }
 
 
-/* Write all plugins in the linked list PLUGINS
+/**
+ * @brief Write all plugins in the linked list PLUGINS.
  *
  * The parameter PLUGINS is the first plugin in the list of plugins to
  * write and FILE is be the stream to be used to write to the cache
  * file.  Each plugin is written with write_plugin.
  *
- * The return value is 0 on success and != 0 otherwise.
+ * @return Returns 0 on success and != 0 otherwise.
  */
 static int
 write_plugin_list(struct nessus_plugin *plugins, FILE *file)
@@ -284,13 +299,14 @@ write_plugin_list(struct nessus_plugin *plugins, FILE *file)
   return 0;
 }
 
-/* Write all dependencies in the linked list DEPS
+/**
+ * @brief Write all dependencies in the linked list DEPS.
  *
  * The parameter DEPS is the first dependency in the list of dependencies to
  * write and FILE is be the stream to be used to write to the cache
  * file. Each dependency is written with write_dep.
  *
- * The return value is 0 on success and != 0 otherwise.
+ * @return Returns 0 on success and != 0 otherwise.
  */
 static int
 write_deps_list(struct arglist *deps, FILE *file)
@@ -305,7 +321,8 @@ write_deps_list(struct arglist *deps, FILE *file)
   return 0;
 }
 
-/* Write the plugins in CONTEXT to a cache
+/**
+ * @brief Write the plugins in CONTEXT to a cache.
  *
  * The parameter CONTEXT is the context whose plugins are to be written.
  * The filename for the cache is determined with
@@ -315,15 +332,15 @@ write_deps_list(struct arglist *deps, FILE *file)
  * empty string for situations where the checking it will not be needed
  * such as when storing the plugins for a report.
  *
- * The return value is 0 on success and != 0 otherwise.
- *
  * If an error occurs when writing the file, the file is removed to
  * avoid incorrect caches lying around.
+ * 
+ * @return Returns 0 on success and != 0 otherwise.
  */
 int
 plugin_cache_write(struct context * context, const char * server_md5sum)
 {
-  char *filename;
+  gchar *filename;
   FILE *file;
   int failure = 0;
 
@@ -332,8 +349,8 @@ plugin_cache_write(struct context * context, const char * server_md5sum)
   file = fopen(filename, "w");
   if (!file)
   {
-    show_error("Could not open file '%s' for writing", filename);
-    efree(&filename);
+    show_error(_("Could not open file '%s' for writing plugin cache"), filename);
+    g_free (filename);
     return -1;
   }
 
@@ -349,20 +366,23 @@ plugin_cache_write(struct context * context, const char * server_md5sum)
 
   if (failure)
     unlink(filename);
-  efree(&filename);
+  g_free (filename);
 
   return failure;
 }
 
 
-/* Read one line from FILE
+/**
+ * @brief Read one line from FILE.
  *
  * The return value is a NUL-terminated string including the trailing
  * newline of the line if any.  The return value is allocated with
  * emalloc and has to be freed by the caller with efree.
- *
- * If an error occurrs this function returns NULL.  When the end of the
- * file is reached the function returns an empty string.
+ * When the end of the file is reached the function returns an empty string.
+ * 
+ * @return NULL if an error occured, empty string when end of file is reached
+ *         or the (nul-terminated) line of a file, including trailing newline if
+ *         any.
  */
 static char *
 read_line(FILE *file)
@@ -410,7 +430,8 @@ fail:
 }
 
 
-/* Split LINE at the vertical bars
+/**
+ * @brief Split LINE at the vertical bars.
  *
  * The NUL-terminated string LINE is split into fields at the vertical
  * bar characters ('|') by replacing the vertical bars with NUL
@@ -424,6 +445,8 @@ fail:
  * The return value is the number of fields found in the line.  This
  * number may be larger than NITEMS in which case the fields beyond the
  * first NITEMS fields won't be accesssible to the caller.
+ * 
+ * @return Number of fields found in the line.
  */
 static int
 split_line(char * line, char **items, int nitems)
@@ -466,10 +489,10 @@ split_line(char * line, char **items, int nitems)
       : ('a' <= (c) && c <= 'f') ? (c) - 'a' + 10\
       : -1)
 
-/* percent-unquote the NUL-terminated string S.
- *
- * Unquoting is done in place.
- * The return value is 0 on success and != 0 otherwise.
+/**
+ * @brief Percent-unquote a NUL-terminated string in place.
+ * 
+ * @return Returns 0 on success and != 0 otherwise.
  */
 static int
 unquote(char * s)
@@ -502,7 +525,8 @@ unquote(char * s)
 }
 
 
-/* Read a line from the cache file and decode it
+/**
+ * @brief Read a line from the cache file and decode it.
  *
  * The parameter FILE is the stread to the read the cache line from.
  * The parameters ITEMS and NITEMS are passed through to split_line and
@@ -523,6 +547,8 @@ unquote(char * s)
  * When an error occurs, the return value is -1.  The ITEMS array may
  * have been modified already in that case, but the memory the items now
  * point to is invalid.
+ * 
+ * @return Actual number of fields in a line, 0 on end of file, -1 on error.
  */
 static int
 read_cache_line(FILE * file, char **items, int nitems)
@@ -556,11 +582,13 @@ read_cache_line(FILE * file, char **items, int nitems)
   if (real_nitems <= 0)
     efree(&line);
 
+ 
   return real_nitems;
 }
 
 
-/* Read the file header
+/**
+ * @brief Read the file header.
  *
  * The file header is the first line of the file with the md5sum for the
  * md5sum originally reported by the server.
@@ -570,6 +598,8 @@ read_cache_line(FILE * file, char **items, int nitems)
  *
  * The md5sum will be stored in a string newly allocated with emalloc in
  * *server_md5sum.
+ * 
+ * @return Returns 0 on success, < 0 on error.
  */
 static int
 check_header(FILE * file, char ** server_md5sum)
@@ -618,7 +648,8 @@ check_header(FILE * file, char ** server_md5sum)
   return result;
 }
 
-/* Read the plugin cache and optionally check the md5sum for the cache
+/**
+ * @brief Read the plugin cache and optionally check the md5sum for the cache.
  *
  * CONTEXT is the context into which the cache should be read.
  * SERVER_MD5SUM should be the string with the hex-encoded md5sum
@@ -634,13 +665,16 @@ check_header(FILE * file, char ** server_md5sum)
  * If an error occurs the function returns a value < 0.  Otherwise if
  * the cache was current it returns 0 and a value > 0 if the cache was
  * outdated.
+ * 
+ * @return If the cache is current, returns 0. On outdated caches >0, on errors
+ *        <0.
  */
 int
 plugin_cache_read(struct context * context)
 {
   int result = 0;
   int end_found = 0;
-  char *filename;
+  gchar *filename;
   FILE *file;
   char *server_md5sum = NULL;
 
@@ -700,20 +734,21 @@ plugin_cache_read(struct context * context)
       efree(&items[0]);
       break;
     }
-
-    if (nitems == 13 && strcmp(items[0], PLUGIN_KEYWORD) == 0)
+    /* If the line has 14 items and first one is the nvt- keyword, parse a nvt*/
+    if (nitems == 15 && strcmp(items[0], NVT_KEYWORD) == 0)
     {
-      struct nessus_plugin *plugin = nessus_plugin_new(items[1] /*id*/,
+      struct nessus_plugin *plugin = nessus_plugin_new(items[1] /*oid*/,
 	  items[3] /*name*/, items[4] /*category*/, items[5] /*copyright*/,
 	  items[6] /*description*/, items[7] /*summary*/,
 	  items[8] /*family*/, items[9] /*version*/, items[10] /*cve*/,
-	  items[11] /*bid*/, items[12] /*xref*/);
-
+	  items[11] /*bid*/, items[12] /*xref*/, items[13] /*sign_key_ids*/,
+          items[14] /* script_tags*/ );
       /* add the md5sum */
       nessus_plugin_set_md5sum(plugin, items[2]);
 
       context_add_plugin(context, plugin);
     }
+    /* If there are three items in line && DEP-keyw. found, parse dependencies*/
     else if (nitems == 3 && strcmp(items[0], DEP_KEYWORD) == 0)
     {
       struct arglist *deps = arg_get_value(context->dependencies, items[1]);
@@ -746,7 +781,7 @@ plugin_cache_read(struct context * context)
   context_set_plugins_md5sum(context, server_md5sum);
 
  fail:
-  efree(&filename);
+  g_free (filename);
   efree(&server_md5sum);
   if (file != NULL)
     fclose(file);
