@@ -1,4 +1,4 @@
-/* Nessus
+/* OpenVAS
  * Copyright (C) 1998 - 2001 Renaud Deraison
  * Copyright (C) 2004 Intevation GmbH
  *
@@ -159,6 +159,7 @@ preferences_new (struct context* context)
     fprintf(f, "begin(SERVER_PREFS)\n");
     fprintf(f, " max_hosts = 20\n");
     fprintf(f, " max_checks = 4\n");
+    fprintf(f, " plugins_timeout = 320\n");
     /*
      * FIXME: see prefs_dialog_apply()
      * start of values from nessusd/preferences.c
@@ -824,6 +825,16 @@ prefs_has_options (struct context *context)
 static char *
 get_username(void)
 {
+#ifdef _WIN32
+  char *user;
+
+  /* Look up the user's name. */
+  user = getenv("USERNAME");
+  if(user)
+    return user;
+
+  return "";
+#else
   char *user;
   struct passwd *pwd;
 
@@ -841,18 +852,147 @@ get_username(void)
     return pwd->pw_name;
 
   return "";
+#endif
 }
 
+
+#ifdef _WIN32
+#include <windows.h>
+#include <shlobj.h>
+#include <io.h>
+
+#define OPENVAS_DEFAULT_HOMEDIR "c:\openvas"
+#define RTLD_LAZY 0
+
+static __inline__ void *
+dlopen (const char * name, int flag)
+{
+  void * hd = LoadLibrary (name);
+  return hd;
+}
+
+static __inline__ void *
+dlsym (void * hd, const char * sym)
+{
+  if (hd && sym)
+    {
+      void * fnc = GetProcAddress (hd, sym);
+      if (!fnc)
+        return NULL;
+      return fnc;
+    }
+  return NULL;
+}
+
+static __inline__ int
+dlclose (void * hd)
+{
+  if (hd)
+    {
+      FreeLibrary (hd);
+      return 0;
+    }
+  return -1;
+}  
+
+
+/* This is a helper function to load and run a Windows function from
+   either of one DLLs. */
+static HRESULT
+w32_shgetfolderpath (HWND a, int b, HANDLE c, DWORD d, LPSTR e)
+{
+  static int initialized;
+  static HRESULT (WINAPI * func)(HWND,int,HANDLE,DWORD,LPSTR);
+
+  if (!initialized)
+    {
+      static char *dllnames[] = { "shell32.dll", "shfolder.dll", NULL };
+      void *handle;
+      int i;
+
+      initialized = 1;
+
+      for (i=0, handle = NULL; !handle && dllnames[i]; i++)
+        {
+          handle = dlopen (dllnames[i], RTLD_LAZY);
+          if (handle)
+            {
+              func = dlsym (handle, "SHGetFolderPathA");
+              if (!func)
+                {
+                  dlclose (handle);
+                  handle = NULL;
+                }
+            }
+        }
+    }
+
+  if (func)
+    return func (a,b,c,d,e);
+  else
+    return -1;
+}
+
+#ifndef CSIDL_APPDATA
+#define CSIDL_APPDATA 0x001a
+#endif
+#ifndef CSIDL_LOCAL_APPDATA
+#define CSIDL_LOCAL_APPDATA 0x001c
+#endif
+#ifndef CSIDL_COMMON_APPDATA
+#define CSIDL_COMMON_APPDATA 0x0023
+#endif
+#ifndef CSIDL_FLAG_CREATE
+#define CSIDL_FLAG_CREATE 0x8000
+#endif
+
+/* Get the standard home directory.  This function does not consider a
+   registry value (under W32) or the environment variable.  */
+static char *
+standard_homedir (void)
+{
+  static char *dir;
+
+  if (!dir)
+    {
+      char path[MAX_PATH];
+
+      /* It might be better to use LOCAL_APPDATA because this is
+         defined as "non roaming" and thus more likely to be kept
+         locally.  For private keys this is desired.  However, given
+         that many users copy private keys anyway forth and back,
+         using a system roaming services might be better than to let
+         them do it manually.  A security conscious user will anyway
+         use the registry entry to have better control.  */
+      if (w32_shgetfolderpath (NULL, CSIDL_APPDATA|CSIDL_FLAG_CREATE,
+                               NULL, 0, path) >= 0) 
+        {
+      dir = malloc (strlen (path) + 1);
+      strcpy (dir, path);
+    }
+      else
+        dir = OPENVAS_DEFAULT_HOMEDIR;
+    }
+  return dir;
+}
+
+#endif
+
 char *
-prefs_get_nessushome (void)
+prefs_get_nessushome(void)
 {
   char *home;
-  struct passwd *pwd;
 
   home = getenv("NESSUSHOME");
   if (home)
     return home;
 
+#ifdef _WIN32
+  return standard_homedir ();
+#else
+
+  struct passwd *pwd;
+
   home = getenv ("HOME");
   if (home)
     return home;
@@ -862,4 +1002,5 @@ prefs_get_nessushome (void)
     return pwd->pw_dir;
 
   return "";
+#endif
 }
