@@ -104,8 +104,7 @@ extern severity_filter_t* global_filter;
 static void prefs_dialog_set_tooltips(struct arglist *);
 
 /**
- * Launch the users manual pdf document with the configured
- * pdf viewer.
+ * @brief Launch the users manual pdf document with the configured pdf viewer.
  */
 void
 show_users_manual (GtkWidget *menuitem, gpointer ctrls)
@@ -399,14 +398,11 @@ prefs_dialog_setup (struct context* context)
   struct arglist *prefs_report;
   struct arglist *ctrls = emalloc(sizeof(struct arglist));
 
-
   MainDialog = ctrls;
 
   create_nessus_icon_factory();
 
-/*
- * We draw the window ....
- */
+  /* We draw the window .... */
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_window_set_default_size(GTK_WINDOW(window), 1000, 630);
   g_signal_connect(G_OBJECT(window), "delete_event",
@@ -417,16 +413,14 @@ prefs_dialog_setup (struct context* context)
   gtk_window_set_title(GTK_WINDOW(window), _("OpenVAS-Client"));
   arg_add_value(ctrls, "WINDOW", ARG_PTR, -1, window);
   arg_add_value(ctrls, "CONTEXT", ARG_PTR, -1, window);
-  /*
-   * We put a vbox in it...
-   */
+
+  /* We put a vbox in it... */
   box = gtk_vbox_new(FALSE, 0);
   gtk_container_add(GTK_CONTAINER(window), box);
   gtk_widget_show(box);
 
-/*
- * Main menu
- */
+
+  /* Main menu */
   accel_group = gtk_accel_group_new();
   gtk_window_add_accel_group(GTK_WINDOW(window), accel_group);
 
@@ -618,10 +612,7 @@ prefs_dialog_setup (struct context* context)
 
 
 
-
-
 /* hbox with toolbar+scopetree-vbox and notebook */
-
   hbox = gtk_hbox_new(FALSE, 4);
   gtk_widget_show(hbox);
   gtk_box_pack_start(GTK_BOX(box), hbox, TRUE, TRUE, 0);
@@ -638,9 +629,7 @@ prefs_dialog_setup (struct context* context)
   gtk_widget_show(vbox);
   gtk_container_add(GTK_CONTAINER(hpaned), vbox);
 
-/*
- * The Toolbar
- */
+  /* The Toolbar */
   toolbar = gtk_toolbar_new();
   gtk_widget_show(toolbar);
   gtk_box_pack_start(GTK_BOX(vbox), toolbar, FALSE, FALSE, 0);
@@ -709,37 +698,27 @@ prefs_dialog_setup (struct context* context)
   gtk_widget_show(GTK_WIDGET(tool_button));
   arg_add_value(ctrls, "EXECSCOPE_BUTTON", ARG_PTR, -1, tool_button);
 
-/*
- * The Scope Tree
- */
-
+  /* The Scope Tree */
   prefs_scope_tree = prefs_dialog_scope_tree(context);
   frame = arg_get_value(prefs_scope_tree, "FRAME");
   gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 0);
   arg_add_value(ctrls, "SCOPETREE", ARG_PTR, -1, prefs_scope_tree);
 
-/*
- * The Context Frame
- */
-
+  /* The Context Frame */
   frame = gtk_frame_new(NULL);
   gtk_frame_set_label(GTK_FRAME(frame), _("Context"));
   gtk_widget_show(frame);
   gtk_container_add(GTK_CONTAINER(hpaned), frame);
   arg_add_value(ctrls, "CONTEXTFRAME", ARG_PTR, -1, frame);
 
-/*
- * The Context Notebook
- */
+  /* The Context Notebook */
   notebook = gtk_notebook_new();
   gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_TOP);
   gtk_container_add(GTK_CONTAINER(frame), notebook);
   gtk_widget_show(notebook);
   arg_add_value(ctrls, "CONTEXTNOTEBOOK", ARG_PTR, -1, notebook);
 
-/*
- * We set up the pages of our notebook
- */
+  /* We set up the pages of our notebook */
   prefs_comment = prefs_dialog_comment();
   prefs_options = prefs_dialog_options(context, ctrls);
   prefs_report = prefs_dialog_report();
@@ -748,9 +727,7 @@ prefs_dialog_setup (struct context* context)
   arg_add_value(ctrls, "OPTIONS", ARG_ARGLIST, -1, prefs_options);
   arg_add_value(ctrls, "REPORT", ARG_ARGLIST, -1, prefs_report);
 
-/*
- * and we append them to it
- */
+  /* and we append them to it  */
 
   /* Tab "Comments" */
   label = gtk_label_new(_("Comments"));
@@ -773,9 +750,8 @@ prefs_dialog_setup (struct context* context)
   g_signal_connect_after(G_OBJECT(notebook), "switch-page",
       G_CALLBACK(prefs_context_switch_notebookpage), NULL);
 
-/*
- * Message Log
- */
+
+  /* Message Log */
 
   /* The frame */
   msglogframe = gtk_frame_new(NULL);
@@ -806,13 +782,13 @@ prefs_dialog_setup (struct context* context)
   gtk_container_add(GTK_CONTAINER(scrolledwindow), textview);
   gtk_text_view_set_editable(GTK_TEXT_VIEW(textview), FALSE);
   gtk_text_buffer_set_text(gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
-      _("Welcome to OpenVAS-Client, http://www.openvas.org/"
-	"\nNessusClient origin: Copyright 1998-2007 by Renaud Deraison"
-	"\nNew code since OpenVAS-Client: Copyright 2007, 2008, 2009 Intevation GmbH"
-	"\nAuthors: Renaud Deraison, Thomas Arendsen Hein, Jan-Oliver Wagner"
-	", Bernhard Herzog, Michel Arboi (SSL-Support), Bruce Verderaime (Pie/Charts)"
-        ", Michael Wiegand, Felix Wolfsteller"
-	"\n"),
+    _("Welcome to OpenVAS-Client, http://www.openvas.org/"
+      "\nNessusClient origin: Copyright 1998-2007 by Renaud Deraison"
+      "\nNew code since OpenVAS-Client: Copyright 2007, 2008, 2009 Intevation GmbH"
+      "\nAuthors: Renaud Deraison, Thomas Arendsen Hein, Jan-Oliver Wagner"
+      ", Bernhard Herzog, Michel Arboi (SSL-Support), Bruce Verderaime (Pie/Charts)"
+      ", Michael Wiegand, Felix Wolfsteller"
+      "\n"),
       -1);
   arg_add_value(ctrls, "MSGLOGTEXT", ARG_PTR, -1, textview);
 
@@ -820,9 +796,7 @@ prefs_dialog_setup (struct context* context)
   gtk_widget_hide(msglogframe);
 
 
-/*
- * Status bar
- */
+  /* Status bar */
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_widget_show(hbox);
   gtk_box_pack_end(GTK_BOX(box), hbox, FALSE, TRUE, 0);
@@ -852,9 +826,7 @@ prefs_dialog_setup (struct context* context)
   gtk_box_pack_start(GTK_BOX(hbox), icon, FALSE, TRUE, 0);
   arg_add_value(ctrls, "CONNECT_IMAGE", ARG_PTR, -1, icon);
 
-/*
- * Final
- */
+  /* Final */
   menuitem = arg_get_value(ctrls, "TOGGLETOOLBAR_MENUITEM");
   gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem),
       !prefs_get_int(Global, "hide_toolbar"));
@@ -874,12 +846,16 @@ prefs_dialog_setup (struct context* context)
  * @brief key existed as ARG_INT before.
  *
  * @param preferences    Preferences arglist.
+ *
  * @param prefrence_name Key to look for and eventually set to "yes" or no.
+ *
+ * @return The value of the preference as string (do not free it).
  */
-static void
-arg_int_to_yesno(struct arglist* preferences, char* preference_name)
+static char*
+arg_int_to_yesno (struct arglist* preferences, const char* preference_name)
 {
   char* value = arg_get_value (preferences, preference_name);
+
   if (arg_get_type (preferences, preference_name) == ARG_INT)
   {
     char *yesno = (value) ? estrdup("yes") : estrdup("no");
@@ -887,7 +863,51 @@ arg_int_to_yesno(struct arglist* preferences, char* preference_name)
     /* RATS: ignore yesno is nul-terminated because of strdup of string literal*/
     arg_set_value (preferences, preference_name, strlen(yesno), yesno);
     arg_set_type  (preferences, preference_name, ARG_STRING);
+    return yesno;
   }
+
+  return value;
+}
+
+/**
+ * @brief Sets the state of a togglebutton according to a preference value and
+ * @brief possibly changes the pref value (to represent "yes"/"no" as strings).
+ *
+ * @param ctrls Arglist where the toggle-button is hooked into.
+ *
+ * @param togglebuttonkey Key for toggle button in arglist (param) ctrls.
+ *
+ * @param prefs Arglist holding the preferences.
+ *
+ * @param prefkey Key (preference name) of preference value in arlist (param)
+ *                prefs.
+ *
+ * @return TRUE if togglebutton was set according to a preferences value, FALSE
+ *         otherwise.
+ */
+static gboolean
+set_toggle_from_pref (struct arglist* ctrls,
+                      const char* togglebuttonkey,
+                      struct arglist* prefs,
+                      const char* prefkey
+                      )
+{
+  GtkWidget* togglebutton = arg_get_value (ctrls, togglebuttonkey);
+  char* value;
+
+  if (!togglebutton)
+    return FALSE;
+
+  // If we see yes/no represented as int, change it into "yes" or "no" and
+  // set the type of this key/value-pair to type_string.
+  value = arg_int_to_yesno (prefs, prefkey);
+
+  if (value && !strcmp(value, "yes"))
+    GTK_TOGGLE_BUTTON(togglebutton)->active = TRUE;
+  else
+    GTK_TOGGLE_BUTTON(togglebutton)->active = FALSE;
+
+  return TRUE;
 }
 
 /**
@@ -906,47 +926,25 @@ prefs_dialog_set_defaults (struct context *context, struct arglist *ctrls)
   int flag = 0;
   GtkWidget *gtkw;
 
-
   serv = arg_get_value(context->prefs, "SERVER_PREFS");
   if(!serv)
     return;
 
-
   t = arg_get_value(ctrls, "PLUGINS");
-  gtkw = arg_get_value(t, "ENABLE_DEPS_AT_RUNTIME");
-  if(gtkw)
-  {
-    v = arg_get_value(serv, "auto_enable_dependencies");
-    if(arg_get_type(serv, "auto_enable_dependencies") == ARG_INT)
-    {
-      char *s = strdup(v ? "yes" : "no");
 
-      arg_set_type(serv, "auto_enable_dependencies", ARG_STRING);
-      arg_set_value(serv, "auto_enable_dependencies", strlen(s), s); /* RATS: ignore s is yes or no and nul terminated */
-      v = s;
-    }
-    if(v && !strcmp(v, "yes"))
-      GTK_TOGGLE_BUTTON(gtkw)->active = TRUE;
-    else
-      GTK_TOGGLE_BUTTON(gtkw)->active = FALSE;
-  }
-  gtkw = arg_get_value(t, "SILENT_DEPS");
-  if(gtkw)
-  {
-    v = arg_get_value(serv, "silent_dependencies");
-    if(arg_get_type(serv, "silent_dependencies") == ARG_INT)
-    {
-      char *s = strdup(v ? "yes" : "no");
+  set_toggle_from_pref (t, "ENABLE_DEPS_AT_RUNTIME", serv, "auto_enable_dependencies");
+  set_toggle_from_pref (t, "SILENT_DEPS", serv, "silent_dependencies");
 
-      arg_set_type(serv, "silent_dependencies", ARG_STRING);
-      arg_set_value(serv, "silent_dependencies", strlen(s), s); /* RATS: ignore s is yes or no and nul terminated */
-      v = s;
+  gtkw = arg_get_value (t, "GLOBAL_NVT_TIMEOUT");
+  if(gtkw)
+    {
+      v = arg_get_value(serv, "plugins_timeout");
+      if(v)
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON(gtkw), atof(v));
     }
-    if(v && !strcmp(v, "yes"))
-      GTK_TOGGLE_BUTTON(gtkw)->active = TRUE;
-    else
-      GTK_TOGGLE_BUTTON(gtkw)->active = FALSE;
-  }
+
+  // Not using set_toggle_from_pref because the preferences type (int) shall not
+  // be changed
   gtkw = arg_get_value(t, "AUTO_ENABLE_NEW_PLUGINS");
   if(gtkw)
   {
@@ -957,9 +955,7 @@ prefs_dialog_set_defaults (struct context *context, struct arglist *ctrls)
       GTK_TOGGLE_BUTTON(gtkw)->active = FALSE;
   }
 
-  /*
-   *  Host expansion options
-   */
+  /* Host expansion options */
   t = arg_get_value(ctrls, "TARGET");
   gtk_entry_set_text(GTK_ENTRY(arg_get_value(t, "TARGET")),
       prefs_get_string(context, "targets"));
@@ -986,48 +982,14 @@ prefs_dialog_set_defaults (struct context *context, struct arglist *ctrls)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), (flag & EX_DNS));
   }
 
-  /*
-   * Scan options 
-   */
+  /* Scan options */
   t = arg_get_value(ctrls, "SCAN_OPTIONS");
-  gtkw = arg_get_value(t, "PING_HOSTS");
-  arg_int_to_yesno(serv, "ping_hosts");
-  v = arg_get_value(serv, "ping_hosts");
-  if(v)
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw), !strcmp(v, "yes"));
 
-  gtkw = arg_get_value(t, "REVERSE_LOOKUP");
-  arg_int_to_yesno(serv, "reverse_lookup");
-  v = arg_get_value(serv, "reverse_lookup");
-  if(v)
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw), !strcmp(v, "yes"));
-
-
-  gtkw = arg_get_value(t, "OPTIMIZE_TEST");
-  arg_int_to_yesno(serv, "optimize_test");
-  v = arg_get_value(serv, "optimize_test");
-  if(v)
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw), !strcmp(v, "yes"));
-  else
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw), 1);
-
-
-  gtkw = arg_get_value(t, "SAFE_CHECKS");
-  arg_int_to_yesno(serv, "safe_checks");
-  v = arg_get_value(serv, "safe_checks");
-  if(v)
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw), !strcmp(v, "yes"));
-  else
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw), 1);
-
-
-  gtkw = arg_get_value(t, "USE_MAC_ADDR");
-  arg_int_to_yesno(serv, "use_mac_addr");
-  v = arg_get_value(serv, "use_mac_addr");
-  if(v)
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw), !strcmp(v, "yes"));
-  else
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw), 0);
+  set_toggle_from_pref (t, "PING_HOSTS", serv, "ping_hosts");
+  set_toggle_from_pref (t, "REVERSE_LOOKUP", serv, "reverse_lookup");
+  set_toggle_from_pref (t, "OPTIMIZE_TEST", serv, "optimize_test");
+  set_toggle_from_pref (t, "SAFE_CHECKS", serv, "safe_checks");
+  set_toggle_from_pref (t, "USE_MAC_ADDR", serv, "use_mac_addr");
 
   v = arg_get_value(serv, "port_range");
   if(v)
@@ -1037,31 +999,7 @@ prefs_dialog_set_defaults (struct context *context, struct arglist *ctrls)
       gtk_entry_set_text(GTK_ENTRY(gtkw), v);
   }
 
-  gtkw = arg_get_value(t, "UNSCANNED_CLOSED");
-  v = arg_get_value(serv, "unscanned_closed");
-  if(arg_get_type(serv, "unscanned_closed") == ARG_INT)
-  {
-
-    char *s;
-    int v;
-
-    v = GPOINTER_TO_SIZE(arg_get_value(serv, "unscanned_closed"));
-    if(v)
-      s = strdup("yes");
-    else
-      s = strdup("no");
-
-    arg_set_value(serv, "unscanned_closed", strlen(s), s);
-    arg_set_type(serv, "unscanned_closed", ARG_STRING);
-  }
-  v = arg_get_value(serv, "unscanned_closed");
-
-  if(v)
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw), !strcmp(v, "yes"));
-  else
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw), 0);
-
-
+  set_toggle_from_pref (t, "UNSCANNED_CLOSED", serv, "unscanned_closed");
 
   gtkw = arg_get_value(t, "MAX_HOSTS");
   if(gtkw)
@@ -1087,9 +1025,7 @@ prefs_dialog_set_defaults (struct context *context, struct arglist *ctrls)
       gtk_entry_set_text(GTK_ENTRY(gtkw), v);
   }
 
-  /*
-   * User
-   */
+  /* User */
   fill_rules_list(context, arg_get_value(MainDialog, "USER"));
 
 #ifdef ENABLE_SAVE_KB
@@ -1122,6 +1058,9 @@ prefs_dialog_set_tooltips (struct arglist *ctrls)
   w = arg_get_value(t, "AUTO_ENABLE_NEW_PLUGINS");
   gtk_tooltips_set_tip(tooltips, w, HLP_AUTO_ENABLE_NEW_PLUGINS, "");
 
+  w = arg_get_value(t, "GLOBAL_NVT_TIMEOUT");
+  gtk_tooltips_set_tip(tooltips, w, HLP_AUTO_GLOBAL_NVT_TIMEOUT, "");
+
   t = arg_get_value(ctrls, "TARGET");
   w = arg_get_value(t, "DNS_EXPAND");
   gtk_tooltips_set_tip(tooltips, w, HLP_HOST_EXPANSION_DNS, "");
@@ -1157,12 +1096,14 @@ prefs_dialog_set_tooltips (struct arglist *ctrls)
   w = arg_get_value(t, "MAX_CHECKS");
   gtk_tooltips_set_tip(tooltips, w, HLP_MISC_MAX_CHECKS, "");
   w = arg_get_value(t, "CGI_PATH");
+
   gtk_tooltips_set_tip(tooltips, w, HLP_CGI_PATH, "");
   // FIXME suspect tooltip for following item is missing:
   t = arg_get_value(ctrls, "USER");
   gtk_tooltips_enable(tooltips);
 }
 
+
 /**
  * @brief Sets a string in a preference arglist as either "yes" or "no",
  * @brief depending on the state (active -> "yes") of a togglebutton.
@@ -1179,12 +1120,12 @@ set_yesno_pref_from_toggle (struct arglist* preferences, GtkWidget* togglebutton
  if(togglebutton)
   {
     char *value;
-  
+
     if(GTK_TOGGLE_BUTTON(togglebutton)->active)
       value = estrdup("yes");
     else
       value = estrdup("no");
-  
+
     if(arg_get_value(preferences, preference_name))
       arg_set_value(preferences, preference_name, strlen(value), value); /* RATS: ignore */
     else
@@ -1193,6 +1134,7 @@ set_yesno_pref_from_toggle (struct arglist* preferences, GtkWidget* togglebutton
   }
 }
 
+
 /**
  * @brief Applies user choices to a context (and its preferences etc.).
  * 
@@ -1219,10 +1161,9 @@ prefs_dialog_apply (struct context *context, struct arglist *ctrls)
    * FIXME:
    * Only try to save values if GTK widgets were changed.
    * Otherwise prefs_dialog_set_defaults can't set default
-   * values from server.
-   */
+   * values from server. */
 
-  bzero(expansion, 30);
+  bzero (expansion, 30);
   prefs = context->prefs;
   serv = arg_get_value(prefs, "SERVER_PREFS");
   if(!serv)
@@ -1231,36 +1172,41 @@ prefs_dialog_apply (struct context *context, struct arglist *ctrls)
     arg_add_value(prefs, "SERVER_PREFS", ARG_ARGLIST, -1, serv);
   }
 
-
   t = arg_get_value(ctrls, "PLUGINS");
-  
+
   gtkw = arg_get_value(t, "ENABLE_DEPS_AT_RUNTIME");
   set_yesno_pref_from_toggle(serv, gtkw, "auto_enable_dependencies");
-  
+
   gtkw = arg_get_value(t, "SILENT_DEPS");
   set_yesno_pref_from_toggle(serv, gtkw, "silent_dependencies");
-  
+
+  gtkw = arg_get_value(t, "GLOBAL_NVT_TIMEOUT");
+  s = g_strdup (gtk_entry_get_text(GTK_ENTRY(gtkw)));
+
+  if(arg_get_value(serv, "plugins_timeout"))
+    arg_set_value(serv, "plugins_timeout", strlen(s), s);
+  else
+    arg_add_value(serv, "plugins_timeout", ARG_STRING, strlen(s), s);
+
   gtkw = arg_get_value(t, "AUTO_ENABLE_NEW_PLUGINS");
   if(gtkw)
   {
     if(GTK_TOGGLE_BUTTON(gtkw)->active)
-      prefs_set_int(context,"auto_enable_new_plugins",1);
+      prefs_set_int(context,"auto_enable_new_plugins", 1);
     else
-      prefs_set_int(context,"auto_enable_new_plugins",0);
+      prefs_set_int(context,"auto_enable_new_plugins", 0);
   }
 
-  /*
-   * Host expansion
-   */
+  /* Host expansion */
   t = arg_get_value(ctrls, "TARGET");
   gtkw = arg_get_value(t, "DNS_EXPAND");
   if(GTK_TOGGLE_BUTTON(gtkw)->active)
-    strcat(expansion, "dns;");
+    strcat (expansion, "dns;");
 
   strcat(expansion, "ip;");
 
-  if(!strlen(expansion))
-    strncpy(expansion, "none;", 5);
+  if (!strlen(expansion))
+    strncpy (expansion, "none;", 5);
   expansion[strlen(expansion) - 1] = 0;
 
   s = (char *)gtk_entry_get_text(GTK_ENTRY(arg_get_value(t, "TARGET")));
@@ -1292,8 +1238,6 @@ prefs_dialog_apply (struct context *context, struct arglist *ctrls)
   gtkw = arg_get_value(t, "SAFE_CHECKS");
   set_yesno_pref_from_toggle(serv, gtkw, "safe_checks");
 
-
-
   gtkw = arg_get_value(t, "USE_MAC_ADDR");
   set_yesno_pref_from_toggle(serv, gtkw, "use_mac_addr");
 
@@ -1306,11 +1250,9 @@ prefs_dialog_apply (struct context *context, struct arglist *ctrls)
   else
     arg_add_value(serv, "port_range", ARG_STRING, strlen(s), s);
 
-
   gtkw = arg_get_value(t, "UNSCANNED_CLOSED");
   set_yesno_pref_from_toggle(serv, gtkw, "unscanned_closed");
 
-
   gtkw = arg_get_value(t, "MAX_HOSTS");
 
   s = estrdup (gtk_entry_get_text(GTK_ENTRY(gtkw)));
@@ -1322,7 +1264,6 @@ prefs_dialog_apply (struct context *context, struct arglist *ctrls)
 
 
   gtkw = arg_get_value(t, "MAX_CHECKS");
-
   s = g_strdup (gtk_entry_get_text(GTK_ENTRY(gtkw)));
 
   if(arg_get_value(serv, "max_checks"))
@@ -1330,7 +1271,6 @@ prefs_dialog_apply (struct context *context, struct arglist *ctrls)
   else
     arg_add_value(serv, "max_checks", ARG_STRING, strlen(s), s);
 
-
   gtkw = arg_get_value(t, "CGI_PATH");
   s = estrdup((char *)gtk_entry_get_text(GTK_ENTRY(gtkw)));
 
@@ -1346,11 +1286,9 @@ prefs_dialog_apply (struct context *context, struct arglist *ctrls)
 #endif
 
 
-  /*
-   * Client-side User Access Rules
+  /* Client-side User Access Rules
    * Get them out of the USRER->RULES_TREE and push them into
-   * context->prefs->CLIENTSIDE_USERRULES
-   */
+   * context->prefs->CLIENTSIDE_USERRULES */
   t = arg_get_value(ctrls, "USER");
   gtkw = arg_get_value(t, "RULES_TREE");
   if (gtkw)
@@ -1362,7 +1300,7 @@ prefs_dialog_apply (struct context *context, struct arglist *ctrls)
     char * rule, * name = NULL;
     struct arglist * clientside_userrules;
 
-    /* first of all, remove the old stuff */
+    /* First of all, remove the old stuff */
     clientside_userrules = emalloc(sizeof(struct arglist));
     if (arg_get_value(prefs, "CLIENTSIDE_USERRULES"))
     {
@@ -1374,7 +1312,7 @@ prefs_dialog_apply (struct context *context, struct arglist *ctrls)
 
     store = gtk_tree_view_get_model(GTK_TREE_VIEW(gtkw));
 
-    /* go to the third entry */
+    /* Go to the third entry */
     path = gtk_tree_path_new_from_string("2:0");
     if (gtk_tree_model_get_iter(store, &iter, path))
     {
@@ -1400,7 +1338,7 @@ prefs_dialog_apply (struct context *context, struct arglist *ctrls)
  * @returns Plugin preference string for a radiobutton selection.
  */
 static char*
-get_plugin_radio_pref(GSList* list, struct arglist* pref)
+get_plugin_radio_pref (GSList* list, struct arglist* pref)
 {
   char* value = NULL;
   /* First pass: find the active entry */
@@ -1529,24 +1467,21 @@ prefs_dialog_execute (GtkWidget* w, struct arglist* ctrls)
   prefs_dialog_apply_plugin_prefs(context->scanners);
   context_sync_plugin_prefs(context);
 
-  /*
-   * Check for the errors
-   */
-
+  /* Check for the errors */
   if(!prefs_dialog_auth_connection(context))
     return (0);
 
-  /* if the target is a file, then translate it */
+  /* If the target is a file, then translate it */
   hostname = target_translate(prefs_get_string(context, "targets"));
 
   if(hostname == NULL || hostname[0] == '\0')
   {
-    show_error(_("You must enter the name of the primary target\n\
-to attack in the 'target' section"));
+    show_error(_("You must enter the name or IP of the target(s)\n\
+to attack in the 'Target' section."));
     return (0);
   }
 
-  monitor_dialog_setup(hostname, context);
+  monitor_dialog_setup (hostname, context);
 
   return (0);
 }
