@@ -89,7 +89,7 @@ prefs_dialog_auth_defaultport_clicked(button, auth)
   struct auth_dialog *auth;
 {
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(auth->port),
-      (int)prefs_get_default(auth->context, "nessusd_port"));
+      GPOINTER_TO_SIZE(prefs_get_default(auth->context, "nessusd_port")));
 }
 
 void
@@ -582,7 +582,7 @@ prefs_dialog_auth_connect(menuitem, ctrls)
   prefs_dialog_auth_connect_dialog(Context, ctrls);
 }
 
-/*
+/**
  * Try connecting if not already connected and context->passwd is
  * available. passwd may be empty (but != NULL) for user certificates.
  * If this fails, raise the login dialog.
