@@ -36,10 +36,11 @@
 #include "prefs_dialog_plugins_prefs.h"
 #include "listnotebook.h"
 #include "readonly.h"
+#include "error_dlg.h"
+#include "nvt_pref_sshlogin.h"
 
 #include "nessus_i18n.h"
 
-
 static GtkWidget * pprefs_add_notebook_page(struct arglist *, char *, int);
 static void pprefs_add_entry(struct arglist *, struct arglist *, char *, GtkWidget*);
 static void pprefs_add_password(struct arglist *, struct arglist *, char *, GtkWidget*);
@@ -47,11 +48,15 @@ static void pprefs_add_file(struct arglist *, struct arglist *, char *, GtkWidge
 static void pprefs_add_checkbox(struct arglist *, struct arglist *, char *, GtkWidget*);
 static void pprefs_add_radio(struct arglist *, struct arglist *, char *, GtkWidget*);
 
-
-
+/**
+ * Adds and hooks up (or resets) the two notebook pages for Plugin Preferences 
+ * and Credentials.
+ * These pages are itself notebooks with dynamical content.
+ * 
+ * @param ctrls Arglist to hook the notebooks into.
+ */
 static void
-create_plugin_prefs_containers(ctrls)
-  struct arglist *ctrls;
+create_plugin_prefs_containers(struct arglist* ctrls)
 {
   GtkWidget *listnotebook, *cred_listnotebook;
 
@@ -77,7 +82,12 @@ create_plugin_prefs_containers(ctrls)
   }
 }
 
-
+/**
+ * Creates "Advanced Plugins preferences" and  "Credentials" frames.
+ * Calls create_plugin_prefs_containers to init content in them.
+ * 
+ * @return Arglist with Plugins preferences and Credentials hooked into.
+ */
 struct arglist *
 prefs_dialog_plugins_prefs()
 {
@@ -91,7 +101,6 @@ prefs_dialog_plugins_prefs()
   arg_add_value(ctrls, "FRAME", ARG_PTR, -1, frame);
   read_only_set_recurse(frame);
 
-
   cred_frame = gtk_frame_new(_("Credentials"));
   gtk_container_border_width(GTK_CONTAINER(cred_frame), 10);
   gtk_widget_show(cred_frame);
@@ -110,21 +119,34 @@ prefs_dialog_plugins_prefs()
   return (ctrls);
 }
 
-
+/**
+ * @brief Sets the preference frame and the credentials frame readonly.
+ * 
+ * @param ctrls Arglist where the FRAME and FRAME_CREDENTIALS are hooked in.
+ * @param readonly If true, frames are set readonly.
+ */
 void
-prefs_dialog_plugins_prefs_read_only(struct arglist *ctrls, gboolean readonly)
+prefs_dialog_plugins_prefs_read_only( struct arglist *ctrls, gboolean readonly)
 {
-  read_only_set_read_only(GTK_WIDGET(arg_get_value(ctrls, "FRAME")),
-      readonly);
-  read_only_set_read_only(GTK_WIDGET(arg_get_value(ctrls,
-	      "FRAME_CREDENTIALS")), readonly);
+  read_only_set_read_only (GTK_WIDGET(arg_get_value (ctrls, "FRAME")), readonly);
+  read_only_set_read_only (GTK_WIDGET(arg_get_value(ctrls, "FRAME_CREDENTIALS")),
+                           readonly);
 }
 
+/**
+ * @brief Fill the credentials and plugin preferences pages with the corresponding 
+ *        widgets and values.
+ * 
+ * Widgets are added dynamically, based on the plugin preference type, e.g.
+ * for a PREF_CHECKBOX pprefs_add_checkbox() is called.
+ * 
+ * @param context The context to use.
+ * @param ctrls Arglist holding the notebook page widgets.
+ * @param plugins Plugin list.
+ */
 void
-prefs_dialog_plugins_prefs_fill(context, ctrls, plugins)
-  struct context *context;
-  struct arglist *ctrls;
-  struct nessus_plugin *plugins;
+prefs_dialog_plugins_prefs_fill (struct context* context, struct arglist* ctrls,
+                                 struct nessus_plugin* plugins)
 {
   struct arglist *pprefs = arg_get_value(context->prefs, "PLUGINS_PREFS");
   struct nessus_plugin *plugs = plugins;
@@ -144,28 +166,30 @@ prefs_dialog_plugins_prefs_fill(context, ctrls, plugins)
       {
         notebook_vbox = pprefs_add_notebook_page(ctrls, plugs->name, 1);
       }
-
+      // For each preference of this plugin, add the widget.
       while(prefs && prefs->next)
       {
 	char *type, *value;
-	GtkWidget *vbox;
-
-        vbox = notebook_vbox;
 
 	type = arg_get_value(prefs->value, "type");
 	value = arg_get_value(prefs->value, "value");
 	if(type)
 	{
 	  if(!strcmp(type, PREF_ENTRY))
-	    pprefs_add_entry(pprefs, prefs, value, vbox);
+	    pprefs_add_entry(pprefs, prefs, value, notebook_vbox);
 	  else if(!strcmp(type, PREF_PASSWORD))
-	    pprefs_add_password(pprefs, prefs, value, vbox);
+	    pprefs_add_password(pprefs, prefs, value, notebook_vbox);
 	  else if(!strcmp(type, PREF_RADIO))
-	    pprefs_add_radio(pprefs, prefs, value, vbox);
+	    pprefs_add_radio(pprefs, prefs, value, notebook_vbox);
 	  else if(!strcmp(type, PREF_CHECKBOX))
-	    pprefs_add_checkbox(pprefs, prefs, value, vbox);
+	    pprefs_add_checkbox(pprefs, prefs, value, notebook_vbox);
 	  else if(!strcmp(type, PREF_FILE))
-	    pprefs_add_file(pprefs, prefs, value, vbox);
+	    pprefs_add_file(pprefs, prefs, value, notebook_vbox);
+          else if(!strcmp(type, PREF_SSH_CREDENTIALS))
+            nvt_pref_sshlogin_add(notebook_vbox, prefs);
+          else
+            show_warning(_("%s asked for unknown preference type %s."), 
+                         plugs->name, type);
 	}
 	prefs = prefs->next;
       }
@@ -174,14 +198,12 @@ prefs_dialog_plugins_prefs_fill(context, ctrls, plugins)
   }
 }
 
-/*
+/**
  * Clean up the plugin preferences and plugin
  * preferences widgets
  */
 void
-prefs_plugins_reset(ctrls, plugins)
-  struct arglist *ctrls;
-  struct nessus_plugin *plugins;
+prefs_plugins_reset (struct arglist* ctrls, struct nessus_plugin* plugins)
 {
   struct arglist *prefs;
 
@@ -207,13 +229,11 @@ prefs_plugins_reset(ctrls, plugins)
   }
 }
 
-/*
+/**
  * Redraw the plugins preferences
  */
 void
-prefs_plugins_prefs_redraw(context, ctrls)
-  struct context *context;
-  struct arglist *ctrls;
+prefs_plugins_prefs_redraw (struct context* context, struct arglist* ctrls)
 {
   GtkWidget *frame, *cred_frame;
   GtkWidget *plugin_prefs, *plugin_credentials;
@@ -279,115 +299,123 @@ prefs_plugins_prefs_redraw(context, ctrls)
 }
 
 
+/**
+ * Adds a notebook page to either the plugin preference notebook or the 
+ * credentials notebook and returns the vbox for it.
+ * 
+ * @param ctrls Arglist in which the other Gtk widgets are held.
+ * @param name Name for the new notebook page.
+ * @param credentials If 0 page is added to preference notebook, otherwise to 
+ *                    credentials notebook.
+ * 
+ * @return The Gtk vbox nested in a Gtk scrolled window of the new page.
+ */
 static GtkWidget *
-pprefs_add_notebook_page(ctrls, name, credentials)
-  struct arglist *ctrls;
-  char *name;
-  int credentials;
+pprefs_add_notebook_page(struct arglist* ctrls, char* name, int credentials)
 {
   GtkWidget *vbox = NULL;
-
+  GtkWidget *notebook = NULL;
+  
   if (credentials == 0)
-  {
-    GtkWidget *listnotebook = arg_get_value(ctrls, "PLUGIN_PREFS");
-    GtkWidget *s_window = gtk_scrolled_window_new(NULL, NULL);
-
-    read_only_set_recurse(s_window);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(s_window),
-	GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_widget_show(s_window);
-    vbox = gtk_vbox_new(FALSE, FALSE);
-    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(s_window), vbox);
-    gtk_widget_show(vbox);
-
-    listnotebook_add_page(listnotebook, s_window, name, NULL);
-  }
+    notebook = arg_get_value(ctrls, "PLUGIN_PREFS");
   else
-  {
-    GtkWidget *cred_listnotebook = arg_get_value(ctrls, "PLUGIN_CREDENTIALS");
-    GtkWidget *s_window = gtk_scrolled_window_new(NULL, NULL);
+    notebook = arg_get_value(ctrls, "PLUGIN_CREDENTIALS");
+  
+  GtkWidget *s_window = gtk_scrolled_window_new(NULL, NULL);
+  read_only_set_recurse(s_window);
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(s_window),
+                                 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_widget_show(s_window);
+  vbox = gtk_vbox_new(FALSE, FALSE);
+  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(s_window), vbox);
+  gtk_widget_show(vbox);
 
-    read_only_set_recurse(s_window);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(s_window),
-                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_widget_show(s_window);
-    vbox = gtk_vbox_new(FALSE, FALSE);
-    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(s_window), vbox);
-    gtk_widget_show(vbox);
-
-    listnotebook_add_page(cred_listnotebook, s_window, name, NULL);
-  }
+  listnotebook_add_page(notebook, s_window, name, NULL);
 
   return vbox;
 }
 
-
+/**
+ * @brief Displays a file chooser dialog.
+ * 
+ * The path to the selected file is set as text to the NVT file preferences
+ * text entry widget.
+ * 
+ * @see file_selected
+ * 
+ * @param b Ignored.
+ * @param ctrl Arglist on which to operate (just need the "ENTRY" key/value).
+ * 
+ * @return Always 0.
+ */
 static int
-file_dialog_hide(GtkWidget * filew, GtkWidget * nul)
+select_file (GtkWidget * b, struct arglist *ctrls)
 {
-  gtk_widget_hide(filew);
-  gtk_widget_destroy(filew);
+  GtkWidget* filechooser;
+  GtkWidget* filename_entry;
+  // Gtk >= 2.6 defines gtk_file_chooser_set_show_hidden, which might be turned on.
+  filechooser = gtk_file_chooser_dialog_new (_("Select file"),
+                                            NULL,
+                                            GTK_FILE_CHOOSER_ACTION_OPEN,
+                                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                            GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                            NULL);
+
+  if (gtk_dialog_run (GTK_DIALOG (filechooser)) == GTK_RESPONSE_ACCEPT)
+    {
+      char *filename;
+      filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filechooser));
+      filename_entry = arg_get_value (ctrls, "ENTRY");
+      gtk_entry_set_text (GTK_ENTRY(filename_entry), filename);
+    }
+  gtk_widget_destroy (filechooser);
+
   return 0;
 }
 
-
-static int
-file_selected(GtkWidget * nul, GtkWidget * filew)
-{
-  struct arglist *c;
-  GtkWidget *entry;
-  char *fname =
-      (char *)gtk_file_selection_get_filename(GTK_FILE_SELECTION(filew));
-  gtk_widget_hide(filew);
-  c = gtk_object_get_data(GTK_OBJECT(filew), "data");
-  entry = arg_get_value(c, "ENTRY");
-  gtk_entry_set_text(GTK_ENTRY(entry), fname);
-  return 0;
-}
-static int
-select_file(GtkWidget * b, struct arglist *ctrls)
+/**
+ * @brief Returns "yes" or "no" if preference is of type ARG_INT.
+ * 
+ * @return ("yes" or "no") when pref of type int, value otherwise.
+ */
+static char*
+get_pref_value (struct arglist* prefname, struct arglist* prefvalue,
+                char* value)
 {
+ char* fullname = arg_get_value(prefname->value, "fullname");
+ 
+ if(prefvalue)
+ {
+   int type;
 
-  GtkWidget *filew = gtk_file_selection_new(_("Select file"));
-
-  g_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->ok_button),
-      "clicked", (GtkSignalFunc) file_selected, filew);
-  g_signal_connect_swapped(GTK_OBJECT(GTK_FILE_SELECTION(filew)->
-	  cancel_button), "clicked", GTK_SIGNAL_FUNC(file_dialog_hide),
-      GTK_OBJECT(filew));
-  gtk_object_set_data(GTK_OBJECT(filew), "data", ctrls);
-  gtk_widget_show(filew);
-  return 0;
+   if((type = arg_get_type(prefvalue, fullname)) >= 0)
+   {
+     value = arg_get_value(prefvalue, fullname);
+     if(type == ARG_INT)
+     {
+       if(value)
+         value = strdup("yes");
+       else
+         value = strdup("no");
+     }
+   }
+ }
+ 
+ return value;
 }
 
-
+/**
+ * Add "entry" widget corresponding to the "entry" plugin preference.
+ */
 static void
-pprefs_add_entry(pprefs, pref, value, vbox)
-  struct arglist *pprefs;
-  struct arglist *pref;
-  char *value;
-  GtkWidget *vbox;
+pprefs_add_entry (struct arglist* pprefs, struct arglist* pref, char* value,
+                  GtkWidget* vbox)
 {
   GtkWidget *entry, *text, *box;
   char *name = pref->name;
-  char *fullname = arg_get_value(pref->value, "fullname");
-
-  if(pprefs)
-  {
-    int type;
-
-    if((type = arg_get_type(pprefs, fullname)) >= 0)
-    {
-      value = arg_get_value(pprefs, fullname);
-      if(type == ARG_INT)
-      {
-	if(value)
-	  value = strdup("yes");
-	else
-	  value = strdup("no");
-      }
-    }
-  }
+  
+  value = get_pref_value(pref, pprefs, value);
+  
   box = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, FALSE, 5);
   gtk_widget_show(box);
@@ -404,33 +432,18 @@ pprefs_add_entry(pprefs, pref, value, vbox)
 }
 
 
+/**
+ * Add "password" widget corresponding to the "password" plugin preference.
+ */
 static void
-pprefs_add_password(pprefs, pref, value, vbox)
-  struct arglist *pprefs;
-  struct arglist *pref;
-  char *value;
-  GtkWidget *vbox;
+pprefs_add_password (struct arglist* pprefs, struct arglist* pref, char* value,
+                     GtkWidget* vbox)
 {
   GtkWidget *entry, *text, *box;
   char *name = pref->name;
-  char *fullname = arg_get_value(pref->value, "fullname");
-
-  if(pprefs)
-  {
-    int type;
-
-    if((type = arg_get_type(pprefs, fullname)) >= 0)
-    {
-      value = arg_get_value(pprefs, fullname);
-      if(type == ARG_INT)
-      {
-	if(value)
-	  value = strdup("yes");
-	else
-	  value = strdup("no");
-      }
-    }
-  }
+  
+  value = get_pref_value(pref, pprefs, value);
+  
   box = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, FALSE, 5);
   gtk_widget_show(box);
@@ -447,34 +460,20 @@ pprefs_add_password(pprefs, pref, value, vbox)
   arg_add_value(pref->value, "ENTRY", ARG_PTR, -1, entry);
 }
 
+
+/**
+ * Add "file" widgets corresponding to the "file" plugin preference.
+ */
 static void
-pprefs_add_file(pprefs, pref, value, vbox)
-  struct arglist *pprefs;
-  struct arglist *pref;
-  char *value;
-  GtkWidget *vbox;
+pprefs_add_file (struct arglist* pprefs, struct arglist* pref, char* value,
+                 GtkWidget* vbox)
 {
   GtkWidget *entry, *text, *box;
   GtkWidget *hbox, *button;
   char *name = pref->name;
-  char *fullname = arg_get_value(pref->value, "fullname");
-
-  if(pprefs)
-  {
-    int type;
-
-    if((type = arg_get_type(pprefs, fullname)) >= 0)
-    {
-      value = arg_get_value(pprefs, fullname);
-      if(type == ARG_INT)
-      {
-	if(value)
-	  value = strdup("yes");
-	else
-	  value = strdup("no");
-      }
-    }
-  }
+  
+  value = get_pref_value(pref, pprefs, value);
+  
   box = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, FALSE, 5);
   gtk_widget_show(box);
@@ -502,39 +501,21 @@ pprefs_add_file(pprefs, pref, value, vbox)
 }
 
 
-
+/**
+ * Add radio buttons corresponding to the "radio" plugin preference.
+ */
 static void
-pprefs_add_radio(pprefs, pref, value, vbox)
-  struct arglist *pprefs;
-  struct arglist *pref;
-  char *value;
-  GtkWidget *vbox;
+pprefs_add_radio (struct arglist* pprefs, struct arglist* pref, char* value,
+                  GtkWidget* vbox)
 {
   GtkWidget *orig;
   GtkWidget *button, *first_button;
   GtkWidget *label;
   char *t;
   GSList *list = NULL;
-  char *fullname = arg_get_value(pref->value, "fullname");
-  char *def = NULL;
-
-  if(pprefs)
-  {
-    int type;
-
-    if((type = arg_get_type(pprefs, fullname)) >= 0)
-    {
-      def = arg_get_value(pprefs, fullname);
-      if(type == ARG_INT)
-      {
-	if(def)
-	  def = strdup("yes");
-	else
-	  def = strdup("no");
-      }
-    }
-  }
-
+  char* def = NULL;
+  
+  def = get_pref_value(pref, pprefs, def);
 
   label = gtk_label_new(pref->name);
   gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 5);
@@ -572,35 +553,21 @@ pprefs_add_radio(pprefs, pref, value, vbox)
   arg_add_value(pref->value, "RADIOBUTTONS", ARG_PTR, -1, list);
 }
 
+
+/**
+ * Add a "checkbox" widget corresponding to the "checkbox" plugin preference.
+ */
 static void
-pprefs_add_checkbox(pprefs, pref, value, vbox)
-  struct arglist *pprefs;
-  struct arglist *pref;
-  char *value;
-  GtkWidget *vbox;
+pprefs_add_checkbox (struct arglist* pprefs, struct arglist* pref, char* value,
+                     GtkWidget* vbox)
 {
   GtkWidget *box;
   GtkWidget *button;
   char *name = pref->name;
   char *def = NULL;
-  char *fullname = arg_get_value(pref->value, "fullname");
 
-  if(pprefs)
-  {
-    int type;
-
-    if((type = arg_get_type(pprefs, fullname)) >= 0)
-    {
-      def = arg_get_value(pprefs, fullname);
-      if(type == ARG_INT)
-      {
-	if(def)
-	  def = strdup("yes");
-	else
-	  def = strdup("no");
-      }
-    }
-  }
+  def = get_pref_value(pref, pprefs, def);
+      
   box = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, FALSE, 5);
   gtk_widget_show(box);
