@@ -26,13 +26,16 @@
 #include "context.h"
 #include "preferences.h"
 
-/* Build and run the preferences Dialog. In case of finishing the
- * dialog with OK, store the changed preferences data. */
+
+/**
+ * Build and run the preferences Dialog. In case of finishing the
+ * dialog with OK, store the changed preferences data.
+ * @param menuitem Not required here, but mandatory since function is connected
+ *                 via GTK_SIGNAL_CONNECT.
+ * @param ctrls Pointer to arglist where the gui elements are hooked into.
+ */
 void
-prefs_dialog_prefs(menuitem, ctrls)
-  GtkMenuItem * menuitem; /* not required here, but mandatory since
-                             function is connected via GTK_SIGNAL_CONNECT */
-  gpointer ctrls;
+prefs_dialog_prefs(GtkMenuItem * menuitem, gpointer ctrls)
 {
   GtkWindow * window = GTK_WINDOW(arg_get_value(ctrls, "WINDOW"));
   GtkWidget * dialog;
@@ -140,8 +143,6 @@ prefs_dialog_prefs(menuitem, ctrls)
   protocol_combobox = gtk_combo_box_new_text ();
   gtk_widget_show(protocol_combobox);
   gtk_table_attach_defaults(GTK_TABLE(table), protocol_combobox, 1, 2, 1, 2);
-  gtk_combo_box_append_text(GTK_COMBO_BOX(protocol_combobox),
-			    _("NTP 1.2"));
   gtk_combo_box_append_text(GTK_COMBO_BOX(protocol_combobox),
 			    _("OTP 1.0"));
   gtk_combo_box_set_active(GTK_COMBO_BOX(protocol_combobox), prefs_get_int(Global, "protocol_version"));
@@ -265,13 +266,13 @@ prefs_dialog_prefs(menuitem, ctrls)
       prefs_get_string(Global, "url_bid"));
   gtk_table_attach_defaults(GTK_TABLE(table), entry_url_bid, 1, 2, 2, 3);
 
-
   /*
   frame = gtk_frame_new(_("Debug"));
   gtk_widget_show(frame);
   gtk_box_pack_start_defaults(GTK_BOX(vbox), frame);
   */
 
+  /* Run the dialog and store values if OK was pressed. */
   switch (gtk_dialog_run(GTK_DIALOG(dialog)))
   {
     case GTK_RESPONSE_OK:
