@@ -177,22 +177,20 @@ add_rule_callback (GtkWidget * w, struct arglist * ctrls)
   GtkEntry * target_entry;
   GtkWidget * tree;
   GtkTreeStore * store;
-  GtkTreeModel * model;
   GtkTreeIter iter, parent;
   char * action = NULL;
   char * target = NULL;
-  char * rule = NULL;
+  gchar * rule = NULL;
   GtkTreePath * path;
 
   action_combo = arg_get_value(ctrls, "ACTION");
-  /* XXX: Once the GTK+ minimum version is 2.6, this line
-   * can replace the following if construct:
-   * action = (char *)gtk_combo_box_get_active_text(action_combo);
-   */
-  if (gtk_combo_box_get_active_iter (action_combo, &iter)) {
+  action = (char *)gtk_combo_box_get_active_text(action_combo);
+  /* Before the GTK+ minimum version was 2.6,  looked like:
+    GtkTreeModel * model;
+    if (gtk_combo_box_get_active_iter (action_combo, &iter)) {
     model = gtk_combo_box_get_model(action_combo);
     gtk_tree_model_get(model, &iter, 0, &action, -1);
-  }
+  }*/
   target_entry = arg_get_value(ctrls, "TARGET");
   target = (char*)gtk_entry_get_text(target_entry);
   tree = arg_get_value(ctrls, "RULES_TREE");
