@@ -225,4 +225,10 @@ plugins (that you have not seen before in this scope) are automatically \
 enabled. In any case, a message will be displayed when new plugins have been \
 found, showing your choice.")
 
+#define HLP_AUTO_GLOBAL_NVT_TIMEOUT _("Enter the global timeout for NVTs in \
+seconds. This value can be overwritten for individual NVTs in the NVT Info \
+dialog, which opens on a double click on a NVT. If execution of an NVT takes \
+more time than specified here or for an individual NVT it will get killed by \
+the server. A value of -1 means \"no timeout\".")
+
 #endif
