@@ -26,6 +26,12 @@
  * do so, delete this exception statement from your version.
  */
 
+/** @file
+ * The plugins are in the clients GUI, showing a Tree of plugins, and some
+ * controls like buttons to dis/enable everything in the tree, filter the
+ * shown NVTs and NVT- related options.
+ */
+
 #include <includes.h>
 
 #ifdef USE_GTK
@@ -43,64 +49,59 @@
 #include "readonly.h"
 
 
-
 static int
-set_filter(w, ctrls)
-  GtkWidget *w;
-  struct arglist *ctrls;
+set_filter (GtkWidget *w, struct arglist *ctrls)
 {
   struct plugin_filter filter;
   char *old;
   struct nessus_plugin *plugins = Context->plugins;
   unsigned int filter_count = 0;
-  GtkWidget *label = arg_get_value(ctrls, "FILTER_LABEL");
+  GtkWidget *label = arg_get_value (ctrls, "FILTER_LABEL");
 
   ask_filter(&filter);
   if(!filter.pattern)
     return 0;
 
 
-  if((old = arg_get_value(ctrls, "FILTER")))
-  {
-    arg_set_value(ctrls, "FILTER", sizeof(filter), &filter);
-  }
+  if ((old = arg_get_value(ctrls, "FILTER")))
+    {
+      arg_set_value (ctrls, "FILTER", sizeof(filter), &filter);
+    }
   else
-    arg_add_value(ctrls, "FILTER", ARG_STRUCT, sizeof(filter), &filter);
+    arg_add_value (ctrls, "FILTER", ARG_STRUCT, sizeof(filter), &filter);
 
 
   Filter = filter;
-  memcpy(&Filter, &filter, sizeof(filter));
+  memcpy (&Filter, &filter, sizeof(filter));
 
-    while(plugins != NULL )
+  while (plugins != NULL )
     {
-      if(filter_plugin(&filter, plugins))
-	 plugins->enabled = 0;
+      if (filter_plugin (&filter, plugins))
+        plugins->enabled = 0;
       else
-	 filter_count++;
-	 
+        filter_count++;
+
       plugins = plugins->next;
     }
 
-  if (strlen(filter.pattern) == 0)
-  {
-    gtk_label_set_text(GTK_LABEL(label), _("No filter active"));
-  }
+  if (strlen (filter.pattern) == 0)
+    {
+      gtk_label_set_text (GTK_LABEL(label), _("No filter active"));
+    }
   else
-  {
-    char *text = g_strdup_printf(_("Filter matches %u plugins"), filter_count);
-    gtk_label_set_text(GTK_LABEL(label), text);
-    g_free(text);
-  }
+    {
+      char *text = g_strdup_printf (_("Filter matches %u plugins"), filter_count);
+      gtk_label_set_text (GTK_LABEL(label), text);
+      g_free (text);
+    }
 
-  prefs_plugin_tree_context_changed(Context, ctrls, TRUE);
+  prefs_plugin_tree_context_changed (Context, ctrls, TRUE);
 
   return 0;
 }
 
 static int
-disable_all(w, data)
-  GtkWidget *w;
-  gpointer data;
+disable_all (GtkWidget *w, gpointer data)
 {
   prefs_plugin_tree_enable_all(GTK_TREE_VIEW(data), FALSE);
 
@@ -108,9 +109,7 @@ disable_all(w, data)
 }
 
 static int
-enable_all(w, data)
-  GtkWidget *w;
-  gpointer data;
+enable_all (GtkWidget *w, gpointer data)
 {
   prefs_plugin_tree_enable_all(GTK_TREE_VIEW(data), TRUE);
 
@@ -118,24 +117,20 @@ enable_all(w, data)
 }
 
 static void
-expand_all(w, data)
-  GtkWidget *w;
-  gpointer data;
+expand_all (GtkWidget *w, gpointer data)
 {
   gtk_tree_view_expand_all(GTK_TREE_VIEW(data));
 
-  /* normally the tree should automatically be redrawn.  This doesn't
+  /* Normally the tree should automatically be redrawn.  This doesn't
    * happen in gtk+ 2.0.2, though, so we trigger a redraw explicitly
    */
   gtk_widget_queue_draw(GTK_WIDGET(data));
 }
 
 static void
-collapse_all(w, data)
-  GtkWidget *w;
-  gpointer data;
+collapse_all (GtkWidget *w, gpointer data)
 {
-  gtk_tree_view_collapse_all(GTK_TREE_VIEW(data));
+  gtk_tree_view_collapse_all (GTK_TREE_VIEW(data));
 }
 
 /**
@@ -152,12 +147,10 @@ collapse_all(w, data)
  * run and should be added again.
  */
 static gboolean
-update_plugin_statistics_label(user_data)
-  gpointer user_data;
+update_plugin_statistics_label (gpointer user_data)
 {
   GtkWidget *label = GTK_WIDGET(user_data);
-  GtkTreeView *tree = GTK_TREE_VIEW(g_object_get_data(G_OBJECT(label),
-	  "tree"));
+  GtkTreeView *tree = GTK_TREE_VIEW (g_object_get_data (G_OBJECT(label), "tree"));
   int total, enabled;
   char*text;
 
@@ -165,10 +158,10 @@ update_plugin_statistics_label(user_data)
 
   text = g_strdup_printf(_("%d plugins; %d enabled"), total, enabled);
 
-  gtk_label_set_text(GTK_LABEL(label), text);
+  gtk_label_set_text (GTK_LABEL(label), text);
 
   g_free(text);
-  
+
   g_object_set_data(G_OBJECT(label), "idle-update-id", GUINT_TO_POINTER(0));
 
   return FALSE;
@@ -192,30 +185,27 @@ update_plugin_statistics_label(user_data)
  * become idle.
  */
 static void
-update_plugin_statistics_label_when_idle(label)
-  GtkWidget *label;
+update_plugin_statistics_label_when_idle (GtkWidget *label)
 {
   guint idle_id;
 
-  idle_id = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(label),
-	  "idle-update-id"));
+  idle_id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT(label),
+                                                 "idle-update-id"));
   if (!idle_id)
-  {
-    idle_id = g_idle_add(update_plugin_statistics_label, label);
+    {
+      idle_id = g_idle_add (update_plugin_statistics_label, label);
 
-    g_object_set_data(G_OBJECT(label), "idle-update-id",
-	GUINT_TO_POINTER(idle_id));
-  }
+      g_object_set_data (G_OBJECT(label), "idle-update-id",
+                         GUINT_TO_POINTER(idle_id));
+    }
 }
 
 static void
-update_statistics(tree_view, user_data)
-  GtkWidget *tree_view;
-  gpointer user_data;
+update_statistics (GtkWidget *tree_view, gpointer user_data)
 {
-  update_plugin_statistics_label_when_idle(user_data);
+  update_plugin_statistics_label_when_idle (user_data);
 }
-  
+
 /**
  * @brief Builds up the plugin area with plugin tree, buttons and preferences.
  *
@@ -252,7 +242,7 @@ prefs_dialog_plugins (struct context *context)
   gtk_box_set_homogeneous(GTK_BOX(w_box), FALSE);
   read_only_set_recurse(w_box);
 
-  /* tree view of the plugins */
+  /* Tree view of the plugins */
   tree_window = gtk_scrolled_window_new(NULL, NULL);
   read_only_set_active(tree_window);
   gtk_container_border_width(GTK_CONTAINER(tree_window), 10);
@@ -268,16 +258,16 @@ prefs_dialog_plugins (struct context *context)
   arg_add_value(ctrls, "PLUGIN_TREE", ARG_PTR, -1, tree);
 
   /* Label showing some statistics */
-  label = gtk_label_new(_("No plugins"));
+  label = gtk_label_new (_("No plugins"));
   gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-  gtk_box_pack_start(GTK_BOX(w_box), label, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(w_box), label, FALSE, FALSE, 0);
   gtk_widget_show(label);
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(tree));
-  /* connect to some tree model signals so that we update the label when
+  /* Connect to some tree model signals so that we update the label when
    * the model changes.  The way the model is updated currently means
    * that only row-changed and row-deleted are interesting. */
-  g_signal_connect(G_OBJECT(tree), "statistics-changed", 
-      update_statistics, label);
+  g_signal_connect (G_OBJECT(tree), "statistics-changed",
+                   (GCallback) update_statistics, label);
   g_object_set_data(G_OBJECT(label), "tree", tree);
   g_object_set_data(G_OBJECT(label), "idle-update-id", GUINT_TO_POINTER(0));
 
@@ -300,7 +290,7 @@ prefs_dialog_plugins (struct context *context)
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  /* enable all / disable all buttons */
+  /* Enable all / disable all buttons */
   hbox = gtk_hbox_new(FALSE, 5);
   gtk_box_pack_start(GTK_BOX(w_box), hbox, FALSE, FALSE, 0);
   gtk_widget_show(hbox);
@@ -311,14 +301,13 @@ prefs_dialog_plugins (struct context *context)
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-
   button = gtk_button_new_with_label(_("Disable all"));
   g_signal_connect(GTK_OBJECT(button),
       "clicked", GTK_SIGNAL_FUNC(disable_all), tree);
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  /* expand all / collapse all buttons */
+  /* Expand all / collapse all buttons */
   hbox = gtk_hbox_new(FALSE, 5);
   gtk_box_pack_start(GTK_BOX(w_box), hbox, FALSE, FALSE, 0);
   gtk_widget_show(hbox);
@@ -336,15 +325,13 @@ prefs_dialog_plugins (struct context *context)
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-
-  /* dependency buttons */
+  /* Dependency buttons */
   hbox = gtk_hbox_new(FALSE, 5);
-  gtk_box_pack_start(GTK_BOX(w_box), hbox, FALSE, FALSE, 5);
-  gtk_widget_show(hbox);
+  gtk_box_pack_start (GTK_BOX(w_box), hbox, FALSE, FALSE, 5);
+  gtk_widget_show (hbox);
 
-  /* Label showing the filter status */
-  label = gtk_label_new(_("Dependencies:"));
-  gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+  label = gtk_label_new (_("Dependencies:"));
+  gtk_misc_set_alignment (GTK_MISC(label), 0, 0.5);
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_widget_show(label);
 
@@ -355,14 +342,14 @@ prefs_dialog_plugins (struct context *context)
   arg_add_value(ctrls, "ENABLE_DEPS_AT_RUNTIME", ARG_PTR, -1, button);
 
   button = gtk_check_button_new_with_label (_("Silent"));
-  gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
-  gtk_widget_show(button);
-  arg_add_value(ctrls, "SILENT_DEPS", ARG_PTR, -1, button);
+  gtk_box_pack_start (GTK_BOX(hbox), button, TRUE, TRUE, 0);
+  gtk_widget_show (button);
+  arg_add_value (ctrls, "SILENT_DEPS", ARG_PTR, -1, button);
 
   /* Auto-activate new plugins buttons */
-  hbox = gtk_hbox_new(FALSE, 5);
-  gtk_box_pack_start(GTK_BOX(w_box), hbox, FALSE, FALSE, 5);
-  gtk_widget_show(hbox);
+  hbox = gtk_hbox_new (FALSE, 5);
+  gtk_box_pack_start (GTK_BOX(w_box), hbox, FALSE, FALSE, 5);
+  gtk_widget_show (hbox);
 
   button =
       gtk_check_button_new_with_label(_("Automatically enable new plugins"));
@@ -370,11 +357,26 @@ prefs_dialog_plugins (struct context *context)
   gtk_widget_show(button);
   arg_add_value(ctrls, "AUTO_ENABLE_NEW_PLUGINS", ARG_PTR, -1, button);
 
-  /* Round- up */
-  fill_plugins_family(context, ctrls);
+  /* Global NVT timeout */
+  hbox = gtk_hbox_new (FALSE, 5);
+  gtk_box_pack_start (GTK_BOX(w_box), hbox, FALSE, FALSE, 5);
+  gtk_widget_show (hbox);
 
-  gtk_widget_show(w_box);
-  gtk_widget_show(frame);
+  label = gtk_label_new (_("Global NVT Timeout (sec):"));
+  gtk_misc_set_alignment (GTK_MISC(label), 0, 0.5);
+  gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
+  gtk_widget_show (label);
+
+  button = gtk_spin_button_new_with_range (-1, 32000, 2);
+  gtk_box_pack_start (GTK_BOX(hbox), button, FALSE, FALSE, 0);
+  gtk_widget_show (button);
+  arg_add_value (ctrls, "GLOBAL_NVT_TIMEOUT", ARG_PTR, -1, button);
+
+  /* Round- up */
+  fill_plugins_family (context, ctrls);
+
+  gtk_widget_show (w_box);
+  gtk_widget_show (frame);
 
   return (ctrls);
 }
@@ -384,7 +386,7 @@ prefs_dialog_plugins (struct context *context)
  * plugins tree but cannot make modifications.
  */
 void
-prefs_plugins_read_only(struct arglist * ctrls, gboolean readonly)
+prefs_plugins_read_only (struct arglist * ctrls, gboolean readonly)
 {
   read_only_set_read_only(GTK_WIDGET(arg_get_value(ctrls, "FRAME")),
     readonly);
@@ -393,12 +395,10 @@ prefs_plugins_read_only(struct arglist * ctrls, gboolean readonly)
 }
 
 void
-fill_plugins_family(context, ctrls)
-  struct context *context;
-  struct arglist *ctrls;
+fill_plugins_family (struct context *context, struct arglist *ctrls)
 {
-  /* init tree data */
-  prefs_plugin_tree_context_changed(context, ctrls, FALSE);
+  /* Init tree data */
+  prefs_plugin_tree_context_changed (context, ctrls, FALSE);
 }
 
-#endif
+#endif /* USE_GTK */
