@@ -83,11 +83,11 @@ static void
 create_statistics_changed_signal()
 {
   if (statistics_changed_signal == 0)
-  {
-    statistics_changed_signal = g_signal_new("statistics-changed",
-	GTK_TYPE_TREE_VIEW, G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-	g_cclosure_marshal_VOID__VOID, GTK_TYPE_NONE, 0);
-  }
+    {
+      statistics_changed_signal = g_signal_new("statistics-changed",
+                           GTK_TYPE_TREE_VIEW, G_SIGNAL_RUN_LAST, 0, NULL, NULL,
+                           g_cclosure_marshal_VOID__VOID, GTK_TYPE_NONE, 0);
+    }
 }
 
 /**
@@ -98,7 +98,7 @@ create_statistics_changed_signal()
 static void
 emit_statistics_changed (GtkWidget* tree_view)
 {
-  g_signal_emit(tree_view, statistics_changed_signal, 0);
+  g_signal_emit (tree_view, statistics_changed_signal, 0);
 }
 
 /**
@@ -107,13 +107,12 @@ emit_statistics_changed (GtkWidget* tree_view)
  * Emit the "statistics-changed" signal on the tree model.
  */
 static void
-emit_statistics_when_row_changed(treemodel, arg1, arg2, user_data)
-  GtkTreeModel *treemodel;
-  GtkTreePath *arg1;
-  GtkTreeIter *arg2;
-  gpointer user_data;
+emit_statistics_when_row_changed (GtkTreeModel *treemodel,
+                                  GtkTreePath *arg1,
+                                  GtkTreeIter *arg2,
+                                  gpointer user_data)
 {
-  emit_statistics_changed(GTK_WIDGET(user_data));
+  emit_statistics_changed (GTK_WIDGET(user_data));
 }
 
 /**
@@ -122,12 +121,10 @@ emit_statistics_when_row_changed(treemodel, arg1, arg2, user_data)
  * Emit the "statistics-changed" signal on the tree model.
  */
 static void
-emit_statistics_when_row_deleted(treemodel, arg1, user_data)
-  GtkTreeModel *treemodel;
-  GtkTreePath *arg1;
-  gpointer user_data;
+emit_statistics_when_row_deleted (GtkTreeModel *treemodel, GtkTreePath *arg1,
+                                  gpointer user_data)
 {
-  emit_statistics_changed(GTK_WIDGET(user_data));
+  emit_statistics_changed (GTK_WIDGET(user_data));
 }
 
 
@@ -137,25 +134,29 @@ emit_statistics_when_row_deleted(treemodel, arg1, user_data)
  * The iter argument must be the iter pointing to the family row.
  * A family is enabled when at least one of it's plugins is enabled as
  * determined by plug_get_launch.
+ * 
+ * @return TRUE if the family that model and iter define is enabled, FALSE
+ *         otherwise.
+ *
+ * @TODO Make use of the third state of checkboxes ("half"), to indicate that
+ *       some (but not all) NVTs of a family are enabled.
  */
 static gboolean
-is_family_enabled(model, iter)
-  GtkTreeModel* model;
-  GtkTreeIter * iter;
+is_family_enabled (GtkTreeModel* model, GtkTreeIter * iter)
 {
   GtkTreeIter child_iter;
 
-  if (gtk_tree_model_iter_children(model, &child_iter, iter))
-  {
-    do
+  if (gtk_tree_model_iter_children (model, &child_iter, iter))
     {
-      struct nessus_plugin *plugin;
-      gtk_tree_model_get(model, &child_iter, COL_PLUGIN, &plugin, -1);
-      if ( plugin->enabled )
-	return TRUE;
+      do
+        {
+          struct nessus_plugin *plugin;
+          gtk_tree_model_get (model, &child_iter, COL_PLUGIN, &plugin, -1);
+          if (plugin->enabled)
+            return TRUE;
+        }
+      while (gtk_tree_model_iter_next (model, &child_iter));
     }
-    while (gtk_tree_model_iter_next(model, &child_iter));
-  }
   return FALSE;
 }
 
@@ -177,10 +178,7 @@ is_family_enabled(model, iter)
  * otherwise.
  */
 static int
-should_show_warning(model, path, iter)
-  GtkTreeModel *model;
-  GtkTreePath *path;
-  GtkTreeIter *iter;
+should_show_warning (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter)
 {
   GtkTreeIter real_iter;
   struct nessus_plugin *plugin;
@@ -256,7 +254,7 @@ active_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
 
   gtk_tree_model_get_iter_from_string(model, &iter, path_str);
 
-  /* if the item is a family instead of a plugin, toggle the state of
+  /* If the item is a family instead of a plugin, toggle the state of
    * all the children as well.  Since only families have children, we
    * can determine whether the iter points to a family by checking
    * whether we can get an iterator for its children.
@@ -295,13 +293,12 @@ active_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
  * @brief Called when the user double clicks on a row of the tree view.
  * 
  * Pop up the plugin info dialog if the row is a plugin, not a family.
+ * 
+ * @param user_data ignored (callback).
  */
 static void
-row_activated(treeview, path, column, user_data)
-  GtkTreeView *treeview;
-  GtkTreePath *path;
-  GtkTreeViewColumn *column;
-  gpointer user_data;
+row_activated (GtkTreeView *treeview, GtkTreePath *path,
+               GtkTreeViewColumn *column, gpointer user_data)
 {
   GtkTreeModel * model = gtk_tree_view_get_model(treeview);
   int depth = gtk_tree_path_get_depth(path);
@@ -344,26 +341,27 @@ button_press_event (GtkTreeView *tree, GdkEventButton *event,
   int colnum;
   gboolean event_was_handled = FALSE;
 
-  if (!gtk_tree_view_get_path_at_pos(tree, event->x, event->y, &path, &column,
-	  NULL, NULL))
+  if (!gtk_tree_view_get_path_at_pos (tree, event->x, event->y, &path, &column,
+                                      NULL, NULL))
     return FALSE;
+
   colnum = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(column), "colnum"));
 
   if (colnum == 1)
-  {
-    if (should_show_warning(gtk_tree_view_get_model(tree), path, NULL))
     {
-      show_info("%s", HLP_WARNING);
+      if (should_show_warning(gtk_tree_view_get_model(tree), path, NULL))
+        {
+          show_info ("%s", HLP_WARNING);
+        }
+      event_was_handled = TRUE;
     }
-    event_was_handled = TRUE;
-  }
   else if (colnum == 2)
-  {
-    gtk_tree_view_set_cursor(tree, path, column, TRUE);
-    event_was_handled = TRUE;
-  }
+    {
+      gtk_tree_view_set_cursor(tree, path, column, TRUE);
+      event_was_handled = TRUE;
+    }
 
-  gtk_tree_path_free(path);
+  gtk_tree_path_free (path);
 
   return event_was_handled;
 }
@@ -416,8 +414,7 @@ warning_data_func(tree_column, cell, model, iter, data)
   if (should_show_warning(model, NULL, iter))
   {
     if (!warning_pixbuf)
-      warning_pixbuf = gdk_pixbuf_new_from_xpm_data(
-	(const char**)warning_small_xpm);
+      warning_pixbuf = gdk_pixbuf_new_from_xpm_data((const char**) warning_small_xpm);
     value = warning_pixbuf;
   }
 
@@ -427,7 +424,9 @@ warning_data_func(tree_column, cell, model, iter, data)
 
 
 /**
- * @brief Create a new plugin tree and model.
+ * @brief Create a new plugin tree and model and hooks up widgets in ctrls.
+ * 
+ * @param ctrls[in,out] Arglist in which to hook up widgets.
  */
 GtkWidget *
 prefs_create_plugins_tree (struct context *context, struct arglist* ctrls)
@@ -493,7 +492,7 @@ fill_plugin_tree_store (struct context *context,   struct arglist *ctrls)
   struct plugin_filter *filter = arg_get_value(ctrls, "FILTER");
   GHashTable* family_hash = g_hash_table_new_full(g_str_hash, g_str_equal,
       NULL, (GDestroyNotify)gtk_tree_path_free);
-  
+
   /* Add the plugins and families.  The family nodes are created when
    * the first plugin of that family is encountered */
   while(plugs != NULL )
@@ -519,9 +518,8 @@ fill_plugin_tree_store (struct context *context,   struct arglist *ctrls)
       gtk_tree_store_append(GTK_TREE_STORE(store), &family_iter, NULL);
       family_path = gtk_tree_model_get_path(store, &family_iter);
       g_hash_table_insert(family_hash, plug_family, family_path);
-      gtk_tree_store_set(GTK_TREE_STORE(store), &family_iter,
-	  COL_NAME, plug_family, COL_PLUGIN, NULL, -1);
-      
+      gtk_tree_store_set (GTK_TREE_STORE(store), &family_iter,
+                          COL_NAME, plug_family, COL_PLUGIN, NULL, -1);
     }
     else
     {
@@ -531,8 +529,8 @@ fill_plugin_tree_store (struct context *context,   struct arglist *ctrls)
     /* Now family_iter should be set to the iter of the family the
      * current plugin belongs to.  Append the plugin to that family. */
     gtk_tree_store_append(GTK_TREE_STORE(store), &insert_iter, &family_iter);
-    gtk_tree_store_set(GTK_TREE_STORE(store), &insert_iter,
-	COL_NAME, plugs->name, COL_PLUGIN, plugs, -1);
+    gtk_tree_store_set (GTK_TREE_STORE(store), &insert_iter,
+                        COL_NAME, plugs->name, COL_PLUGIN, plugs, -1);
 
     plugs = plugs->next;
   }
@@ -599,14 +597,14 @@ prefs_plugin_tree_context_changed (struct context *context,
 
   if (model != NULL)
   {
-    g_signal_connect(model, "row-changed",
-	emit_statistics_when_row_changed, tree_view);
-    g_signal_connect(model, "row-deleted",
-	emit_statistics_when_row_deleted, tree_view);
+    g_signal_connect (model, "row-changed",
+                      (GCallback) emit_statistics_when_row_changed, tree_view);
+    g_signal_connect (model, "row-deleted",
+                      (GCallback) emit_statistics_when_row_deleted, tree_view);
   }
 
   /* When a new model is set, the statistics will have changed: */
-  emit_statistics_changed ( GTK_WIDGET(tree_view));
+  emit_statistics_changed (GTK_WIDGET(tree_view));
 }
 
 
@@ -638,7 +636,7 @@ prefs_plugin_tree_enable_all (GtkTreeView *tree, int enable)
       }
     }
     while (gtk_tree_model_iter_next(model, &iter));
-  }	
+  }
 }
 
 /**
@@ -686,8 +684,8 @@ prefs_plugin_tree_statistics (GtkTreeView *tree_view, int *total, int *enabled)
 void
 prefs_plugin_tree_read_only (GtkTreeView* tree_view, gboolean readonly)
 {
-  g_object_set_data(G_OBJECT(tree_view), "read-only",
-      GINT_TO_POINTER(readonly));
+  g_object_set_data (G_OBJECT(tree_view), "read-only",
+                     GINT_TO_POINTER(readonly));
 }
 
 #endif /* USE_GTK */
