@@ -698,7 +698,7 @@ create_override_page (severity_override_t* override)
  * @brief the list of selected issues (in the ctrls).
  */
 static void
-addprio_click (GtkMenuItem* widget, gpointer user_data)
+add_override_click (GtkMenuItem* widget, gpointer user_data)
 {
   struct arglist* report = arg_get_value (MainDialog, "REPORT");
   GtkWindow *window      = GTK_WINDOW (arg_get_value (MainDialog, "WINDOW"));
@@ -723,7 +723,6 @@ addprio_click (GtkMenuItem* widget, gpointer user_data)
                                          GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
                                          NULL);
 
-
   listnotebook = listnotebook_new (TRUE, TRUE);
   issue = issues;
   while (issue != NULL)
@@ -755,6 +754,116 @@ addprio_click (GtkMenuItem* widget, gpointer user_data)
   gtk_widget_destroy (dialog);
 }
 
+/**
+ * @brief Asks the user to select a file and exports the textviews current
+ * @brief context.
+ * 
+ * @param widget    Ignored (callback).
+ * @param user_data Ignored (callback).
+ * 
+ * Does hard checking for certain strings, usable just in a very specific
+ * setting.
+ * 
+ * @TODO Consider implementation as TextBufferSerializeFunc
+ */
+static void
+gshb_export_click (GtkMenuItem* widget, gpointer user_data)
+{
+  struct arglist* guiargs = arg_get_value (MainDialog, "REPORT");
+  GtkWidget * textview    = arg_get_value (guiargs, "REPORT");
+  GtkTextBuffer* textbuffer = NULL;
+  GtkWidget *file_dialog;
+  GtkTextIter startiter;
+  GtkTextIter enditer;
+  int fd;
+  gsize text_length;
+  int written = 0;
+  gchar* buffer;
+  gchar* before_header;
+  gchar* proposed_filename;
+  gchar* filename = NULL;
+  severity_override_t* issue = NULL;
+  GSList* overrides = NULL;
+
+  // Find out which target was scanned
+  overrides = arg_get_value (guiargs, "SELECTED_ISSUES");
+  if (overrides == NULL 
+      || (issue = (severity_override_t*) overrides->data) == NULL)
+    {
+      show_error (_("Could not export the selected report item as a GSHB report."));
+      return;
+    }
+
+  proposed_filename = g_strdup_printf ("openvas-gshbt-%s.txt", issue->host);
+
+  // Get the user-defined file name from a filechooser
+  file_dialog = gtk_file_chooser_dialog_new (_("Export to"),
+                                              GTK_WINDOW(arg_get_value(MainDialog, "WINDOW")),
+                                              GTK_FILE_CHOOSER_ACTION_SAVE,
+                                              GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                              GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+                                              NULL);
+  gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (file_dialog), TRUE);
+  gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (file_dialog), proposed_filename);
+
+  if (gtk_dialog_run (GTK_DIALOG (file_dialog)) != GTK_RESPONSE_ACCEPT)
+    {
+      gtk_widget_destroy (file_dialog);
+      // NTBD
+      g_free (proposed_filename);
+      return;
+    }
+  g_free (proposed_filename);
+
+  filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_dialog));
+
+  textbuffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(textview));
+  gtk_text_buffer_get_start_iter (textbuffer, &startiter);
+  gtk_text_buffer_get_end_iter   (textbuffer, &enditer);
+  buffer = gtk_text_buffer_get_text (textbuffer, &startiter, &enditer, TRUE);
+
+  // We expect some garbage, then: "ID"|"Status"|"Description"|
+  before_header = g_strstr_len (buffer, strlen(buffer),
+                                "\"ID\"|\"Status\"|\"Description\"|");
+
+  if (before_header == NULL)
+    {
+      show_error (_("Message does not contain a valid GSHB report."));
+      gtk_widget_destroy (file_dialog);
+      g_free (filename);
+      g_free (buffer);
+      return;
+    }
+
+  // Open a file to write content to.
+  // (with GLIB >= 2.8 we can use file_set_contents)
+  fd = open (filename, O_RDWR|O_CREAT|O_TRUNC, 0600);
+  if (!fd)
+    {
+      gtk_widget_destroy (file_dialog);
+      show_error (_("Export failed, could not open file %s."), filename);
+      g_free (buffer);
+      g_free (filename);
+      return;
+    }
+
+  // Write content
+  text_length = strlen (before_header);
+  written = write (fd, before_header, text_length);
+
+  // Clean up
+  close (fd);
+  if (written != text_length)
+    {
+      show_error (_("Export failed, could write only incomplete data (%d/%d)."), written, text_length);
+    }
+
+  gtk_widget_destroy (file_dialog);
+  g_free (buffer);
+  g_free (filename);
+  return ;
+}
+
 /**
  * @brief Create and show a popup menu.
  */
@@ -763,13 +872,61 @@ show_popup_menu (GtkWidget *treeview, GdkEventButton *event, gpointer userdata)
 {
   GtkWidget *menu;
   GtkWidget *menuitem;
+  GtkTreeSelection *selection;
+  GtkTreeModel     *model;
+  GtkTreeIter       iter;
+  GtkTreeIter       parent;
+  GtkTreePath*      treepath;
+  gboolean is_gshb_exportable = FALSE;
+
+  // Find out whether we can gshb-export any of the selected data
+  // use gtk_tree_path_get_depth // gtk_tree_model_get_path
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(treeview));
+  gtk_tree_selection_get_selected (selection, &model, &iter);
+  treepath = gtk_tree_model_get_path (model, &iter);
+  if (gtk_tree_path_get_depth (treepath) == 3)
+    {
+      gchar *name;
+      gchar* key;
+      gtk_tree_model_iter_parent (model, &parent, &iter);
+
+      // Ordering matters, we need to know the "port" (general/GSHB)
+      gtk_tree_model_get (model, &parent, COL_KEY, &key, -1);
+      if (!strcmp (key, "port"))
+        ;
+      else
+        {
+          // Cannot assign parent 'in-place' (gtk_tree_model_iter_parent (model, &parent, &parent);)
+          GtkTreeIter tmp;
+          gtk_tree_model_iter_parent (model, &tmp, &parent);
+          parent = tmp;
+        }
+
+      gtk_tree_model_get (model, &parent, COL_NAME, &name, -1);
+      is_gshb_exportable = (g_strstr_len (name, strlen(name), "general/GSHB") == NULL) ? FALSE
+                                                                                : TRUE;
+      gtk_tree_model_get (model, &parent, COL_KEY, &name, -1);
+
+      g_free (name);
+      g_free (key);
+    }
 
   menu = gtk_menu_new();
-  menuitem = gtk_menu_item_new_with_label(_("Severities..."));
-  gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
-  gtk_widget_set_sensitive (menuitem, !Context->is_severity_mapped);
 
-  g_signal_connect(G_OBJECT(menuitem), "activate", GTK_SIGNAL_FUNC(addprio_click), NULL);
+  // Severities item
+  menuitem = gtk_menu_item_new_with_label(_("Severities..."));
+  gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+  gtk_widget_set_sensitive (menuitem, !Context->is_severity_mapped);
+  g_signal_connect(G_OBJECT(menuitem), "activate", GTK_SIGNAL_FUNC(add_override_click), NULL);
+
+  // Export GSHB item
+  if (is_gshb_exportable)
+    {
+      menuitem = gtk_menu_item_new_with_label(_("Export GSHB Table..."));
+      gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+      gtk_widget_set_sensitive (menuitem, is_gshb_exportable);
+      g_signal_connect(G_OBJECT(menuitem), "activate", GTK_SIGNAL_FUNC(gshb_export_click), NULL);
+    }
 
   gtk_widget_show_all(menu);
 
@@ -785,7 +942,7 @@ show_popup_menu (GtkWidget *treeview, GdkEventButton *event, gpointer userdata)
  * @brief Shows a popup menu.
  */
 static gboolean
-prio_show_popup (GtkWidget *treeview, gpointer userdata)
+show_popup (GtkWidget *treeview, gpointer userdata)
 {
   show_popup_menu(treeview, NULL, userdata);
   return TRUE; /* we handled this */
@@ -795,15 +952,28 @@ prio_show_popup (GtkWidget *treeview, gpointer userdata)
  * @brief Shows a popup menu if registered a right mouse button click.
  */
 static gboolean
-prio_button_press (GtkWidget *treeview, GdkEventButton *event, gpointer userdata)
+mouse_button_press (GtkWidget *treeview, GdkEventButton *event, gpointer userdata)
 {
   /* Single click with the right mouse button? */
   if (event->type == GDK_BUTTON_PRESS  &&  event->button == 3)
     {
-      // Need to know: What is currently selected? Then show appropriate options.
-      // But this conflict rmb selections
-      show_popup_menu(treeview, event, userdata);
-      return FALSE; /* We did not handle this -> selection via rmb possible */
+        GtkTreeSelection *selection;
+
+        selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
+        GtkTreePath *path;
+
+        /* Get tree path for row that was clicked */
+        if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview),
+                                          (gint) event->x,
+                                          (gint) event->y,
+                                          &path, NULL, NULL, NULL))
+          {
+            gtk_tree_selection_unselect_all(selection);
+            gtk_tree_selection_select_path(selection, path);
+            gtk_tree_path_free(path);
+            show_popup_menu(treeview, event, userdata);
+          }
+      return TRUE; /* We did handle this -> we did a selection via rmb ourselves */
     }
 
   return FALSE; /* we did not handle this */
@@ -911,8 +1081,8 @@ prefs_dialog_report (void)
                    G_CALLBACK(onKeypressed), NULL);
 
   /* Add popup-menu support */
-  g_signal_connect (G_OBJECT(tree), "button-press-event", (GCallback) prio_button_press, NULL);
-  g_signal_connect (G_OBJECT(tree), "popup-menu", (GCallback) prio_show_popup, NULL);
+  g_signal_connect (G_OBJECT(tree), "button-press-event", (GCallback) mouse_button_press, NULL);
+  g_signal_connect (G_OBJECT(tree), "popup-menu", (GCallback) show_popup, NULL);
 
   /* The "report widget" (contains the text) in a scolled window */
   report_window = gtk_scrolled_window_new(NULL, NULL);
