@@ -30,29 +30,54 @@
 #include "prefs_context.h"
 #include "prefs_dialog.h"
 #include "prefs_dialog_auth.h"
+#include "prefs_report.h"
 #include "prefs_scope_tree.h"
+#include "severity_filter.h"
 #include "error_dlg.h"
 #include "report.h"
 #include "report_utils.h"
 #include "backend.h"
 #include "treeview_support.h"
 
+/**
+ * @file
+ * Handle the scope- tree (in GUI the area to the left where Global Settings,
+ * taks and scopes are organized in a tree).
+ * Scopes and Global settings have an icon, showing its connection state.
+ * The scope- tree also acts as a table, allowing an overview over how many
+ * security notes, warnings, holes and false positives were reported in a
+ * "report"- scope.
+ * 
+ * The counted numbers for warnings, holes etc are stored in a separate .cnt
+ * file to avoid recounting.
+ * The cnt file is placed next to the location of the .nbe backend file (usually
+ * in the contexts directory).
+ */
+
+/* temporary, should be part of the global context (from severity_filter.c) */
+extern severity_filter_t * global_filter;
+
+/**
+ * @brief Indices of the Scope- treeview.
+ *
+ * Will be shown in the tree of scopes.
+ */
 enum
 {
   COL_CONTEXT = 0,
-  COL_NAME,
-  COL_NOTE,
-  COL_WARN,
-  COL_HOLE,
+  COL_NAME,  /**< Name of the task/scope/report. */
+  COL_NOTE,  /**< Nr. of "security notes" reported. */
+  COL_WARN,  /**< Nr. of warnings reported. */
+  COL_HOLE,  /**< Nr. of holes reported. */
+  COL_FALSE, /**< Nr. of false positives reported. */
+  COL_LOG,   /**< Nr. of log messages received. */
   COL_EDITABLE,
   NUM_COLS
 };
 
 void
-scopetree_save_treerowref(context, model, iter)
-  struct context *context;
-  GtkTreeModel *model;
-  GtkTreeIter iter;
+scopetree_save_treerowref (struct context* context, GtkTreeModel *model,
+                           GtkTreeIter iter)
 {
   GtkTreePath *path;
 
@@ -61,20 +86,20 @@ scopetree_save_treerowref(context, model, iter)
   context->treerowref = gtk_tree_row_reference_new(model, path);
 }
 
-void
-scope_move_menuitem_enable(context, enable)
-  struct context *context;
-  gboolean enable;
-{
-  context = context_by_type(context, CONTEXT_TASK);
-  if(context && context->move_menuitem && GTK_IS_WIDGET(context->move_menuitem))
-    gtk_widget_set_sensitive(context->move_menuitem, enable);
-}
 
 void
-scopetree_move(context, new_parent)
-  struct context *context;
-  struct context *new_parent;
+scope_move_menuitem_enable (struct context *context, gboolean enable)
+{
+  context = context_by_type(context, CONTEXT_TASK);
+  if (context && context->move_menuitem && GTK_IS_WIDGET(context->move_menuitem))
+      gtk_widget_set_sensitive(context->move_menuitem, enable);
+}
+
+/**
+ * @brief Moves a context under a new parent.
+ */
+void
+scopetree_move (struct context* context, struct context* new_parent)
 {
   GtkWidget *scopetree = GTK_WIDGET(
       arg_get_value(arg_get_value(MainDialog, "SCOPETREE"), "TREEVIEW"));
@@ -84,32 +109,43 @@ scopetree_move(context, new_parent)
   GtkTreeIter iter, parent;
   struct context *next;
   const char *copy_name;
-  int copy_note, copy_warn, copy_hole;
+  int copy_note, copy_warn, copy_hole, copy_false, copy_log;
   gboolean copy_editable;
 
-  /* read old context */
+  /* Read old context */
   old_treerowref = context->treerowref;
   context->treerowref = NULL;
   path = gtk_tree_row_reference_get_path(old_treerowref);
   gtk_tree_model_get_iter(model, &iter, path);
   gtk_tree_path_free(path);
-  gtk_tree_model_get(model, &iter,
-      COL_NAME, &copy_name,
-      COL_NOTE, &copy_note, COL_WARN, &copy_warn, COL_HOLE, &copy_hole,
-      COL_EDITABLE, &copy_editable, -1);
+  gtk_tree_model_get (model, &iter,
+                      COL_NAME, &copy_name,
+                      COL_HOLE, &copy_hole,
+                      COL_WARN, &copy_warn,
+                      COL_NOTE, &copy_note,
+                      COL_FALSE, &copy_false,
+                      COL_LOG, &copy_log,
+                      COL_EDITABLE, &copy_editable,
+                      -1);
 
-  /* create the target context */
+  /* Create the target context */
   path = gtk_tree_row_reference_get_path(new_parent->treerowref);
   gtk_tree_model_get_iter(model, &parent, path);
   gtk_tree_path_free(path);
   gtk_tree_store_append(GTK_TREE_STORE(model), &iter, &parent);
-  gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
-      COL_CONTEXT, context, COL_NAME, copy_name,
-      COL_NOTE, copy_note, COL_WARN, copy_warn, COL_HOLE, copy_hole,
-      COL_EDITABLE, copy_editable, -1);
+  gtk_tree_store_set (GTK_TREE_STORE(model), &iter,
+                      COL_CONTEXT, context,
+                      COL_NAME, copy_name,
+                      COL_HOLE, copy_hole,
+                      COL_WARN, copy_warn,
+                      COL_NOTE, copy_note,
+                      COL_FALSE, copy_false,
+                      COL_LOG, &copy_log,
+                      COL_EDITABLE, copy_editable,
+                      -1);
   scopetree_save_treerowref(context, model, iter);
 
-  /* move children */
+  /* Move children */
   next = context->children;
   while(next)
   {
@@ -117,7 +153,7 @@ scopetree_move(context, new_parent)
     next = next->next;
   }
 
-  /* remove old context */
+  /* Remove old context */
   path = gtk_tree_row_reference_get_path(old_treerowref);
   gtk_tree_model_get_iter(model, &iter, path);
   gtk_tree_path_free(path);
@@ -126,9 +162,7 @@ scopetree_move(context, new_parent)
 }
 
 void
-scope_menu_moveto(menuitem, context)
-  GtkMenuItem *menuitem;
-  struct context *context;
+scope_menu_moveto (GtkMenuItem *menuitem, struct context *context)
 {
   GtkWidget *scopetree = GTK_WIDGET(
       arg_get_value(arg_get_value(MainDialog, "SCOPETREE"), "TREEVIEW"));
@@ -148,8 +182,7 @@ scope_menu_moveto(menuitem, context)
 }
 
 void
-scopetree_move_menuitem_add(context)
-  struct context *context;
+scopetree_move_menuitem_add (struct context *context)
 {
   GtkWidget *menu = arg_get_value(MainDialog, "MOVESCOPE_SUBMENU");
   GtkWidget *menuitem;
@@ -164,8 +197,7 @@ scopetree_move_menuitem_add(context)
 }
 
 void
-scopetree_rename(type)
-  context_type type;
+scopetree_rename (context_type type)
 {
   GtkWidget *scopetree = GTK_WIDGET(
       arg_get_value(arg_get_value(MainDialog, "SCOPETREE"), "TREEVIEW"));
@@ -191,46 +223,34 @@ scopetree_rename(type)
 }
 
 void
-task_menu_rename(menuitem, user_data)
-  GtkMenuItem *menuitem;
-  gpointer user_data;
+task_menu_rename (GtkMenuItem *menuitem, gpointer user_data)
 {
   scopetree_rename(CONTEXT_TASK);
 }
 
 void
-scope_menu_rename(menuitem, user_data)
-  GtkMenuItem *menuitem;
-  gpointer user_data;
+scope_menu_rename (GtkMenuItem *menuitem, gpointer user_data)
 {
   scopetree_rename(CONTEXT_SCOPE);
 }
 
 void
-report_menu_rename(menuitem, user_data)
-  GtkMenuItem *menuitem;
-  gpointer user_data;
+report_menu_rename (GtkMenuItem *menuitem, gpointer user_data)
 {
   scopetree_rename(CONTEXT_REPORT);
 }
 
 
 struct context *
-scopetree_new(type, name, filename)
-  context_type type;
-  const char *name;
-  const char *filename;
+scopetree_new (context_type type, const char* name, const char* filename)
 {
   return scopetree_new_with_parent(NULL, type, name, filename);
 }
 
 
 struct context *
-scopetree_new_with_parent(parentscope, type, name, filename)
-  struct context * parentscope;
-  context_type type;
-  const char *name;
-  const char *filename;
+scopetree_new_with_parent (struct context* parentscope, context_type type,
+                           const char *name, const char *filename)
 {
   GtkWidget *scopetree = GTK_WIDGET(
       arg_get_value(arg_get_value(MainDialog, "SCOPETREE"), "TREEVIEW"));
@@ -284,11 +304,12 @@ scopetree_new_with_parent(parentscope, type, name, filename)
     }
     else
       gtk_tree_store_append(GTK_TREE_STORE(model), &iter, &parent);
-    gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
-	COL_CONTEXT, context,
-	COL_NAME, prefs_get_string(context, "name"),
-	COL_NOTE, -1, COL_WARN, -1, COL_HOLE, -1,
-	COL_EDITABLE, TRUE, -1);
+    gtk_tree_store_set (GTK_TREE_STORE(model), &iter,
+                        COL_CONTEXT, context,
+                        COL_NAME, prefs_get_string(context, "name"),
+                        COL_HOLE, -1, COL_WARN, -1, COL_NOTE, -1, COL_FALSE, -1,
+                        COL_LOG, -1,
+                        COL_EDITABLE, TRUE, -1);
     scopetree_save_treerowref(context, model, iter);
 
     if(parentpath)
@@ -338,12 +359,11 @@ scopetree_context_new(button, user_data)
 }
 
 
-/*
+/**
  * Delete menu widgets, tree row references and tree rows for a subtree.
  */
-void
-scopetree_delete_recurse(context)
-  struct context *context;
+static void
+scopetree_delete_recurse (struct context *context)
 {
   struct context *child = context->children;
   GtkWidget *scopetree = GTK_WIDGET(
@@ -366,9 +386,8 @@ scopetree_delete_recurse(context)
   gtk_tree_store_remove(GTK_TREE_STORE(model), &iter);
 }
 
-void
-scopetree_delete(type)
-  context_type type;
+static void
+scopetree_delete (context_type type)
 {
   GtkWindow *window = GTK_WINDOW(arg_get_value(MainDialog, "WINDOW"));
   GtkWidget *dialog;
@@ -426,34 +445,38 @@ scopetree_delete(type)
 }
 
 
+/**
+ * @param user_data ignored (callback).
+ */
 void
-task_menu_delete(menuitem, user_data)
-  GtkMenuItem *menuitem;
-  gpointer user_data;
+task_menu_delete (GtkMenuItem *menuitem, gpointer user_data)
 {
   scopetree_delete(CONTEXT_TASK);
 }
 
+/**
+ * @param user_data ignored (callback).
+ */
 void
-scope_menu_delete(menuitem, user_data)
-  GtkMenuItem *menuitem;
-  gpointer user_data;
+scope_menu_delete (GtkMenuItem *menuitem, gpointer user_data)
 {
   scopetree_delete(CONTEXT_SCOPE);
 }
 
+/**
+ * @param user_data ignored (callback).
+ */
 void
-report_menu_delete(menuitem, user_data)
-  GtkMenuItem *menuitem;
-  gpointer user_data;
+report_menu_delete (GtkMenuItem *menuitem, gpointer user_data)
 {
   scopetree_delete(CONTEXT_REPORT);
 }
 
+/**
+ * @param user_data ignored (callback).
+ */
 void
-scopetree_context_delete(button, user_data)
-  GtkWidget *button;
-  gpointer user_data;
+scopetree_context_delete (GtkWidget *button, gpointer user_data)
 {
   if(Context->type == CONTEXT_TASK)
     scopetree_delete(CONTEXT_TASK);
@@ -465,11 +488,11 @@ scopetree_context_delete(button, user_data)
     show_error(_("scopetree_context_delete() called with illegal type"));
 }
 
-
-void
-scope_menu_open_ok(widget, user_data)
-  GtkWidget *widget;
-  gpointer user_data;
+/**
+ * @param user_data ignored (callback).
+ */
+static void
+scope_menu_open_ok (GtkWidget *widget, gpointer user_data)
 {
   GtkWidget *dialog = GTK_WIDGET(user_data);
   gchar *filename;
@@ -488,10 +511,11 @@ scope_menu_open_ok(widget, user_data)
   g_free(filename);
 }
 
+/**
+ * @param user_data ignored (callback).
+ */
 void
-scope_menu_open(menuitem, user_data)
-  GtkMenuItem *menuitem;
-  gpointer user_data;
+scope_menu_open (GtkMenuItem *menuitem, gpointer user_data)
 {
   GtkWindow *parent = arg_get_value(MainDialog, "CONTEXT");
   GtkWidget *dialog = gtk_file_selection_new(
@@ -508,10 +532,8 @@ scope_menu_open(menuitem, user_data)
 }
 
 
-void
-scope_menu_save_ok(widget, user_data)
-  GtkWidget *widget;
-  gpointer user_data;
+static void
+scope_menu_save_ok (GtkWidget *widget, gpointer user_data)
 {
   GtkWidget *dialog = GTK_WIDGET(user_data);
   gchar *filename;
@@ -531,9 +553,7 @@ scope_menu_save_ok(widget, user_data)
 }
 
 void
-scope_menu_save(menuitem, user_data)
-  GtkMenuItem *menuitem;
-  gpointer user_data;
+scope_menu_save (GtkMenuItem* menuitem, gpointer user_data)
 {
   GtkWindow *parent = arg_get_value(MainDialog, "CONTEXT");
   GtkWidget *dialog = gtk_file_selection_new(_("Save scope configuration"));
@@ -550,72 +570,76 @@ scope_menu_save(menuitem, user_data)
 }
 
 
+/**
+ * @brief Set table values for statistics (e.g. nr. of warnings) in the
+ * @brief treestore. Values are read from or written to a .cnt file.
+ * 
+ * @param treestore Treestore to manipulate.
+ * @param be        Backend index, will be converted (backend_convert) if file
+ *                  does not exist.
+ * @param fname     Path to .cnt file.
+ */
 void
-scopetreestore_counters_update(treestore, iter, be, fname)
-  GtkTreeStore *treestore;
-  GtkTreeIter iter;
-  int be;
-  char * fname;
+scopetreestore_counters_update (GtkTreeStore* treestore, GtkTreeIter iter,
+                                int be, char * fname)
 {
   struct arglist *hosts;
-  char cached_counters[1024];
+  gchar* cached_counters = NULL;
   FILE * fp;
-  int    h = 0, w = 0,  n = 0;
+  int    highs = 0, warns = 0, notes = 0, falsepos = 0, logs = 0;
 
-  /*
-   * Cache the results in a '.cnt' file to avoid recounting 
-   * each .nbe file on startup
-   */
-  if ( fname != NULL )
-	{
-  	snprintf(cached_counters, sizeof(cached_counters), "%s.cnt", fname);
-	fp = fopen(cached_counters, "r");
-	}
+  /* Cache the results in a '.cnt' file to avoid recounting 
+   * each .nbe file on startup */
+  if (fname != NULL)
+    {
+      cached_counters = g_strdup_printf ("%s.cnt", fname);
+      fp = fopen (cached_counters, "r");
+    }
   else
-	fp = NULL;
+    fp = NULL;
 
-  if ( fp == NULL )
+  if (fp == NULL)
   {
      hosts = backend_convert(be);
-     h = number_of_holes(hosts);
-     w = number_of_warnings(hosts);
-     n = number_of_notes(hosts);
+     highs = number_of_holes(hosts);
+     warns = number_of_warnings(hosts);
+     notes = number_of_notes(hosts);
+     falsepos = number_of_false_positives(hosts);
+     logs = number_of_log_messages(hosts);
      if(hosts) arg_free_all(hosts);
      if ( fname != NULL )
-     	fp = fopen(cached_counters, "w");
+       fp = fopen (cached_counters, "w");
      else
 	fp = NULL;
 
      if ( fp != NULL )
       {
-       fprintf(fp, "%d %d %d\n", h, w, n);
+       fprintf(fp, "%d %d %d %d %d\n", highs, warns, notes, falsepos, logs);
        fclose(fp);
       }
       else if ( fname != NULL ) perror("open ");
   }
   else
   {
-    fscanf(fp, "%d %d %d", &h, &w, &n);
+    fscanf(fp, "%d %d %d %d %d", &highs, &warns, &notes, &falsepos, &logs);
     fclose(fp);
   }
-   
-
 
 
   /* XXX: add these to scopes and tasks? */
-  gtk_tree_store_set(treestore, &iter,
-      COL_NOTE, n,
-      COL_WARN, w,
-      COL_HOLE, h,
-      -1);
-
+  gtk_tree_store_set (treestore, &iter,
+                      COL_NOTE, notes,
+                      COL_WARN, warns,
+                      COL_HOLE, highs,
+                      COL_FALSE, falsepos,
+                      COL_LOG, logs,
+                      -1);
+  if (cached_counters) g_free (cached_counters);
 }
 
+
 void
-scopetreeview_counters_update(context, be,fname)
-  struct context *context;
-  int be;
-  char * fname;
+scopetreeview_counters_update (struct context *context, int be, char * fname)
 {
   GtkWidget *scopetree = GTK_WIDGET(
       arg_get_value(arg_get_value(MainDialog, "SCOPETREE"), "TREEVIEW"));
@@ -630,9 +654,9 @@ scopetreeview_counters_update(context, be,fname)
   gtk_tree_path_free(path);
 }
 
+
 void
-scopetreeview_connected_update(context)
-  struct context *context;
+scopetreeview_connected_update (struct context *context)
 {
   GtkWidget *scopetree = GTK_WIDGET(
       arg_get_value(arg_get_value(MainDialog, "SCOPETREE"), "TREEVIEW"));
@@ -645,17 +669,16 @@ scopetreeview_connected_update(context)
   gtk_tree_path_free(path);
 }
 
-/* Set the pixbuf of the cell according to the state of the context or the row
+
+/**
+ * @brief Set the pixbuf of the cell according to the state of the context or
+ *        the row.
  *
- * The data parameter should be the tree-view widget.
+ * @param data The tree-view widget.
  */
 static void
-connected_data_func(tree_column, cell, model, iter, data)
-  GtkTreeViewColumn *tree_column;
-  GtkCellRenderer *cell;
-  GtkTreeModel *model;
-  GtkTreeIter *iter;
-  gpointer data;
+connected_data_func (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell,
+                     GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 {
   GtkWidget *widget = GTK_WIDGET(data);
   GdkPixbuf *icon = NULL;
@@ -668,19 +691,25 @@ connected_data_func(tree_column, cell, model, iter, data)
    * i.e. no icon at all.
    */
   if (context->type == CONTEXT_SCOPE || context->type == CONTEXT_GLOBAL)
-  {
-    icon = gtk_widget_render_icon(widget,
-	context->socket < 0 ? "nessus-disconnect" : "nessus-connect",
-	GTK_ICON_SIZE_MENU, NULL);
-  }
+    {
+      icon = gtk_widget_render_icon (widget,
+             context->socket < 0 ? "openvas-disconnect" : "openvas-connect",
+             GTK_ICON_SIZE_MENU, NULL);
+    }
+  else if (context->type == CONTEXT_REPORT
+           && context->is_severity_mapped == TRUE)
+    {
+      icon = gtk_widget_render_icon (widget, "gtk-convert", GTK_ICON_SIZE_MENU,
+                                     NULL);
+    }
 
-  g_object_set(G_OBJECT(cell), "pixbuf", icon, NULL);
+  g_object_set (G_OBJECT(cell), "pixbuf", icon, NULL);
 
   if (icon != NULL)
     g_object_unref(icon);
 }
 
-void
+static void
 on_scope_edited(cellrenderertext, path_string, new_text, data)
   GtkCellRendererText *cellrenderertext;
   gchar *path_string;
@@ -713,19 +742,24 @@ on_scope_edited(cellrenderertext, path_string, new_text, data)
   gtk_tree_path_free(path);
 }
 
-gboolean
-scopetreeview_selection_func(selection, model, path,
-    path_currently_selected, userdata)
-  GtkTreeSelection *selection;
-  GtkTreeModel *model;
-  GtkTreePath *path;
-  gboolean path_currently_selected;
-  gpointer userdata;
+/**
+ * @brief Implementation of a GtkTreeSelectionFunc().
+ * 
+ * Does autoconnect and auto-expand if the Client was configured to do so.
+ * Sets the filter- state (is_severity_mapped) of the selected context according
+ * to existance of global severity filter and the glabal_filter_active flag.
+ * 
+ * @return Always TRUE, because all rows are always selectable.
+ */
+static gboolean
+scopetreeview_selection_func (GtkTreeSelection *selection, GtkTreeModel *model,
+                              GtkTreePath *path, gboolean path_currently_selected,
+                              gpointer userdata)
 {
   GtkTreeIter iter;
   struct context *context;
 
-  if(!path_currently_selected &&
+  if (!path_currently_selected &&
       !gtk_tree_selection_get_selected(selection, NULL, NULL))
   {
     gtk_tree_model_get_iter(model, &iter, path);
@@ -740,22 +774,28 @@ scopetreeview_selection_func(selection, model, path,
       prefs_dialog_auth_connection(context);
     }
   }
+
   return TRUE;			/* allow selection state to change */
 }
 
-void
-cell_counts(tree_column, cell, tree_model, iter, data)
-  GtkTreeViewColumn *tree_column;
-  GtkCellRenderer *cell;
-  GtkTreeModel *tree_model;
-  GtkTreeIter *iter;
-  gpointer data;
+/**
+ * @brief Writes a number to a cell, number is fetched from tree_model.
+ * 
+ * Acts as cell_data_func for the columns that involve counting 
+ * (e.g. COL_HOLES shows number of reported holes).
+ * 
+ * @param data In practice one of COL_HOLE, COL_WARN, COL_NOTE, COL_FALSE,
+ *             used as column- index in  tree_model to receive the value.
+ */
+static void
+cell_counts (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell,
+             GtkTreeModel *tree_model, GtkTreeIter *iter, gpointer data)
 {
   gint value;
   gchar *text;
 
   /* Get the int value from the model. */
-  gtk_tree_model_get(tree_model, iter, (gint) data, &value, -1);
+  gtk_tree_model_get(tree_model, iter, GPOINTER_TO_SIZE(data), &value, -1);
   /* Now we can format the value ourselves. */
   if(value < 0)
     text = g_strdup("");
@@ -765,9 +805,52 @@ cell_counts(tree_column, cell, tree_model, iter, data)
   g_free(text);
 }
 
+/**
+ * @brief Behave as if the currently selected report would have been freshly
+ * @brief selected, update counters, icons etc.
+ * 
+ * Motivation for this function is to apply filters "on the fly" on the current
+ * selected report.
+ */
 void
-scopetreeview_create_columns(view)
-  GtkWidget *view;
+prefs_scope_tree_update_report ()
+{
+  /* If currently a Report is selected in the GUI,
+    Update the scopeview, as we want the values and icon change immediately
+    according to the severity_filter.
+    Ideally that should work by just sending an update() signal to the
+    scopetreeview. That did not work in practice, however.
+    @TODO make this meachanism clean, document flow of events in real life GUI use.  */
+  if (Context->type == CONTEXT_REPORT)
+    {
+      GtkWidget *scopetree = GTK_WIDGET (arg_get_value(arg_get_value(MainDialog,
+                                                        "SCOPETREE"), "TREEVIEW"));
+      GtkTreeSelection* selection = gtk_tree_view_get_selection(GTK_TREE_VIEW (scopetree));
+      GtkTreeModel* model = gtk_tree_view_get_model (GTK_TREE_VIEW (scopetree));
+      GtkTreeIter iter;
+
+      // Get the selector, and the path to the selected node.
+      gtk_tree_selection_get_selected (selection, NULL, &iter);
+      GtkTreePath * path = gtk_tree_model_get_path (model, &iter);
+      gtk_tree_selection_select_path (selection, path);
+      // Manually call the selection function to update icon that indicates filtering
+      scopetreeview_selection_func (selection, model, path, FALSE, NULL);
+
+      char* fname = report_get_filename (Context);
+      int be = backend_import_report (fname);
+      // Manually call counter update
+      scopetreestore_counters_update (GTK_TREE_STORE(model), iter, be, NULL);
+      prefs_report_update (arg_get_value (MainDialog, "REPORT"), TRUE);
+    }
+}
+
+/**
+ * @brief Creates the columns of the scope- tree view.
+ * 
+ * @param view The scope-tree view.
+ */
+void
+scopetreeview_create_columns (GtkWidget* view)
 {
   GtkTreeViewColumn *column;
   GtkCellRenderer *renderer;
@@ -791,15 +874,15 @@ scopetreeview_create_columns(view)
 
   column = gtk_tree_view_column_new();
   gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), 1);
-  gtk_tree_view_column_set_title(column, _("Low"));
+  gtk_tree_view_column_set_title(column, _("High"));
   gtk_tree_view_append_column(GTK_TREE_VIEW(view), column);
   renderer = gtk_cell_renderer_text_new();
   g_object_set(renderer, "xalign", (gfloat) 1.0, "xpad", (guint) 8, NULL);
   gtk_tree_view_column_pack_start(column, renderer, TRUE);
-  gtk_tree_view_column_add_attribute(column, renderer, "text", COL_NOTE);
+  gtk_tree_view_column_add_attribute(column, renderer, "text", COL_HOLE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  cell_counts,
-					  (gpointer) COL_NOTE, NULL);
+					  (gpointer) COL_HOLE, NULL);
 
   column = gtk_tree_view_column_new();
   gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), 1);
@@ -815,39 +898,61 @@ scopetreeview_create_columns(view)
 
   column = gtk_tree_view_column_new();
   gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), 1);
-  gtk_tree_view_column_set_title(column, _("High"));
+  gtk_tree_view_column_set_title(column, _("Low"));
   gtk_tree_view_append_column(GTK_TREE_VIEW(view), column);
   renderer = gtk_cell_renderer_text_new();
   g_object_set(renderer, "xalign", (gfloat) 1.0, "xpad", (guint) 8, NULL);
   gtk_tree_view_column_pack_start(column, renderer, TRUE);
-  gtk_tree_view_column_add_attribute(column, renderer, "text", COL_HOLE);
+  gtk_tree_view_column_add_attribute(column, renderer, "text", COL_NOTE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  cell_counts,
-					  (gpointer) COL_HOLE, NULL);
+					  (gpointer) COL_NOTE, NULL);
+
+  column = gtk_tree_view_column_new();
+  gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), 1);
+  gtk_tree_view_column_set_title(column, _("FP"));
+  gtk_tree_view_append_column(GTK_TREE_VIEW(view), column);
+  renderer = gtk_cell_renderer_text_new();
+  g_object_set(renderer, "xalign", (gfloat) 1.0, "xpad", (guint) 8, NULL);
+  gtk_tree_view_column_pack_start(column, renderer, TRUE);
+  gtk_tree_view_column_add_attribute(column, renderer, "text", COL_FALSE);
+  gtk_tree_view_column_set_cell_data_func(column, renderer,
+					  cell_counts,
+					  (gpointer) COL_FALSE, NULL);
+  
+  column = gtk_tree_view_column_new ();
+  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(column), 1);
+  gtk_tree_view_column_set_title (column, _("Log"));
+  gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+  renderer = gtk_cell_renderer_text_new ();
+  g_object_set (renderer, "xalign", (gfloat) 1.0, "xpad", (guint) 8, NULL);
+  gtk_tree_view_column_pack_start (column, renderer, TRUE);
+  gtk_tree_view_column_add_attribute (column, renderer, "text", COL_LOG);
+  gtk_tree_view_column_set_cell_data_func (column, renderer, cell_counts,
+                                           (gpointer) COL_LOG, NULL);
 }
 
 GtkTreeStore *
-scope_create_treestore(context)
-  struct context *context;
+scope_create_treestore (struct context *context)
 {
   GtkTreeStore *treestore;
   GtkTreeIter global, task, scope, report;
   /* TODO currently unused:
-   * GtkTreeIter hostgroup, host;
-   */
+   * GtkTreeIter hostgroup, host; */
   struct context *tasks, *scopes, *reports;
 
-  treestore = gtk_tree_store_new(NUM_COLS,
-      G_TYPE_POINTER,
-      G_TYPE_STRING,
-      G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_BOOLEAN);
+  treestore = gtk_tree_store_new (NUM_COLS,
+                                  G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_INT,
+                                  G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,
+                                  G_TYPE_BOOLEAN);
 
   gtk_tree_store_append(treestore, &global, NULL);
-  gtk_tree_store_set(treestore, &global,
-      COL_CONTEXT, context,
-      COL_NAME, prefs_get_string(context, "name"),
-      COL_NOTE, -1, COL_WARN, -1, COL_HOLE, -1,
-      COL_EDITABLE, FALSE, -1);
+  gtk_tree_store_set (treestore, &global,
+                      COL_CONTEXT, context,
+                      COL_NAME, prefs_get_string(context, "name"),
+                      COL_HOLE, -1, COL_WARN, -1, COL_NOTE, -1, COL_FALSE, -1,
+                      COL_LOG, -1,
+                      COL_EDITABLE, FALSE, -1);
   scopetree_save_treerowref(context, GTK_TREE_MODEL(treestore), global);
 
   tasks = context->children;
@@ -855,10 +960,12 @@ scope_create_treestore(context)
   {
     gtk_tree_store_append(treestore, &task, NULL);
     gtk_tree_store_set(treestore, &task,
-	COL_CONTEXT, tasks,
-	COL_NAME, prefs_get_string(tasks, "name"),
-	COL_NOTE, -1, COL_WARN, -1, COL_HOLE, -1,
-	COL_EDITABLE, TRUE, -1);
+                       COL_CONTEXT, tasks,
+                       COL_NAME, prefs_get_string(tasks, "name"),
+                       COL_HOLE, -1, COL_WARN, -1, COL_NOTE, -1, COL_FALSE, -1,
+                       COL_LOG, -1,
+                       COL_EDITABLE, TRUE,
+                       -1);
     scopetree_save_treerowref(tasks, GTK_TREE_MODEL(treestore), task);
     scopetree_move_menuitem_add(tasks);
 
@@ -866,22 +973,24 @@ scope_create_treestore(context)
     while(scopes)
     {
       gtk_tree_store_append(treestore, &scope, &task);
-      gtk_tree_store_set(treestore, &scope,
-	  COL_CONTEXT, scopes,
-	  COL_NAME, prefs_get_string(scopes, "name"),
-	  COL_NOTE, -1, COL_WARN, -1, COL_HOLE, -1,
-	  COL_EDITABLE, TRUE, -1);
+      gtk_tree_store_set (treestore, &scope,
+                          COL_CONTEXT, scopes,
+                          COL_NAME, prefs_get_string(scopes, "name"),
+                          COL_HOLE, -1, COL_WARN, -1, COL_NOTE, -1, COL_FALSE, -1,
+                          COL_LOG, -1,
+                          COL_EDITABLE, TRUE, -1);
       scopetree_save_treerowref(scopes, GTK_TREE_MODEL(treestore), scope);
 
       reports = scopes->children;
       while(reports)
       {
 	gtk_tree_store_append(treestore, &report, &scope);
-	gtk_tree_store_set(treestore, &report,
-	    COL_CONTEXT, reports,
-	    COL_NAME, prefs_get_string(reports, "name"),
-	    COL_NOTE, -1, COL_WARN, -1, COL_HOLE, -1,
-	    COL_EDITABLE, TRUE, -1);
+        gtk_tree_store_set (treestore, &report,
+                            COL_CONTEXT, reports,
+                            COL_NAME, prefs_get_string(reports, "name"),
+                            COL_HOLE, -1, COL_WARN, -1, COL_NOTE, -1, COL_FALSE, -1,
+                            COL_LOG, -1,
+                            COL_EDITABLE, TRUE, -1);
 	scopetree_save_treerowref(reports, GTK_TREE_MODEL(treestore), report);
 
 	{
@@ -905,9 +1014,13 @@ scope_create_treestore(context)
   return treestore;
 }
 
+/**
+ * Returns an arglist with following keys (type, description):
+ *  - FRAME (GtkScrolledWindow*, )
+ *  - TREEVIEW (GtkTreeView*, )
+ */
 struct arglist *
-prefs_dialog_scope_tree(context)
-  struct context *context;
+prefs_dialog_scope_tree (struct context *context)
 {
   GtkTreeModel *model;
   GtkTreeSelection *selection;
