@@ -131,7 +131,7 @@ target_file_to_list(const char* filename)
  char * ret,*t;
  int len;
  struct_stat sb;
- int n, i, offs, left ;
+ int n, offs, left ;
 
  if(fd < 0)
  {
@@ -165,7 +165,7 @@ target_file_to_list(const char* filename)
  while((t=strchr(t, '\n')))t[0]=',';
  t = ret;
  while((t=strchr(t, '\r')))t[0]=' ';
- i = strlen(ret);
+
  /*
   * trailing garbage
   */
@@ -202,7 +202,7 @@ target_translate (const char* target)
 
   // Get untouched list of targets
   if (!strncmp (target, "file:", 5) )
-    untouched = target_file_to_list (target + strlen ("file:") );
+    untouched = target_file_to_list (target + strlen ("file:") ); /* RATS: ignore, string literal is nul terminated */
   else
     untouched = strdup (target);
 
