@@ -67,12 +67,21 @@
 #define SAVE_MAX SAVE_XML_NG
 
 
-/*------------------------------------------------------------------------*/
-
+/**
+ * @brief Callback for report export filename and type (nbe, html...) selection
+ * widget.
+ * 
+ * Determines export target type and converts the backend appropriately, e.g.
+ * by calling arglist_to_html.
+ * 
+ * @return Always 0.
+ * 
+ * @see arglist_to_html
+ * @see backend_to_nbe
+ * @see report_save_cb
+ */
 static int
-file_save_ok_callback(widget, filedialog)
-  GtkWidget *widget;
-  GtkWidget *filedialog;
+file_save_ok_callback (GtkWidget *widget, GtkWidget *filedialog)
 {
   const char *filename =
     gtk_file_selection_get_filename(GTK_FILE_SELECTION(filedialog));
@@ -82,15 +91,17 @@ file_save_ok_callback(widget, filedialog)
   struct arglist *hosts = NULL;
   GtkWidget *menu = gtk_object_get_data(GTK_OBJECT(filedialog), "menu");
   GtkWidget *active = gtk_menu_get_active(GTK_MENU(menu));
-  int type = (int)gtk_object_get_data(GTK_OBJECT(active), "type");
-  char *suffixes[] =
-      { ".nbe", ".html", ".txt", ".tex", "", ".pdf", ".xml"};
-#define MAX_SUFFIX_LEN 5	/* .html */
+  int type = GPOINTER_TO_SIZE(gtk_object_get_data(GTK_OBJECT(active), "type"));
+  char *suffixes[] = { ".nbe", ".html", ".txt", ".tex", "", ".pdf", ".xml"};
+#define MAX_SUFFIX_LEN 5 /* .html */
   char *suffix = suffixes[type];
-  int be = (int)arg_get_value(arg_get_value(MainDialog, "REPORT"), "BE");
+  int be = GPOINTER_TO_SIZE(arg_get_value(arg_get_value(MainDialog, "REPORT"), "BE"));
   struct context *report_context
     = arg_get_value(arg_get_value(MainDialog, "REPORT"), "REPORT_CONTEXT");
 
+  gboolean was_mapped = report_context->is_severity_mapped;
+  report_context->is_severity_mapped = FALSE;
+
   gtk_widget_hide(filedialog);
 
   if(check_is_dir(filename))
@@ -126,7 +137,7 @@ file_save_ok_callback(widget, filedialog)
       hosts = backend_convert(be);
       arglist_to_text(hosts, fname);
       break;
-#ifndef _NOPIE
+#ifndef NO_GDCHART
     case SAVE_HTML_GRAPH:
       hosts = backend_convert(be);
       arglist_to_html_graph(hosts, fname);
@@ -145,16 +156,24 @@ file_save_ok_callback(widget, filedialog)
   if(hosts)
     arg_free_all(hosts);
   gtk_widget_destroy(filedialog);
+
+  report_context->is_severity_mapped = was_mapped;
   return 0;
 }
 
-/*
- *  "inspired" from the Gimp 1.2.2
+/**
+ * @brief Callback, opens a file and export target (nbe, xml, pdf...) selection
+ * @brief widget and attempts export on click on OK.
+ * 
+ * Callback on OK- button is file_save_ok_callback.
+ * "inspired" from the Gimp 1.2.2
  * See gimp/app/fileops.c for a cleaner function
+ * @window Parent gtk widget.
+ * 
+ * @see file_save_ok_callback
  */
 void
-report_save_cb(window)
-  GtkWidget *window;
+report_save_cb (GtkWidget *window)
 {
   GtkWidget *filesave;
   GtkWidget *frame;
@@ -231,7 +250,7 @@ report_save_cb(window)
   gtk_menu_append(GTK_MENU(menu), type);
   gtk_widget_show(type);
 
-#ifndef _NO_PIES
+#ifndef NO_GDCHART
   type = gtk_menu_item_new_with_label(_("HTML with Pies and Graphs"));
   gtk_object_set_data(GTK_OBJECT(type), "type", (void *)SAVE_HTML_GRAPH);
   gtk_menu_append(GTK_MENU(menu), type);
@@ -263,8 +282,7 @@ report_save_cb(window)
 #ifndef CYGWIN
 
 void
-show_pdf(filename)
-  char * filename;
+show_pdf (gchar * filename)
 {
   const gchar *pdfviewer = prefs_get_string(Global, "pdfviewer");
 
@@ -299,8 +317,7 @@ show_pdf(filename)
  * appreciated.
  */
 void
-show_pdf(filename)
-  char * filename;
+show_pdf (gchar * filename)
 {
   char win32path[MAX_PATH];
   HINSTANCE rc;
@@ -329,24 +346,22 @@ show_pdf(filename)
 #endif /* CYGWIN */
 
 void
-report_open_pdf(menuitem, ctrls)
-  GtkWidget *menuitem;
-  gpointer ctrls;
+report_open_pdf (GtkWidget *menuitem,  gpointer ctrls)
 {
-  int be = (int)arg_get_value(arg_get_value(ctrls, "REPORT"), "BE");
+  int be = GPOINTER_TO_SIZE(arg_get_value(arg_get_value(ctrls, "REPORT"), "BE"));
   struct context *report_context
     = arg_get_value(arg_get_value(ctrls, "REPORT"), "REPORT_CONTEXT");
-  char *basename = g_path_get_basename(Context->dir);
-  char *fname = g_strdup_printf("%s.pdf", basename);
-  char *filename = g_build_filename(Context->dir, fname, NULL);
+  gchar *basename = g_path_get_basename (Context->dir);
+  gchar *fname    = g_strdup_printf ("%s.pdf", basename);
+  gchar *filename = g_build_filename (Context->dir, fname, NULL);
 
-  g_free(basename);
-  g_free(fname);
+  g_free (basename);
+  g_free (fname);
 
-  arglist_to_pdf(report_context, be, filename);
+  arglist_to_pdf (report_context, be, filename);
 
-  show_pdf(filename);
-  g_free(filename);
+  show_pdf (filename);
+  g_free (filename);
 }
 
 #endif
