@@ -25,8 +25,11 @@
  * this file, you may extend this exception to your version of the
  * file, but you are not obligated to do so.  If you do not wish to
  * do so, delete this exception statement from your version.
- *
- * Signals handler
+ */
+
+/**
+ * @file
+ * Signal handler and code for closing connections to the server.
  */
 
 #include <includes.h>
@@ -35,50 +38,56 @@
 #include "context.h"
 #include "backend.h"
 #include "auth.h"
-#include "globals.h" /* for closesocket() */
 
-
-void
-nessus_exit(code)
-  int code;
+/**
+ * @brief Closes all connections to the server(s) that are within or under a
+ *        certain context.
+ * 
+ * @param ctx Contexts into which to descend (next and children) and close the
+ *            connection(s) to the server.
+ */
+static void
+close_all_context_cnx (struct context * ctx)
 {
-  backend_clear_all();
-  exit(code);
+  if ( ctx == NULL )
+    return;
+
+  while ( ctx != NULL )
+    {
+      if ( ctx->socket > 0 )
+        {
+          network_printf (ctx->socket, "CLIENT <|> STOP_WHOLE_TEST <|> CLIENT\n");
+          close_stream_connection (ctx->socket);
+          ctx->socket = -1;
+        }
+      close_all_context_cnx (ctx->children);
+      ctx = ctx->next;
+    }
+}
+
+/**
+ * @brief Closes all connections to server, clears the backends and exits with
+ * @brief given code.
+ * 
+ * @param code The exit code.
+ */
+void
+nessus_exit (int code)
+{
+  close_all_context_cnx (Global);
+  backend_clear_all ();
+  exit (code);
 }
 
 void
-sighand_pipe()
+sighand_pipe ()
 {
   Context->socket = -1;
   show_error(_("Connection closed by the server (SIGPIPE caught)"));
 }
 
-void 
-sighand_alarm()
+void sighand_exit ()
 {
-  show_error(_("Connection timed out"));
-}
-
-
-void close_all_context_cnx(struct context * ctx)
-{
- if ( ctx == NULL ) return;
- while ( ctx != NULL )
- {
-  if ( ctx->socket > 0 )
-  {
-    network_printf(ctx->socket, "CLIENT <|> STOP_WHOLE_TEST <|> CLIENT\n");
-    close_stream_connection(ctx->socket);
-    ctx->socket = -1;
- } 
-  close_all_context_cnx(ctx->children);
-  ctx = ctx->next;
- }
-}
-
-
-void sighand_exit()
-{
-  close_all_context_cnx(Context);
-  nessus_exit(1);
+  close_all_context_cnx (Global);
+  nessus_exit (1);
 }
