@@ -30,7 +30,11 @@
 #include "report.h"
 #include "report_utils.h"
 #include "error_dlg.h"
+#include "backend.h"
 
+/* Created from backend_convert, when a severity_filter is active, gives the
+   mapping matrix. */
+extern int sev_mapping_matrix[6][6];
 
 static char * printf_line(FILE * file, char * text, int offset)
 {
@@ -232,6 +236,27 @@ arglist_to_text(hosts, filename)
   fprintf(file, "\n");
   hosts = hosts->next;
  }
+
+ // Print statistics about severity filter application, if enabled.
+ if (Context->is_severity_mapped == TRUE)
+  {
+    int r = 0;
+    int c = 0;
+    fprintf (file, "\n\nSEVERITY FILTER STATISTICS\n\n");
+
+    for (r = 0; r < 6; r++)
+      {
+        for (c = 0; c < 6; c++)
+          {
+            if (sev_mapping_matrix[r][c] != 0)
+              {
+                fprintf (file, " - Mapped %d reported issues from severity '%s' to '%s'.\n\n", sev_mapping_matrix[r][c],
+                              priority_idx_to_str(r), priority_idx_to_str (c));
+              }
+          }
+      }
+  }
+
  fprintf(file, "\n\n\n");
  fprintf(file, "------------------------------------------------------\n");
  fprintf(file, "This file was generated by the OpenVAS Security Scanner [http://www.openvas.org]\n");
