@@ -53,8 +53,12 @@
 #include "context.h"
 #include "preferences.h"
 #include "report_utils.h"
+#include "backend.h"
+#include "xml_output_ng.h"
 
-int backend_to_xml_ng (int, char *);
+/* Created from backend_convert, when a severity_filter is active, gives the
+   mapping matrix. */
+extern int sev_mapping_matrix[6][6];
 
 static void xml_info (int, FILE*, int);
 static void xml_config (FILE*, int);
@@ -133,12 +137,12 @@ static char * escape_string (char * str)
   char *ret, *temp;
   int i, y, len;
 
-  temp = str;
-  ret = emalloc (6 * strlen (temp) + 1);
   len = strlen (str);
+  temp = str;
+  ret = emalloc (6 * len + 1);
+
+  bzero (ret, 6 * len + 1);
 
-  bzero (ret, 6 * strlen (temp) + 1);
-  
   for (i=0,y=0 ; i<len ; i++,y++)
   {
     switch (temp[i])
@@ -406,8 +410,8 @@ xml_config (FILE* fd, int indent)
  * @param indent Current indentation level
  * @param u      NVT of interest.
  */
-static void 
-xml_plugins_plugin (FILE* fd, int indent, struct nessus_plugin * u )
+static void
+xml_plugins_plugin (FILE* fd, int indent, struct nessus_plugin * u)
 {
     char * s = nessus_plugin_get_description(u);
 
@@ -424,44 +428,60 @@ xml_plugins_plugin (FILE* fd, int indent, struct nessus_plugin * u )
      xml_fprintf (fd, indent, "</nvt>\n");
 } /* xml_plugins_plugin */
 
-static void 
+/**
+ * @brief Prints plugin and scanner information to the xml file.
+ * 
+ * @param fd      File to write to.
+ * @param intdent Indentation level to use.
+ */
+static void
 xml_plugins (FILE* fd, int indent)
-{ 
- struct nessus_plugin * t;
+{
+  struct nessus_plugin * t;
 
- xml_fprintf (fd, indent, "<nvts>\n");
+  xml_fprintf (fd, indent, "<nvts>\n");
 
-  if ( Context->parent != NULL )
-	t = Context->parent->scanners;
+  /** @TODO Verify that the Contexts _parents_ info is what we want to see!
+   *        (why parent?) */
+  if (Context->parent != NULL)
+    t = Context->parent->scanners;
   else
-	t = NULL;
+    t = NULL;
 
-  if ( t != NULL )
-   while (t != NULL )
-   {
-     if ( t->enabled != 0 )
-      xml_plugins_plugin(fd, indent+1, t);
+  // If its still NULL, take current contexts.
+  if (t == NULL)
+    t = Context->scanners;
 
-    t = t->next;
-   }
+  if (t != NULL)
+    while (t != NULL)
+      {
+        if (t->enabled != 0)
+          xml_plugins_plugin (fd, indent+1, t);
+        t = t->next;
+      }
   else
-   xml_fprintf (fd, indent+1, "<error txt=\"No scanners list.\"/>\n");
+    xml_fprintf (fd, indent+1, "<error txt=\"No scanners list.\"/>\n");
 
-  if ( Context->parent != NULL )
-	t = Context->parent->plugins;
+  /** @TODO Verify that the Contexts _parents_ info is what we want to see!
+   *        (why parent?) */
+  if (Context->parent != NULL)
+    t = Context->parent->plugins;
   else
-	t = NULL;
-  if ( t != NULL )
-   while (t != NULL )
-   {
-     if ( t->enabled != 0 )
-      xml_plugins_plugin(fd, indent+1, t);
+    t = NULL;
 
-    t = t->next;
-   }
+  // If its still NULL, take current contexts.
+  if (t == NULL)
+    t = Context->plugins;
+
+  if (t != NULL)
+    while (t != NULL)
+      {
+        if ( t->enabled != 0)
+          xml_plugins_plugin (fd, indent+1, t);
+        t = t->next;
+      }
   else
-   xml_fprintf (fd, indent+1, "<error txt=\"No NVT list.\"/>\n");
-
+    xml_fprintf (fd, indent+1, "<error txt=\"No NVT list.\"/>\n");
 
   xml_fprintf (fd, indent, "</nvts>\n");
 }
@@ -724,6 +744,45 @@ xml_results ( FILE* fd, int indent, int be)
  subset_free(sq);
 } /* xml_results */
 
+/**
+ * @brief Print the severity_mapping matrix to xml file (if severity filtering
+ * @brief is enabled at current Context).
+ * 
+ * @param fd     File descriptor to write to (attention: no checks are done).
+ * @param indent Level of indentation to start with.
+ * @param be     Backend index.
+ */
+static void
+xml_filter_matrix (FILE* fd, int indent, int be)
+{
+  if (Context->is_severity_mapped == TRUE)
+    {
+      int r = 0;
+      int c = 0;
+
+      xml_fprintf (fd, indent, "<severity-mapping-statistics>\n");
+      xml_fprintf (fd, indent, "<!-- parent:from children:to -->\n");
+
+      // Get Matrix, print table
+      for (r = 0; r < 6; r++)
+        {
+          xml_fprintf (fd, indent+1, "<from severity=\"%s\">\n", priority_idx_to_str (r));
+          for (c = 0; c < 6; c++)
+            {
+              gchar* to_tag = g_strdup_printf ("<to severity=\"%s\">%d</to>\n",
+                                               priority_idx_to_str (c),
+                                               sev_mapping_matrix[r][c]);
+              xml_fprintf (fd, indent+2, to_tag);
+              g_free (to_tag);
+            }
+          xml_fprintf (fd, indent+1, "</from>\n");
+        }
+
+      xml_fprintf (fd, indent, "</severity-mapping-statistics>\n");
+    }
+  // else we do not display this element
+}
+
 /**
  * @brief Exports a backend to xml.
  * 
@@ -735,11 +794,21 @@ xml_results ( FILE* fd, int indent, int be)
 int
 backend_to_xml_ng (int be, char* filename)
 {
+  // Normally, xml output does not walk over the backend via arglist (rather
+  // via the pseudo-sql). However if we call backend_convert we can use the code
+  // there to arrive at filtered report outputs.
+  struct arglist* tmpargs = NULL;
+  // Do not call backend_convert when severity filtering is disabled anyway
+  if (Context->is_severity_mapped == TRUE)
+    tmpargs = backend_convert (be);
+
   FILE* fd = fopen(filename, "w");
 
   if(!fd)
     {
       show_error(_("Can't open %s for writing: %s."), filename, strerror(errno));
+      if (tmpargs != NULL)
+        arg_free_all (tmpargs);
       return -1;
     }
 
@@ -747,12 +816,17 @@ backend_to_xml_ng (int be, char* filename)
 
   xml_fprintf (fd, 0, "<?xml-stylesheet type=\"text/xsl\" href=\"openvas-report.xsl\"?>\n");
   xml_fprintf (fd, 0, "<openvas-report version=\"1.0\">\n");
-  xml_info (be, fd, 1); 
-  xml_config (fd, 1); 
+  xml_info    (be, fd, 1);
+  xml_config  (fd, 1);
   xml_plugins (fd, 1);
   xml_results (fd, 1, be);
+  xml_filter_matrix (fd, 1, be);
   xml_fprintf (fd, 0, "</openvas-report>\n");
 
   fclose(fd);
+
+  if (tmpargs != NULL)
+    arg_free_all (tmpargs);
+
   return 0;
 }
