@@ -34,6 +34,7 @@
  * wish to do so, delete this exception statement from your version.
  */
 
+#include <time.h>
 #include <includes.h>
 #include <stdarg.h>
 
@@ -166,6 +167,13 @@ show_dialog_gtk_log(type, error_text)
   GtkTextIter iter;
   GtkAdjustment *vadjust;
   char *msgtype;
+  struct tm* localtime_;
+  time_t time_;
+  gchar* time_type;
+  gchar* time_newlineless; // Will contain e.g. 04:12:12
+
+  time_ = time(NULL);
+  localtime_ = localtime(&time_);
 
   if(!textview || !scrolledwin)
     return;
@@ -182,18 +190,28 @@ show_dialog_gtk_log(type, error_text)
       msgtype = _("Error: ");
   }
 
-  /* submit the message to the log */
+  time_newlineless = g_strdup (asctime(localtime_));
+  // Strip the newline
+  time_newlineless[strlen(time_newlineless)-1] = '\0';
+  time_type = g_strdup_printf("[%s] %s", time_newlineless, msgtype);
+
+
+  /* Submit the message to the log text view. */
   log = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
   gtk_text_buffer_get_end_iter(log, &iter);
-  gtk_text_buffer_insert(log, &iter, msgtype, -1);
+  gtk_text_buffer_insert(log, &iter, time_type, -1);
   gtk_text_buffer_get_end_iter(log, &iter);
   gtk_text_buffer_insert(log, &iter, error_text, -1);
+
   gtk_text_buffer_get_end_iter(log, &iter);
   gtk_text_buffer_insert(log, &iter, "\n", -1);
 
   vadjust = gtk_scrolled_window_get_vadjustment(
       GTK_SCROLLED_WINDOW(scrolledwin));
   gtk_adjustment_set_value(vadjust, vadjust->upper - 1);
+
+  g_free (time_newlineless);
+  g_free (time_type);
 }
 
 void
