@@ -214,25 +214,41 @@ remove_pattern (GtkWidget* signal_emitter, char* pattern)
 static void
 prompt_new_pattern (GtkWidget* signal_emitter, gpointer ignored)
 {
-  GtkWidget* dialog          = NULL;
+  GtkWidget* dialog           = NULL;
   GtkWidget* patterntextfield = NULL;
-  GtkWidget* content_box     = NULL;
-  GtkWidget* content_area    = NULL;
-  GtkWidget* combobox        = NULL;
-  gboolean sane              = FALSE;
-  gint response              = GTK_RESPONSE_NONE;
-  GtkWidget *context_window = arg_get_value(MainDialog, "CONTEXT");
+  GtkWidget* content_box      = NULL;
+  GtkWidget* content_area     = NULL;
+  GtkWidget* content_vbox     = NULL;
+  GtkWidget* combobox         = NULL;
+  GtkWidget* text             = NULL;
+  gboolean sane               = FALSE;
+  gint response               = GTK_RESPONSE_NONE;
+  GtkWidget *context_window   = arg_get_value(MainDialog, "CONTEXT");
 
   // Create dialog
-  dialog = gtk_message_dialog_new (GTK_WINDOW(context_window),
-                              GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
-                              GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL,
-                              _("Please enter a pattern (it has to contain * or ?) and assign a login to it."));
+  dialog = gtk_dialog_new_with_buttons ("Enter pattern for hostname",
+                                        GTK_WINDOW(context_window),
+                                        GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK, NULL
+                                        );
+
+  // Label // text
+  text = gtk_label_new (_("Please enter a pattern (it has to contain * or ?)\n"
+                          "for hostnames and assign a login to it.\nYou can "
+                          "still change the assignment later.\nThe "
+                          "pattern will be matched against hostnames or\n"
+                          "target IPs as specified in the 'Target selection'"
+                          " section.\n\nFor example:\n'192.168.15.*' matches "
+                          "'192.168.15.7' but not 'myserver',\n'*' "
+                          "matches everything."
+                         ));
+
   patterntextfield = gtk_entry_new ();
-  content_box = gtk_hbox_new (FALSE, 10);
+  content_box  = gtk_hbox_new (FALSE, 10);
+  content_vbox = gtk_vbox_new (FALSE, 10);
   content_area = GTK_DIALOG(dialog)->vbox;
-  gtk_container_add (GTK_CONTAINER (content_box), patterntextfield);
-  
+
   // Create Combobox with SSH-Logins
   combobox = gtk_combo_box_new_text ();
   gtk_combo_box_append_text (GTK_COMBO_BOX(combobox), NO_SSH_LOGIN_SELECTED);
@@ -245,8 +261,11 @@ prompt_new_pattern (GtkWidget* signal_emitter, gpointer ignored)
     }
 
   // Assemble and show
-  gtk_container_add (GTK_CONTAINER (content_box), combobox);
-  gtk_container_add (GTK_CONTAINER (content_area), content_box);
+  gtk_container_add (GTK_CONTAINER (content_vbox), content_box);
+  gtk_container_add (GTK_CONTAINER (content_vbox), text);
+  gtk_container_add (GTK_CONTAINER (content_box),  patterntextfield);
+  gtk_container_add (GTK_CONTAINER (content_box),  combobox);
+  gtk_container_add (GTK_CONTAINER (content_area), content_vbox);
   gtk_widget_show_all (dialog);
 
   // Run the dialog (until user cancels, closes or enters a valid pattern)
