@@ -231,17 +231,24 @@ const gchar *
 severity_filter_apply (const gchar * host, const gchar * port,
                        const gchar * oid, const gchar * severity)
 {
-  if (global_filter != NULL
-      && host != NULL && port != NULL && oid != NULL && severity != NULL) {
-    GSList * o = g_slist_nth(global_filter->overrides, 0);
-    while (o) {
-      if ((!strcmp(host, ((severity_override_t *)o->data)->host)) &&
-          (!strcmp(port, ((severity_override_t *)o->data)->port)) &&
-          (!strcmp(oid, ((severity_override_t *)o->data)->OID)) &&
-          (!strcmp(severity, ((severity_override_t *)o->data)->severity_from)))
-        return ((severity_override_t *)o->data)->severity_to;
-      o = g_slist_next(o);
+  if (global_filter == NULL
+      || host == NULL || port == NULL || oid == NULL || severity == NULL)
+    {
+      return NULL;
     }
+
+  GSList * o = g_slist_nth(global_filter->overrides, 0);
+
+  while (o) {
+    // Check matches. Optimization possible as probably many strings are
+    // compared against always the same strings or patterns. However, we do not
+    // want to carry compiled versions of the patterns around.
+    if ( g_pattern_match_simple (((severity_override_t *)o->data)->host, host) == TRUE &&
+         g_pattern_match_simple (((severity_override_t *)o->data)->port, port) == TRUE &&
+        (!strcmp(oid, ((severity_override_t *)o->data)->OID)) &&
+        (!strcmp(severity, ((severity_override_t *)o->data)->severity_from)))
+      return ((severity_override_t *)o->data)->severity_to;
+    o = g_slist_next(o);
   }
 
   return NULL;
@@ -420,9 +427,9 @@ write_override_xml_elem (severity_override_t* override, FILE* fd)
   gchar* reason_elem = g_markup_printf_escaped ("\t\t<reason>\n\t\t%s\n\t\t</reason>\n",
                                                 override->reason);
 
-  fprintf (fd, override_elem);
-  fprintf (fd, reason_elem);
-  fprintf (fd, "\t</severity_override>\n");
+  fprintf (fd, "%s", override_elem);
+  fprintf (fd, "%s", reason_elem);
+  fprintf (fd, "%s", "\t</severity_override>\n");
 
   g_free (override_elem);
   g_free (reason_elem);
@@ -450,7 +457,7 @@ severity_filter_to_xml (const severity_filter_t * filter)
   if (fd <= 0) return FALSE;
 
   gchar* filter_start_elem = g_markup_printf_escaped ("<severity_filter name=\"%s\">\n", filter->name);
-  fprintf (fd, filter_start_elem);
+  fprintf (fd, "%s", filter_start_elem);
   g_slist_foreach (filter->overrides, (GFunc) write_override_xml_elem , fd);
   fprintf (fd, "</severity_filter>");
   g_free (filter_start_elem);
@@ -670,7 +677,7 @@ severity_filter_from_xml (const gchar * filename)
 
   g_free (filebuffer);
   g_markup_parse_context_free (context);
-  
+
   if (filter->name == NULL)
     {
       severity_filter_free (filter);
